# -*- rpm-spec -*-

%define do_check 0

# This spec file assumes you are building on a Fedora or RHEL version
# that's still supported by the vendor. It may work on other distros
# or versions, but no effort will be made to ensure that going forward.
%define min_rhel 7
%define min_fedora 29

%if (0%{?fedora} && 0%{?fedora} >= %{min_fedora}) || (0%{?rhel} && 0%{?rhel} >= %{min_rhel})
    %define supported_platform 1
%else
    %define supported_platform 0
%endif

# Default to skipping autoreconf.  Distros can change just this one line
# (or provide a command-line override) if they backport any patches that
# touch configure.ac or Makefile.am.
# Always run autoreconf
%{!?enable_autotools:%global enable_autotools 1}

# The hypervisor drivers that run in libvirtd
%define with_qemu          0%{!?_without_qemu:1}
%define with_lxc           0%{!?_without_lxc:1}
%define with_libxl         0%{!?_without_libxl:1}
%define with_vbox          0%{!?_without_vbox:1}
%define with_vzct          0%{!?_without_vzct:1}
%define with_vz            0%{!?_without_vz:1}
%define with_secret        1
%define with_vcmmd         1
%define with_storage_misc  1
%define with_storage_vstorage 1

%define with_qemu_tcg      %{with_qemu}

%define qemu_kvm_arches %{ix86} x86_64

%if 0%{?fedora}
    %define qemu_kvm_arches %{ix86} x86_64 %{power64} s390x %{arm} aarch64
%endif

%if 0%{?rhel}
    %define with_qemu_tcg 0
    %define qemu_kvm_arches x86_64 %{power64} aarch64 s390x
%endif

%ifarch %{qemu_kvm_arches}
    %define with_qemu_kvm      %{with_qemu}
%else
    %define with_qemu_kvm      0
%endif

%if ! %{with_qemu_tcg} && ! %{with_qemu_kvm}
    %define with_qemu 0
%endif

# Then the hypervisor drivers that run outside libvirtd, in libvirt.so
%define with_openvz        0%{!?_without_openvz:1}
%define with_vmware        0%{!?_without_vmware:1}
%define with_phyp          0%{!?_without_phyp:1}
%define with_esx           0%{!?_without_esx:1}
%define with_hyperv        0%{!?_without_hyperv:1}
%define with_docker        0%{!?_without_docker:1}

# Then the secondary host drivers, which run inside libvirtd
%define with_storage_rbd      0%{!?_without_storage_rbd:1}
%if 0%{?fedora}
    %define with_storage_sheepdog 0%{!?_without_storage_sheepdog:1}
%else
    %define with_storage_sheepdog 0
%endif
%define with_numactl          0%{!?_without_numactl:1}

%define with_storage_gluster 0%{!?_without_storage_gluster:1}
%ifnarch %{qemu_kvm_arches}
    # gluster is only built where qemu driver is enabled on RHEL 8
    %if 0%{?rhel} >= 8
        %define with_storage_gluster 0
    %endif
%endif


# F25+ has zfs-fuse
%if 0%{?fedora}
    %define with_storage_zfs      0%{!?_without_storage_zfs:1}
%else
    %define with_storage_zfs      0
%endif

# We need a recent enough libiscsi (>= 1.18.0)
%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_storage_iscsi_direct 0%{!?_without_storage_iscsi_direct:1}
%else
    %define with_storage_iscsi_direct 0
%endif

# A few optional bits off by default, we enable later
%define with_fuse          0%{!?_without_fuse:0}
%define with_sanlock       0%{!?_without_sanlock:0}
%define with_numad         0%{!?_without_numad:0}
%define with_firewalld     0%{!?_without_firewalld:0}
%define with_firewalld_zone 0%{!?_without_firewalld_zone:0}
%define with_libssh2       0%{!?_without_libssh2:0}
%define with_wireshark     0%{!?_without_wireshark:0}
%define with_libssh        0%{!?_without_libssh:0}
%define with_bash_completion  0%{!?_without_bash_completion:0}

# Finally set the OS / architecture specific special cases

# Xen is available only on i386 x86_64 ia64
%ifnarch %{ix86} x86_64 ia64
    %define with_libxl 0
%endif

# vbox is available only on i386 x86_64
%ifnarch %{ix86} x86_64
    %define with_vbox 0
%endif

# Numactl is not available on many non-x86 archs
%ifarch s390 s390x %{arm} riscv64
    %define with_numactl 0
%endif

# zfs-fuse is not available on some architectures
%ifarch s390 s390x aarch64 riscv64
    %define with_storage_zfs 0
%endif

# Ceph dropping support for 32-bit hosts
%if 0%{?fedora} >= 30
    %ifarch %{arm} %{ix86}
        %define with_storage_rbd 0
    %endif
%endif

# RHEL doesn't ship OpenVZ, VBox, PowerHypervisor,
# VMware, libxenserver (xenapi), libxenlight (Xen 4.1 and newer),
# or HyperV.
%if 0%{?rhel}
    %define with_openvz 0
    %define with_vbox 0
    %define with_phyp 0
    %define with_vmware 0
    %define with_xenapi 0
    %define with_libxl 0
    %define with_hyperv 0
    %if 0%{?_aci_build:1}
        %define with_docker 0
        %define with_vzct 0
        %define with_vz 0
        %define with_secret 0
        %define with_vcmmd 0
        %define with_lxc 0
        %define with_esx 0
        %define with_storage_rbd 0
        %define with_storage_gluster 0
        %define with_storage_zfs 0
        %define with_storage_sheepdog 0
        %define with_storage_misc 0
        %define with_storage_iscsi_direct  0
        %define with_storage_vstorage 0
    %endif
%endif

%define with_firewalld 1

%if 0%{?fedora} >= 31 || 0%{?rhel} > 7
    %define with_firewalld_zone 0%{!?_without_firewalld_zone:1}
%endif


# fuse is used to provide virtualized /proc for LXC
%if %{with_lxc}
    %define with_fuse      0%{!?_without_fuse:1}
%endif

# Enable sanlock library for lock management with QEMU
# Sanlock is available only on arches where kvm is available for RHEL
%if 0%{?fedora}
    %define with_sanlock 0%{!?_without_sanlock:1}
%endif
%if 0%{?rhel} && ! 0%{?_aci_build:1}
    %ifarch %{qemu_kvm_arches}
        %define with_sanlock 0%{!?_without_sanlock:1}
    %endif
%endif

# Enable libssh2 transport for new enough distros
%if 0%{?fedora}
    %define with_libssh2 0%{!?_without_libssh2:1}
%endif

# Enable wireshark plugins for all distros shipping libvirt 1.2.2 or newer
%if 0%{?fedora}
    %define with_wireshark 0%{!?_without_wireshark:1}
    %define wireshark_plugindir %(pkg-config --variable plugindir wireshark)/epan
%endif

# Enable libssh transport for new enough distros
%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_libssh 0%{!?_without_libssh:1}
%endif

%define with_bash_completion  0%{!?_without_bash_completion:1}

# Use Python 3 when possible, Python 2 otherwise
%if 0%{?fedora}
    %define python python3
%else
    %if 0%{?rhel} > 7
        %define python python3-devel
    %else
        %define python python2
    %endif
%endif


%if %{with_qemu} || %{with_lxc}
# numad is used to manage the CPU and memory placement dynamically,
# it's not available on many non-x86 architectures.
    %ifnarch s390 s390x %{arm} riscv64
        %define with_numad    0%{!?_without_numad:1}
    %endif
%endif

# Force QEMU to run as non-root
%define qemu_user  qemu
%define qemu_group  qemu


# RHEL releases provide stable tool chains and so it is safe to turn
# compiler warning into errors without being worried about frequent
# changes in reported warnings
%if 0%{?rhel}
    %define enable_werror --enable-werror
%else
    %define enable_werror --disable-werror
%endif

%if 0%{?rhel} == 7
    %define tls_priority "NORMAL"
%else
    %define tls_priority "@LIBVIRT,SYSTEM"
%endif


Summary: Library providing a simple virtualization API
Name: libvirt
Version: 5.6.0
Release: 10%{?dist}.119.2
License: LGPLv2+
URL: https://libvirt.org/
ExclusiveArch: x86_64

%if %(echo %{version} | grep -q "\.0$"; echo $?) == 1
    %define mainturl stable_updates/
%endif
Source: libvirt-%{version}.tar.xz
Source1: symlinks

Patch1: libvirt-RHEL-Hack-around-changed-Broadwell-Haswell-CPUs.patch
Patch2: libvirt-RHEL-Add-rhel-machine-types-to-qemuDomainMachineNeedsFDC.patch
Patch3: libvirt-RHEL-Fix-virConnectGetMaxVcpus-output.patch
Patch4: libvirt-RHEL-qemu-Add-ability-to-set-sgio-values-for-hostdev.patch
Patch5: libvirt-RHEL-qemu-Add-check-for-unpriv-sgio-for-SCSI-generic-host-device.patch
Patch6: libvirt-RHEL-qemu-Alter-val-usage-in-qemuSetUnprivSGIO.patch
Patch7: libvirt-RHEL-qemu-Alter-qemuSetUnprivSGIO-hostdev-shareable-logic.patch
Patch8: libvirt-RHEL-qemu-Fix-logic-error-in-qemuSetUnprivSGIO.patch
Patch9: libvirt-RHEL-qemu-Fix-crash-trying-to-use-iSCSI-hostdev.patch
Patch10: libvirt-RHEL-Revert-configure-Remove-enable-test-coverage.patch
Patch11: libvirt-Revert-tpm-Check-TPM-XML-device-configuration-changes-after-edit.patch
Patch12: libvirt-qemu-Clarify-error-message-in-qemuMigrationSrcIsSafe.patch
Patch13: libvirt-qemu-Check-for-drop-cache-capability.patch
Patch14: libvirt-qemu-Allow-migration-with-disk-cache-on.patch
Patch15: libvirt-qemu-Pass-qemuCaps-to-qemuDomainDefCopy.patch
Patch16: libvirt-qemu-Pass-qemuCaps-to-qemuDomainDefFormatBufInternal.patch
Patch17: libvirt-qemu-Pass-qemuCaps-to-qemuDomainSaveImageOpen.patch
Patch18: libvirt-qemu-Pass-qemuCaps-to-qemuMigrationAnyPrepareDef.patch
Patch19: libvirt-qemu-Pass-correct-qemuCaps-to-virDomainDefParseString.patch
Patch20: libvirt-qemu-Pass-qemuCaps-to-qemuMigrationCookieXMLParse.patch
Patch21: libvirt-qemu-Pass-correct-qemuCaps-to-virDomainDefCopy.patch
Patch22: libvirt-qemu-Pass-correct-qemuCaps-to-virDomainDefPostParse.patch
Patch23: libvirt-qemu-Pass-correct-qemuCaps-to-virDomainDefParseNode.patch
Patch24: libvirt-qemu-Pass-correct-qemuCaps-to-virDomainDeviceDefPostParse.patch
Patch25: libvirt-qemu-Fix-crash-on-incoming-migration.patch
Patch26: libvirt-network-fix-crash-during-cleanup-from-failure-to-allocate-port.patch
Patch27: libvirt-network-replace-virSaveLastError-with-virErrorPreserveLast.patch
Patch28: libvirt-access-fix-incorrect-addition-to-virAccessPermNetwork.patch
Patch29: libvirt-util-allow-tap-based-guest-interfaces-to-have-MAC-address-prefix-0xFE.patch
Patch30: libvirt-vircgroupv2-fix-parsing-multiple-values-in-single-file.patch
Patch31: libvirt-vircgroupv2-fix-virCgroupV2GetCpuCfsQuota-for-max-value.patch
Patch32: libvirt-network-fix-ability-to-use-openvswitch-with-vlans.patch
Patch33: libvirt-remote-use-Wants-instead-of-Requires-for-libvirtd-sockets.patch
Patch34: libvirt-remote-move-timeout-arg-into-sysconf-file.patch
Patch35: libvirt-remote-forbid-the-listen-arg-when-systemd-socket-activation.patch
Patch36: libvirt-qemuBuildHotpluggableCPUProps-use-VIR_RETURN_PTR.patch
Patch37: libvirt-qemu-Extract-and-store-vCPU-properties-as-qemu-returned-them.patch
Patch38: libvirt-qemu-command-Use-all-vCPU-properties-when-creating-args-for-vCPU-hotplug.patch
Patch39: libvirt-qemu-alias-Generate-qomName-of-disk-with-useraliases.patch
Patch40: libvirt-src-security-Replace-bitwise-OR-with-logical-OR.patch
Patch41: libvirt-security_util-Use-more-VIR_AUTOFREE.patch
Patch42: libvirt-security_util-Document-virSecurityMoveRememberedLabel.patch
Patch43: libvirt-security-Don-t-increase-XATTRs-refcounter-on-failure.patch
Patch44: libvirt-util-Introduce-virhostuptime.patch
Patch45: libvirt-security_util-Remove-stale-XATTRs.patch
Patch46: libvirt-security_util-verify-xattrs-only-if-ref-is-present.patch
Patch47: libvirt-virSecuritySELinuxSetFileconImpl-Drop-optional-argument.patch
Patch48: libvirt-security_selinux-Drop-virSecuritySELinuxSetFileconOptional.patch
Patch49: libvirt-security_selinux-Drop-optional-from-_virSecuritySELinuxContextItem.patch
Patch50: libvirt-security_selinux-Drop-virSecuritySELinuxSetFileconHelper.patch
Patch51: libvirt-security_selinux-Play-nicely-with-network-FS-that-only-emulates-SELinux.patch
Patch52: libvirt-qemu_blockjob-Print-image-path-on-failed-security-metadata-move-too.patch
Patch53: libvirt-qemu_blockjob-Remove-secdriver-metadata-more-frequently.patch
Patch54: libvirt-vircgroupv2-fix-abort-in-VIR_AUTOFREE.patch
Patch55: libvirt-vircgroupv2-fix-setting-cpu.max-period.patch
Patch56: libvirt-remote-fix-registration-of-TLS-socket.patch
Patch57: libvirt-qemu_blockjob-Remove-secdriver-metadata-for-whole-backing-chain-on-job-completion.patch
Patch58: libvirt-qemu_driver-Fix-comment-of-qemuStateCleanup.patch
Patch59: libvirt-driver-Introduce-virDriverShouldAutostart.patch
Patch60: libvirt-lib-autostart-objects-exactly-once.patch
Patch61: libvirt-Revert-src-Document-autostart-for-session-demon.patch
Patch62: libvirt-security-Pass-migrated-to-virSecurityManagerSetAllLabel.patch
Patch63: libvirt-security-Rename-virSecurityManagerGetDriver-to-virSecurityManagerGetVirtDriver.patch
Patch64: libvirt-security-Introduce-virSecurityManagerGetDriver.patch
Patch65: libvirt-security_stack-Turn-list-of-nested-drivers-into-a-doubly-linked-list.patch
Patch66: libvirt-security_stack-Perform-rollback-if-one-of-stacked-drivers-fails.patch
Patch67: libvirt-util-new-function-virNetDevMacVLanIsMacvtap.patch
Patch68: libvirt-util-make-a-couple-virNetDevMacVlan-functions-public.patch
Patch69: libvirt-qemu-reorganize-qemuInterfaceEthernetConnect.patch
Patch70: libvirt-conf-use-virXMLFormatElement-for-interface-target.patch
Patch71: libvirt-conf-new-managed-attribute-for-target-dev-of-interface-type-ethernet.patch
Patch72: libvirt-qemu-support-unmanaged-target-tap-dev-for-interface-type-ethernet.patch
Patch73: libvirt-qemu-support-unmanaged-macvtap-devices-with-interface-type-ethernet.patch
Patch74: libvirt-qemu-avoid-double-reservation-of-PCI-address-for-interface-type-hostdev.patch
Patch75: libvirt-domain_conf-Make-virDomainDeviceFindSCSIController-accept-virDomainDeviceDriveAddress-struct.patch
Patch76: libvirt-domain_conf-Relax-SCSI-addr-used-check.patch
Patch77: libvirt-cpu_conf-Pass-policy-to-CPU-feature-filtering-callbacks.patch
Patch78: libvirt-qemuxml2-test-Add-tests-for-Icelake-Server-pconfig.patch
Patch79: libvirt-qemu-Drop-disabled-CPU-features-unknown-to-QEMU.patch
Patch80: libvirt-cputest-Add-data-for-Ice-Lake-Server-CPU.patch
Patch81: libvirt-cpu_map-Drop-pconfig-from-Icelake-Server-CPU-model.patch
Patch82: libvirt-qemu-Fix-NULL-ptr-dereference-caused-by-qemuDomainDefFormatBufInternal.patch
Patch83: libvirt-qemu-Separate-image-metadata-removal-into-a-function.patch
Patch84: libvirt-qemuProcessStop-Remove-image-metadata-for-running-mirror-jobs.patch
Patch85: libvirt-qemu-fix-EFI-nvram-removal-on-domain-undefine.patch
Patch86: libvirt-util-introduce-virPCIDeviceConfigOpenInternal.patch
Patch87: libvirt-util-Introduce-virPCIDeviceConfigOpenWrite.patch
Patch88: libvirt-util-introduce-readonly-attribute-to-virPCIDeviceConfigOpenInternal.patch
Patch89: libvirt-util-introduce-virPCIDeviceConfigOpenTry.patch
Patch90: libvirt-util-default-to-read-only-in-virPCIDeviceConfigOpen.patch
Patch91: libvirt-virpcimock-Mock-__open_2.patch
Patch92: libvirt-tests-virpcimock-Always-declare-__open_2.patch
Patch93: libvirt-qemu-Add-support-for-setting-string-migration-params.patch
Patch94: libvirt-Introduce-VIR_MIGRATE_PARAM_TLS_DESTINATION-migration-param.patch
Patch95: libvirt-qemu-Implement-VIR_MIGRATE_PARAM_TLS_DESTINATION.patch
Patch96: libvirt-virsh-Add-tls-destination-option-for-migrate-command.patch

# Vz patches
Patch10000: 10000-src-adopt-to-VIR_DRV_SUPPORTS_FEATURE-return-1.patch
Patch10001: 10001-libxl-adopt-to-VIR_DRV_SUPPORTS_FEATURE-return-1.patch
Patch10002: 10002-qemu-adopt-to-VIR_DRV_SUPPORTS_FEATURE-return-1.patch
Patch10003: 10003-src-don-t-hide-error-in-VIR_DRV_SUPPORTS_FEATURE.patch
Patch10004: 10004-qemu-build-fix-for-910b94df.patch
Patch10005: 10005-src-fix-resource-leak-introduced-in-d4439a6b8.patch
Patch10006: 10006-vz-fixes-after-renaming-Parallels-to-Virtuozzo-in-s.patch
Patch10007: 10007-vz-build-fix-for-passing-qemuCaps-to-virDomainDevic.patch
Patch10008: 10008-vz-build-fix-for-passing-qemuCaps-to-virDomainDefPa.patch
Patch10009: 10009-lib-add-virDomainGetGuestInfo.patch
Patch10010: 10010-remote-implement-virDomainGetGuestInfo.patch
Patch10011: 10011-qemu-add-helper-for-getting-guest-users.patch
Patch10012: 10012-qemu-add-helper-function-for-querying-OS-info.patch
Patch10013: 10013-qemu-add-helper-for-querying-timezone-info.patch
Patch10014: 10014-qemu-add-support-for-new-fields-in-FSInfo.patch
Patch10015: 10015-qemu-add-helper-for-getting-full-FSInfo.patch
Patch10016: 10016-qemu-Implement-virDomainGetGuestInfo.patch
Patch10017: 10017-backport-fixup-remote-implement-virDomainGetGuestIn.patch
Patch10018: 10018-qemu-guestinfo-handle-unsupported-agent-commands.patch
Patch10019: 10019-virsh-add-guestinfo-command.patch
Patch10020: 10020-RHEL-screenshot-Implement-multiple-screen-support.patch
Patch10021: 10021-make-check-fix-when-lxc-is-turned-off.patch
Patch10022: 10022-cfg.mk-disable-sc_copyright_check.patch
Patch10023: 10023-RHEL-qemu-support-relative-backing-for-RHEL-7.0.z-q.patch
Patch10024: 10024-RHEL-qemu-Support-vhost-user-multiqueue-with-QEMU-2.patch
Patch10025: 10025-RHEL-Define-ETHTOOL_-GS-COALESCE-when-building-on-o.patch
Patch10026: 10026-qemuhotplugtest-Test-guestfwd-attach-and-detach.patch
Patch10027: 10027-iohelper-truncate-large-chunks-on-write-PSBM-70840.patch
Patch10028: 10028-Added-new-flag-VIR_DOMAIN_CREATE_USER.patch
Patch10029: 10029-conf-tune-connection-parameters-for-Virtuozzo-PSBM-.patch
Patch10030: 10030-Set-LimitCORE-infinity-in-libvirtd.service.patch
Patch10031: 10031-conf-add-format-attribute-to-domain-os-nvram-elemen.patch
Patch10032: 10032-qemu-don-t-pause-vm-when-creating-internal-snapshot.patch
Patch10033: 10033-vz-use-etc-machine-id-as-host-uuid.patch
Patch10034: 10034-qemu-log-log-monitor-events-by-default.patch
Patch10035: 10035-relax-network-adapter-config-checking-bug-PSBM-5459.patch
Patch10036: 10036-qemu-v2-fix-reboot-scenario-bugs-PSBM-41956-PSBM-54.patch
Patch10037: 10037-vz-set-virtio-as-default-network-model.patch
Patch10038: 10038-qemu-fix-crash-on-getting-block-stats-for-empty-cdr.patch
Patch10039: 10039-vz-rework-the-way-we-get-perfomance-counters.patch
Patch10040: 10040-vz-use-cached-statistics-for-a-predefined-period.patch
Patch10041: 10041-vz-don-t-subscribe-to-perfomance-counters.patch
Patch10042: 10042-vz-cleanup-delete-unused-constant-definition.patch
Patch10043: 10043-vz-don-t-create-driver-object-during-daemon-initial.patch
Patch10044: 10044-vireventpoll-isolate-common-code.patch
Patch10045: 10045-vireventpoll-implimentation-using-epoll.patch
Patch10046: 10046-conf-qemu-add-hv-scsi-model-to-scsi-controllers.patch
Patch10047: 10047-vz-add-domain-name-info-in-error-message.patch
Patch10048: 10048-qemu-simplify-graphics-port-releasing.patch
Patch10049: 10049-upgrade-support-local-p2p-migration.patch
Patch10050: 10050-object-add-shared-lock-option-to-lockable.patch
Patch10051: 10051-upgrade-initial-implementation.patch
Patch10052: 10052-upgrade-don-t-show-events-from-not-face-process.patch
Patch10053: 10053-upgrade-start-target-domain-with-source-id.patch
Patch10054: 10054-cgroup-use-id-generation-for-machine-cgroup-name-if.patch
Patch10055: 10055-upgrade-fix-id-clashes-for-domain-private-paths-etc.patch
Patch10056: 10056-conf-accept-path-in-virDomainSaveXML.patch
Patch10057: 10057-upgrade-store-generation-in-status-file.patch
Patch10058: 10058-dom-list-refactor-reuse-code-in-find-functions.patch
Patch10059: 10059-upgrade-return-face-domain-from-domlist.patch
Patch10060: 10060-migration-support-release-ram.patch
Patch10061: 10061-migration-add-postcopy-start-to-start-postcopy-imme.patch
Patch10062: 10062-upgrade-virtlogd-handle-output-for-one-path-from-2-.patch
Patch10063: 10063-upgrade-pass-live-config-to-target.patch
Patch10064: 10064-upgrade-don-t-generate-seclabel-again-on-upgrade.patch
Patch10065: 10065-upgrade-handle-auto-generated-char-dev-unix-paths.patch
Patch10066: 10066-upgrade-vnc-do-not-regenerate-graphics-for-target-p.patch
Patch10067: 10067-upgrade-vnc-factor-out-building-vnc-opts.patch
Patch10068: 10068-upgrade-vnc-make-vnc-upgrade-possible.patch
Patch10069: 10069-upgrade-vnc-keep-vnc-state-across-upgrade.patch
Patch10070: 10070-upgrade-tap-use-multiqueue-to-make-upgrade-possible.patch
Patch10071: 10071-upgrade-tap-don-t-regenerate-name-on-upgrade.patch
Patch10072: 10072-upgrade-network-iface-keep-actual-net.patch
Patch10073: 10073-upgrade-snapshots-support-snapshots.patch
Patch10074: 10074-upgrade-don-t-assign-dev-aliases-on-upgrade.patch
Patch10075: 10075-qemu-drop-acquiring-job-condition-on-removing-vm-fr.patch
Patch10076: 10076-qemu-fix-one-more-race-on-undefining-and-create.patch
Patch10077: 10077-upgrade-restart-pending-jobs-after-upgrade.patch
Patch10078: 10078-upgrade-fix-domain-lookup-in-old-face-removing-phas.patch
Patch10079: 10079-upgrade-make-correct-reconnection-of-upgrade.patch
Patch10080: 10080-upgrade-set-used-ports-only-for-face.patch
Patch10081: 10081-upgrade-support-for-server-backends-for-serial-char.patch
Patch10082: 10082-qemu.conf-set-upper-limit-for-vnc-spice-ports-to-69.patch
Patch10083: 10083-upgrade-don-t-reject-upgrade-if-hostname-is-localho.patch
Patch10084: 10084-qemu-wait-indefinetly-when-acquiring-job-condition-.patch
Patch10085: 10085-upgrade-close-agent-channel-befor-postcopy-with-rel.patch
Patch10086: 10086-upgrade-use-unique-name-for-pidfiles-across-upgrade.patch
Patch10087: 10087-qemu-remove-time-limit-on-waiting-qemu-disappearenc.patch
Patch10088: 10088-qemu-add-vmbus-bridge-device-if-hv-scsi-present.patch
Patch10089: 10089-qemu-agent-stop-io-loop-effectively-on-eof-or-error.patch
Patch10090: 10090-upgrade-fix-crash-if-vm-newdef-is-empty.patch
Patch10091: 10091-libvirtd-tune-OOMScoreAdjust.patch
Patch10092: 10092-keycodes-fix-for-make-dist.patch
Patch10093: 10093-qemu-revert-fb2cd32c.patch
Patch10094: 10094-daemon-finish-threads-on-close.patch
Patch10095: 10095-qemu-monitor-check-monitor-not-closed-on-send.patch
Patch10096: 10096-qemu-implement-state-driver-shutdown-function.patch
Patch10097: 10097-vz-remove-domain-uuid-check-on-migration-PSBM-43767.patch
Patch10098: 10098-qemu-support-hv-net-interface-models.patch
Patch10099: 10099-nwfilter-fix-deadlock-on-firewalld-restart-reload.patch
Patch10100: 10100-vz-allow-to-start-vz-driver-without-host-cache-info.patch
Patch10101: 10101-qemu-snapshot-revert-upstream-9e2465834-PSBM-76749.patch
Patch10102: 10102-api-qemu-add-block-pull-compress-option-PSBM-73618.patch
Patch10103: 10103-qemu-reduce-nesting-in-qemuDomainSnapshotForEachQco.patch
Patch10104: 10104-qemu-include-nvram-into-offline-snapshots.patch
Patch10105: 10105-qemu-fail-making-internal-snapshots-with-non-qcow2-.patch
Patch10106: 10106-util-virFDStreamConnectUNIX-add-missing-error-repor.patch
Patch10107: 10107-util-add-30s-connection-timeout-to-virFDStreamConne.patch
Patch10108: 10108-qemu-use-job-to-make-domain-responsive-on-qemuDomai.patch
Patch10109: 10109-qemu-wait-qemu-death-indefinetely-on-domain-stop-PS.patch
Patch10110: 10110-pull-api-add-API-for-pull-external-backups.patch
Patch10111: 10111-pull-api-add-driver-based-implementation.patch
Patch10112: 10112-pull-remote-add-pull-backup-API-implementation.patch
Patch10113: 10113-pull-qemu-monitor-add-commands-for-backup.patch
Patch10114: 10114-pull-conf-add-block-snapshot-format-parse.patch
Patch10115: 10115-pull-virsh-add-block-snapshot-create-delete.patch
Patch10116: 10116-qemu-store-guest-visible-disk-size-from-qemu-monito.patch
Patch10117: 10117-qemu-add-option-to-handle-inactive-blockjobs-to-can.patch
Patch10118: 10118-util-hash-add-misc-functions.patch
Patch10119: 10119-pull-conf-add-block-snaphots-to-status-file.patch
Patch10120: 10120-pull-qemu-block-snapshots-basic-implementation.patch
Patch10121: 10121-pull-qemu-support-disks-quiesce.patch
Patch10122: 10122-pull-qemu-add-block-snapshots-listing.patch
Patch10123: 10123-pull-qemu-support-block-snapshot-dumpxml.patch
Patch10124: 10124-pull-qemu-monitor-add-cmd-to-delete-nbd-export.patch
Patch10125: 10125-pull-conf-add-export-conf-def-parsing.patch
Patch10126: 10126-pull-qemu-implement-export-start-stop.patch
Patch10127: 10127-pull-qemu-don-t-delete-snapshot-while-disks-are-exp.patch
Patch10128: 10128-util-hash-remove-const-from-value-in-kv-pair-type.patch
Patch10129: 10129-pull-add-autodelete-option-for-creating-block-snaps.patch
Patch10130: 10130-pull-stop-exporting-snapshot-on-snapshot-autodelete.patch
Patch10131: 10131-pull-add-backcompat-capabilities.patch
Patch10132: 10132-pull-qemu-monitor-add-bitmap-commands.patch
Patch10133: 10133-pull-pull-add-dirty-bitmap-on-creating-snapshot.patch
Patch10134: 10134-pull-add-command-to-remove-checkpoint.patch
Patch10135: 10135-pull-qemu-remove-checkpoint-on-autodelete.patch
Patch10136: 10136-pull-qemu-load-bitmaps-on-domain-start.patch
Patch10137: 10137-pull-qemu-monitor-add-command-to-export-bitmap.patch
Patch10138: 10138-pull-export-bitmap.patch
Patch10139: 10139-pull-migrate-checkpoints.patch
Patch10140: 10140-pull-qemu-validate-snapshot-name.patch
Patch10141: 10141-pull-qemu-add-exportable-paused-start.patch
Patch10142: 10142-pull-add-TLS-to-block-export.patch
Patch10143: 10143-pull-add-relaxng.patch
Patch10144: 10144-pull-add-autoport-on-export.patch
Patch10145: 10145-qemu-add-unmap-stats-to-all-domain-stats.patch
Patch10146: 10146-api-qemu-add-latency-histogram.patch
Patch10147: 10147-hubapi-remote-implement-listing-domains.patch
Patch10148: 10148-hubapi-remote-support-domain-API-calls.patch
Patch10149: 10149-hubapi-remote-support-domain-lookup-functions.patch
Patch10150: 10150-hubapi-remote-support-create-define-xml-API.patch
Patch10151: 10151-hubapi-remote-support-domain-events.patch
Patch10152: 10152-hubapi-remote-support-virConnectGetCapabilities.patch
Patch10153: 10153-hubapi-remote-return-vz-connection-type-if-vz-is-in.patch
Patch10154: 10154-hubapi-remote-return-vz-connection-type-if-vzct-is-.patch
Patch10155: 10155-hubapi-find-appropriate-connection-for-domain-xml-V.patch
Patch10156: 10156-vz-add-option-to-resize-filesystems-thur-virDomainB.patch
Patch10157: 10157-vz-support-virDomainGetBlockInfo-in-driver.patch
Patch10158: 10158-api-qemu-introduce-hv-vss-freeze-thaw.patch
Patch10159: 10159-pull-disable-risky-cases-with-RW-NBD-exports.patch
Patch10160: 10160-qemu-fix-attach-detach-char-devices-to-use-guest-de.patch
Patch10161: 10161-conf-remove-none-console-target-type-check-from-vir.patch
Patch10162: 10162-conf-remove-none-console-target-type-check-from-vir.patch
Patch10163: 10163-conf-remove-none-console-target-type-check-from-vir.patch
Patch10164: 10164-qemu-update-compat-console-on-attach-first-serial-d.patch
Patch10165: 10165-qemu-support-updating-backend-of-serial-device.patch
Patch10166: 10166-pull-qemu-add-option-to-export-last-checkpoint.patch
Patch10167: 10167-portallocator-print-warn-on-releasing-not-used-port.patch
Patch10168: 10168-rpc-netdaemon-remove-watch-before-closing-fd.patch
Patch10169: 10169-netlink-remove-watch-before-closing-fd.patch
Patch10170: 10170-qemu-monitor-set-error-flag-even-in-OOM-conditions.patch
Patch10171: 10171-utils-export-virCopyError.patch
Patch10172: 10172-qemu-fix-domain-object-wait-to-handle-monitor-error.patch
Patch10173: 10173-qemu-fix-races-in-beingDestroyed-usage.patch
Patch10174: 10174-lib-provide-error-message-in-new-blockjob-event.patch
Patch10175: 10175-qemu-agent-incapsulate-vm-reference-management.patch
Patch10176: 10176-qemu-agent-remove-unconvinient-destroy-callback.patch
Patch10177: 10177-qemu-agent-factor-out-code-to-open-channel.patch
Patch10178: 10178-qemu-agent-remove-useless-signalling.patch
Patch10179: 10179-qemu-agent-do-not-take-moninor-ref-in-IO-callback.patch
Patch10180: 10180-qemu-agent-remove-qemuAgentNotifyCloseLocked.patch
Patch10181: 10181-qemu-agent-don-t-retry-first-sync-message-if-monito.patch
Patch10182: 10182-qemu-agent-better-error-message-for-disconnected-ag.patch
Patch10183: 10183-qemu-agent-give-same-message-on-monitor-errors.patch
Patch10184: 10184-qemu-agent-move-monitor-error-check-to-better-place.patch
Patch10185: 10185-qemu-agent-reduce-nesting-in-qemuAgentCommand.patch
Patch10186: 10186-qemu-domain-add-name-arg-to-qemuFindAgentConfig.patch
Patch10187: 10187-qemu-agent-prepare-serial-event-handler-for-aux-cha.patch
Patch10188: 10188-rpc-support-multiple-streams-on-client-side.patch
Patch10189: 10189-rpc-fix-to-support-multiple-streams.patch
Patch10190: 10190-rpc-close-stream-on-receive-errors.patch
Patch10191: 10191-rpc-pass-original-stream-recv-send-error.patch
Patch10192: 10192-qemu-add-exec-with-true-streams.patch
Patch10193: 10193-tools-stop-event-loop-before-closing-connection.patch
Patch10194: 10194-virsh-don-t-print-n-footer-for-x-exec.patch
Patch10195: 10195-pull-fix-visible-NULL-entries-in-block-snapshot-has.patch
Patch10196: 10196-nwfilter-use-vfork-to-fasten-spawn-of-ip-eb-tables-.patch
Patch10197: 10197-pci-more-verbose-error-in-virPCIGetDeviceAddressFro.patch
Patch10198: 10198-daemon-purge-logs-for-domains-removed-more-than-mon.patch
Patch10199: 10199-remote-fix-SIGSEGV-on-closing-client-connection.patch
Patch10200: 10200-pull-don-t-destroy-vm-if-it-has-block-snapshots-or-.patch
Patch10201: 10201-tools-make-building-virt-login-shell-truly-conditio.patch
Patch10202: 10202-qemu-destroy-domain-on-monitor-EOF-anyway.patch
Patch10203: 10203-pull-log-merge-rename-bitmap-operations.patch
Patch10204: 10204-api-qemu-add-move-nvram-API.patch
Patch10205: 10205-qemu-add-option-to-update-disk-copy_on_read-live-VS.patch
Patch10206: 10206-qemu-add-qcow2-cache-size-policy.patch
Patch10207: 10207-tools-move-virshGetEscapeChar-to-utils.patch
Patch10208: 10208-syms-add-virStringListCopy-to-private-syms.patch
Patch10209: 10209-virsh-support-in-err-out-as-regular-files.patch
Patch10210: 10210-qemu-support-interactive-exec-PSBM-91739.patch
Patch10211: 10211-qemu-remove-sanity-check-in-qemuMonitorJSONDiskName.patch
Patch10212: 10212-exec-provide-tty-params-on-exec-when-possible.patch
Patch10213: 10213-rpc-allow-comments-in-prototol-description.patch
Patch10214: 10214-remote-leave-stub-comment-for-16-virDomainGetOSInfo.patch
Patch10215: 10215-libvirt-add-new-virDomainCommandXSetParams-API.patch
Patch10216: 10216-exec-handle-client-window-size-change-when-interact.patch
Patch10217: 10217-qemu-add-hci-value-128MiB-to-qcow2-disk-cache-polic.patch
Patch10218: 10218-upgrade-handle-firewall-rules-PSBM-90137.patch
Patch10219: 10219-qemu-caps-invalidate-kvm-capable-qemu-binaries-on-e.patch
Patch10220: 10220-cgroup-blacklist-criu-temporary-mounts-PSBM-90471.patch
Patch10221: 10221-qemu-imply-qcow2-format-for-backing-store-if-not-se.patch
Patch10222: 10222-rpc-client-fix-race-on-stream-error-and-stream-crea.patch
Patch10223: 10223-exec-virsh-support-redirection-to-special-chardevs-.patch
Patch10224: 10224-exec-restore-std-streams-flags-on-become-foreground.patch
Patch10225: 10225-rpc-client-stream-notify-streams-of-closing-connect.patch
Patch10226: 10226-Revert-log-actually-do-substring-matches-with-fnmat.patch
Patch10227: 10227-pull-clean-autodelete-snapshots-on-daemon-restart.patch
Patch10228: 10228-qemu-agent-add-code-2-when-guest-exec-pid-not-found.patch
Patch10229: 10229-qemu-don-t-wait-job-in-cleanup-thread.patch
Patch10230: 10230-exec-kill-orphans-on-client-disconnect-PSBM-91329-V.patch
Patch10231: 10231-exec-kill-orphans-on-migration-destination-PSBM-913.patch
Patch10232: 10232-qemu-seccomp-don-t-turn-it-on-by-default-PSBM-93004.patch
Patch10233: 10233-qemu-ignore-disabled-arch-facilities-in-configs-PSB.patch
Patch10234: 10234-qemu-support-explicit-disk-backing-in-input-VSTOR-2.patch
Patch10235: 10235-logging-remove-watch-before-closing-fd-in-virLogHan.patch
Patch10236: 10236-qemu-don-t-log-error-for-disk-sources-not-supportin.patch
Patch10237: 10237-qemu-don-t-log-error-when-monitor-EOF-is-expected-P.patch
Patch10238: 10238-qemu-agent-don-t-log-error-when-monitor-EOF-is-expe.patch
Patch10239: 10239-qemu-agent-aux-don-t-log-error-when-monitor-EOF-is-.patch
Patch10240: 10240-qemu-qemuBlockDiskDetectNodes-get-name-if-one-is-kn.patch
Patch10241: 10241-backup-copy-bitmaps-to-top-image-on-snapshot.patch
Patch10242: 10242-virDomainObjListAddObjLocked-Don-t-expect-vm-def-to.patch
Patch10243: 10243-virDomainObjListAddLocked-Set-vm-def-only-in-succes.patch
Patch10244: 10244-virDomainObjListAdd-Leave-def-assigning-as-an-exerc.patch
Patch10245: 10245-virDomainObjListAdd-Remove-unused-flag.patch
Patch10246: 10246-qemu-Grab-modify-job-for-changing-domain-XML.patch
Patch10247: 10247-qemu_domain-Allow-qemuDomainObjListAdd-to-keep-job-.patch
Patch10248: 10248-qemu-release-job-on-cleanup-path.patch
Patch10249: 10249-qemu-snapshot-revert-reuse-common-cleanup-code.patch
Patch10250: 10250-qemu-snapshot-save-restore-inactive-persistent-conf.patch
Patch10251: 10251-schema-snapshot-add-persistent-domain-config.patch
Patch10252: 10252-conf-snapshot-dump-parse-persistent-domain-config.patch
Patch10253: 10253-docs-add-persistent-config-to-snapshot-xml-descript.patch
Patch10254: 10254-conf-snapshot-check-domain-name-on-redefine.patch
Patch10255: 10255-conf-snapshot-support-persistent-config-on-redefine.patch
Patch10256: 10256-qemu-add-option-to-close-cdrom-tray-PSBM-95870.patch
Patch10257: 10257-conf-remove-features-unknown-to-qemu-related-to-PSB.patch
Patch10258: 10258-agent-increase-default-timeout-from-5s-to-30s-PSBM-.patch
Patch10259: 10259-qemu-introduce-qemuDomainChrSerialTargetModel.patch
Patch10260: 10260-conf-add-debugcon-chardev-guest-interface.patch
Patch10261: 10261-qemu-make-irq-optional-when-formatting-the-ISA-addr.patch
Patch10262: 10262-qemu-implement-debugcon-chardev.patch
Patch10263: 10263-qemu-autoadd-iobase-to-debugcon-chardev.patch
Patch10264: 10264-api-qemu-add-pause-resume-for-blockjobs.patch
Patch10265: 10265-qemu-agent-log-total-tx-rx-for-streams.patch
Patch10266: 10266-debug-print-thr-a-a-bt-in-log-when-taking-some-mute.patch
Patch10267: 10267-qemu-monitor-throttle-logging-BLOCK_IO_ERROR-events.patch
Patch10268: 10268-qemu-ignore-delayed-EOF-events-from-previous-VM-inc.patch
Patch10269: 10269-qemu-don-t-fail-pausing-block-job-if-it-is-missing-.patch
Patch10270: 10270-qemu-migration-implement-shared-workaround-VSTOR-11.patch
Patch10271: 10271-conf-handle-empty-string-in-interface-target-name-P.patch
Patch10272: 10272-conf-add-replug-option-for-usb-hostdev.patch
Patch10273: 10273-qemu-track-hostdev-delete-intention.patch
Patch10274: 10274-qemu-support-host-usb-device-unplug.patch
Patch10275: 10275-qemu-support-usb-hostdev-plugging-back.patch
Patch10276: 10276-qemu-handle-host-usb-device-add-del-udev-events.patch
Patch10277: 10277-qemu-handle-libvirtd-restart-after-host-usb-device-.patch
Patch10278: 10278-qemu-handle-race-on-device-deletion-and-usb-host-de.patch
Patch10279: 10279-qemu-hotplug-update-device-list-on-device-deleted-e.patch
Patch10280: 10280-qemu-handle-host-usb-device-plug-unplug-when-libvir.patch
Patch10281: 10281-qemu-don-t-mess-with-non-mandatory-hostdevs-on-reat.patch
Patch10282: 10282-qemu-handle-detaching-of-unplugged-hostdev.patch
Patch10283: 10283-conf-parse-hostdev-missing-flag.patch
Patch10284: 10284-backup-don-t-keep-bitmaps-in-base-image-on-snapshot.patch
Patch10285: 10285-backup-copy-bitmaps-down-on-active-block-commit-VST.patch
Patch10286: 10286-qemu-support-new-qemu-without-nbd-server-add-bitmap.patch
Patch10287: 10287-fix-for-virDomainObjListAdd-Leave-def-assigning-as-.patch
Patch10288: 10288-qemu-handle-storage-virtlogd-hanging-VSTOR-27947.patch
Patch10289: 10289-log-in-case-of-OOM-at-least-try-to-log-something-on.patch
Patch10290: 10290-qemu-add-option-to-process-offloaded-legacy-blockjo.patch
Patch10291: 10291-qemu-reconnect-precreate-legacy-blockjobs.patch
Patch10292: 10292-qemu-remove-extra-block-job-finalize-on-reconnect.patch
Patch10293: 10293-qemu-remove-stale-cleanup-in-qemuProcessRefreshLega.patch
Patch10294: 10294-qemu-add-note-for-outdated-legacy-block-job-events.patch
Patch10295: 10295-qemu-use-autoptr-in-qemuProcessRefreshLegacyBlockjo.patch
Patch10296: 10296-qemu-refresh-backing-chain-after-block-job-reconnec.patch
Patch10297: 10297-qemu-move-code-that-depends-on-backing-chain-approp.patch
Patch10298: 10298-qemu-fix-race-on-legacy-block-completion-and-querin.patch
Patch10299: 10299-qemu-sync-backing-chain-update-and-completed-blockj.patch
Patch10300: 10300-qemu-support-preserve-option-for-on_poweroff.patch
Patch10301: 10301-qemu-add-reconnect-params-for-nbd-network-disks-VST.patch
Patch10302: 10302-netdaemon-fix-deadlock-on-stopping-libvirtd-when-VM.patch
Patch10303: 10303-qemu-kill-partially-started-domain-immediately-on-r.patch
Patch10304: 10304-qemu-migration-log-keep-alive-message-during-migrat.patch
Patch10305: 10305-conf-refactor-virDomainBlockIoTuneInfoHas.patch
Patch10306: 10306-conf-expand-iotune-params-if-only-group-name-is-giv.patch
Patch10307: 10307-qemu-check-iotune-params-same-for-all-disk-in-group.patch
Patch10308: 10308-qemu-fix-using-defaults-when-setting-persistent-iot.patch
Patch10309: 10309-qemu-propagate-iotune-settings-to-all-disks-in-the-.patch
Patch10310: 10310-qemu-get-defaults-from-iotune-group-we-move-disk-in.patch
Patch10311: 10311-qemu-when-leaving-iotune-group-update-xml-properly-.patch
Patch10312: 10312-qemu-disable-snapshot-explicitly-when-block-snapsho.patch
Patch10313: 10313-make-add-flags-to-configure-sanitizer.patch
Patch10314: 10314-asan-workaround-sanitizer-issues-with-clone-2.patch
Patch10315: 10315-asan-configure-to-coredump-on-signals.patch
Patch10316: 10316-hubapi-workaround-virURIFormat-degradation-in-vz8.patch
Patch10317: 10317-qemu-hide-details-of-fake-reboot.patch
Patch10318: 10318-qemu-adopt-nodename-detection-to-backup-filter-node.patch
Patch10319: 10319-qemu-adopt-latency-impl-to-new-qemu-PSBM-97535.patch
Patch10320: 10320-qemu-turn-on-keep-alive-for-nbd-disk-migration-PSBM.patch
Patch10321: 10321-OOM-add-abort-to-functions-we-don-t-check-return-va.patch
Patch10322: 10322-docker-First-implementation-of-libvirt-Docker-drive.patch
Patch10323: 10323-conf-add-more-options-to-save-config-filename.patch
Patch10324: 10324-conf-allow-NULL-callback-in-virDomainObjListRename.patch
Patch10325: 10325-conf-support-extra-id-in-domain-list.patch
Patch10326: 10326-vzct-2-add-basic-structure-and-listing.patch
Patch10327: 10327-virsystemd-workaround-race-on-systemd-machined-idle.patch
Patch10328: 10328-qemu-agent-sync-once-if-qemu-has-serial-port-event-.patch
Patch10329: 10329-qemu-remove-redundant-needReply-argument-of-qemuAge.patch
Patch10330: 10330-rpc-add-timeout-on-connection-VSTOR-32643.patch
Patch10331: 10331-util-fix-byte-order-of-port-in-virSocketAddrResolve.patch
Patch10332: 10332-docker-add-lookup-API-impl-PSBM-102978.patch
Patch10333: 10333-docker-implementation-control-methods-for-domain-PS.patch
Patch10334: 10334-docker-extend-types-of-HTTP-request-PSBM-103311.patch
Patch10335: 10335-docker-correct-POST-HTTP-request-PSBM-103381.patch
Patch10336: 10336-docker-add-special-label-with-libvirt-uuid-in-conta.patch
Patch10337: 10337-qemu-Check-for-job-being-set-when-getting-iothread-.patch
Patch10338: 10338-conf-support-light-vcpus-and-unlimitied-number.patch
Patch10339: 10339-vzct-2-support-dumpxml.patch
Patch10340: 10340-docker-add-template-source-type-PSBM-103381.patch
Patch10341: 10341-vzct-2-implement-define.patch
Patch10342: 10342-vzct-2-implement-start-stop.patch
Patch10343: 10343-docker-implementation-of-XML-methods-for-libvirt-dr.patch
Patch10344: 10344-docker-cleanup-code-for-hypervisor-driver-PSBM-1040.patch
Patch10345: 10345-FIXUP-docker-look-up-by-hash-id-with-leading-zero-P.patch
Patch10346: 10346-docker-implementation-of-stats-methods-PSBM-104003.patch
Patch10347: 10347-FIXUP-docker-look-up-by-name-PSBM-104003.patch
Patch10348: 10348-docker-cleanup-code-PSBM-104003.patch
Patch10349: 10349-vzct-2-support-vnc-PSBM-104068.patch
Patch10350: 10350-vzct-2-support-cloud-init-cdrom-PSBM-104067.patch
Patch10351: 10351-vzct-2-add-vzctDomainHasManagedSaveImage-stub.patch
Patch10352: 10352-vzct-2-support-iolimits-PSBM-104069.patch
Patch10353: 10353-vzct-2-add-misc-API.patch
Patch10354: 10354-docker-implementation-of-connectGetAllDomainStats-m.patch
Patch10355: 10355-docker-cleanup-code-PSBM-104537.patch
Patch10356: 10356-docker-changing-of-type-of-some-objects-in-XML-mode.patch
Patch10357: 10357-vzct-2-make-disk-names-stable-PSBM-104105.patch
Patch10358: 10358-FIXUP-docker-simplification-of-existing-code-PSBM-1.patch
Patch10359: 10359-vzct-2-support-stats-API-PSBM-104070.patch
Patch10360: 10360-docker-implementation-of-network-driver-PSBM-104537.patch
Patch10361: 10361-qemu-bring-back-capabilities-from-update-14-PSBM-10.patch
Patch10362: 10362-docker-Added-support-for-mounting-volumes-or-FSs-PS.patch
Patch10363: 10363-qemu-use-explicit-backing-mode-only-if-there-is-nbd.patch
Patch10364: 10364-Support-hooks-placed-in-several-files-in-libvirt-PS.patch
Patch10365: 10365-qemu-optimize-qemuOpenFileAs-for-reads-VSTOR-34701.patch
Patch10366: 10366-Add-qemu-hook-suitable-to-handle-device-hotplug-hot.patch
Patch10367: 10367-util-add-virFileRead-function.patch
Patch10368: 10368-vzct-2-support-snapshots.patch
Patch10369: 10369-docker-Offline-migration-of-windows-container-PSBM-.patch
Patch10370: 10370-FIXUP-Changes-for-using-define-instead-of-several-i.patch
Patch10371: 10371-docker-Added-rename-method-for-driver.patch
Patch10372: 10372-xml-add-venet0-network-interface-type.patch
Patch10373: 10373-vzct-2-support-venet0-network-interface-PSBM-105548.patch
Patch10374: 10374-qemu-ignore-allow_disk_format_probing-PSBM-105558.patch
Patch10375: 10375-upgrade-don-t-mess-with-security-labels-PSBM-105674.patch
Patch10376: 10376-qemu-pass-rememberOwner-during-update-PSBM-105674.patch
Patch10377: 10377-docs-fix-typo-in-virsh.rst-for-balloon.major_fault.patch
Patch10378: 10378-include-clarify-docs-for-hugetlb-in-virDomainMemory.patch
Patch10379: 10379-docs-add-missing-balloon-stats-docs-in-domstats.patch
Patch10380: 10380-docs-add-missing-iothread-stats-docs-in-domstats.patch
Patch10381: 10381-src-add-missing-balloon-stats-docs.patch
Patch10382: 10382-docker-Add-some-configuration-features-for-driver-P.patch
Patch10383: 10383-network-make-it-safe-to-call-networkSetupPrivateCha.patch
Patch10384: 10384-network-force-re-creation-of-iptables-private-chain.patch
Patch10385: 10385-qemu-auto-load-vhost-vsock-module-PSBM-106171.patch
Patch10386: 10386-qemu-make-latency-work-with-legacy-interface-PSBM-1.patch
Patch10387: 10387-virsh-handle-snapshots-with-domain-state-unknown.patch
Patch10388: 10388-conf-moment-remember-if-name-is-autogenerated.patch
Patch10389: 10389-util-add-means-to-detect-vstorage-filesystem.patch
Patch10390: 10390-security-exclude-vstorage-from-labelling-PSBM-10598.patch
Patch10391: 10391-vzct-2-don-t-try-virDomainLookupByID.patch
Patch10392: 10392-qemu-caps-use-more-precise-condition-when-to-use-CA.patch
Patch10393: 10393-doc-adopt-README.md-for-Virtuozzo.patch
Patch10394: 10394-docker-first-implementation-of-winrs-transport-to-w.patch
Patch10395: 10395-docker-basic-implementation-of-storage-driver-for-W.patch
Patch10396: 10396-Add-new-type-of-storage-pool-for-Windows-Storage-Sp.patch
Patch10397: 10397-docker-full-implementation-of-storage-driver-for-Wi.patch
Patch10398: 10398-docker-add-method-for-cloning-volume-PSBM-106275.patch
Patch10399: 10399-docker-using-common-CA-certificate-for-docker-and-w.patch
Patch10400: 10400-docker-reuse-winrm-coonnection-PSBM-106278.patch
Patch10401: 10401-docker-forbid-access-to-primordial-storage-pools-PS.patch
Patch10402: 10402-virsh-don-t-shout-if-virDomainGetJobInfo-is-not-sup.patch
Patch10403: 10403-vzct-2-save-disks-uuid-in-config-status-files.patch
Patch10404: 10404-vzct-2-intoduce-migration.patch
Patch10405: 10405-conf-add-auto-mininal-memory-guarantee-mode.patch
Patch10406: 10406-vzct-2-support-memory-guarantees-PSBM-106482.patch
Patch10407: 10407-docker-unification-of-source-code-PSBM-106989.patch
Patch10408: 10408-docker-common-auth-certificate-for-docker-and-winrm.patch
Patch10409: 10409-FIXUP-docker-use-more-correct-powershell-expression.patch
Patch10410: 10410-vzct-2-mark-supported-xml-parts-in-domain-snapshot-.patch
Patch10411: 10411-FIXUP-docker-use-correct-timeouts-and-subnet-value-.patch
Patch10412: 10412-docker-add-support-for-static-IP-address-PSBM-10677.patch
Patch10413: 10413-qemu-add-vcmmd-support-PSBM-106483.patch
Patch10414: 10414-FIXUP-using-vars-for-compacting-code-PSBM-106778.patch
Patch10415: 10415-qemu-agent-disable-blocking-calls-to-agent-PSBM-107.patch
Patch10416: 10416-vzct-2-add-jobs-support-for-everything-except-migra.patch
Patch10417: 10417-vzct-2-support-jobs-during-migration-PSBM-107444.patch
Patch10418: 10418-vzct-2-drop-job-on-client-disconnection-during-migr.patch
Patch10419: 10419-Changes-for-support-DNS-configuration-PSBM-106778.patch
Patch10420: 10420-docker-support-DNS-configuration-PSBM-106778.patch
Patch10421: 10421-docker-rename-CA-certificate-file-to-ca.pem.patch
Patch10422: 10422-qemu-fix-concurrency-crash-bug-in-snapshot-revert.patch
Patch10423: 10423-qemu-fix-concurrency-crash-bug-in-force-snapshot-re.patch
Patch10424: 10424-vzct-2-add-lifecycle-events-PSBM-107730.patch
Patch10425: 10425-vzct-2-support-getting-stats-for-migration-PSBM-107.patch
Patch10426: 10426-vzct-2-support-aborting-domain-job-API-PSBM-107446.patch
Patch10427: 10427-Fixes-for-support-creation-of-docker-container-PSBM.patch
Patch10428: 10428-logging-read-all-bytes-on-EOF-in-event-handler.patch
Patch10429: 10429-logging-fix-endless-loop-on-EOF.patch
Patch10430: 10430-docker-Support-CPU-limits-PSBM-107960.patch
Patch10431: 10431-docker-support-wss-storage-pool-for-connection-capa.patch
Patch10432: 10432-docker-support-wss-volume-resizing-PSBM-108203.patch
Patch10433: 10433-vstorage-migration-execute-src-migration-cleanup-in.patch
Patch10434: 10434-qemu-fix-qemuMigrationSrcCleanup-to-use-qemuMigrati.patch
Patch10435: 10435-qemu-monitor-return-error-message-from-qemuMonitorR.patch
Patch10436: 10436-qemu-monitor-add-qemuMonitorQueryFdsets-function.patch
Patch10437: 10437-qemu-don-t-leave-descriptors-in-fdsets-after-proces.patch
Patch10438: 10438-qemu-support-file-chardev-append-option-on-hotplug-.patch
Patch10439: 10439-qemu-support-logfile-option-on-chardev-hotplug-chan.patch
Patch10440: 10440-qemu-migration-add-cookie-parts-for-vstorage-charde.patch
Patch10441: 10441-logging-close-backing-file-on-eof-on-drain.patch
Patch10442: 10442-qemu-monitor-let-qemuMonitorAddFd-generate-fdset.patch
Patch10443: 10443-qemu-monitor-add-option-to-override-backend-in-qemu.patch
Patch10444: 10444-qemu-migration-support-changing-chardev-backend-wit.patch
Patch10445: 10445-logging-handle-race-on-drain-and-closing-in-event-l.patch
Patch10446: 10446-logging-allow-NULL-to-inode-and-offset-out-args-on-.patch
Patch10447: 10447-qemu-migration-detect-shared-vstorage-chardevs.patch
Patch10448: 10448-vstorage-support-migrating-with-chardevs-on-vstorag.patch
Patch10449: 10449-qemu-add-vstorage-chardev-tmpfile-names-to-status-f.patch
Patch10450: 10450-qemu-sync-chardevs-unplugged-status-on-reconnect.patch
Patch10451: 10451-qemu-cleanup-up-vstorage-chardevs-after-libvirtd-cr.patch
Patch10452: 10452-qemu-drain-file-chardevs-on-domain-process-stop.patch
Patch10453: 10453-Support-resources-change-for-libvirt-docker-driver-.patch
Patch10454: 10454-vstorage-migration-introduce-virDomainMigrateVstora.patch
Patch10455: 10455-vstorage-migration-add-vstorage-snapshot-commit-pha.patch
Patch10456: 10456-vstorage-migration-add-vstorage-disks-info-to-cooki.patch
Patch10457: 10457-vstorage-migration-add-vstorage-nvram-info-to-cooki.patch
Patch10458: 10458-qemu-add-nvram-block-job-support.patch
Patch10459: 10459-qemu-add-vstorage-snapshot-utility-functions.patch
Patch10460: 10460-vstorage-migration-add-vstorage-snapshot-commit.patch
Patch10461: 10461-vstorage-migration-main-patch-PSBM-106202.patch
Patch10462: 10462-vstorage-migration-support-p2p.patch
Patch10463: 10463-vstorage-load-bitmaps-from-base-image-for-tmp-snaps.patch
Patch10464: 10464-vstorage-migration-track-valid-temporary-snapshot.patch
Patch10465: 10465-vstorage-migration-resolve-valid-tmp-snapshot-on-do.patch
Patch10466: 10466-qemu-move-restoring-after-failure-to-cleanup-in-qem.patch
Patch10467: 10467-vstorage-migration-disable-API-that-can-clash-with-.patch
Patch10468: 10468-vstorage-migration-keep-snapshot-info-in-status.patch
Patch10469: 10469-vstorage-migration-add-dst-cleanup-after-disconnect.patch
Patch10470: 10470-vstorage-migration-determine-valid-snapshot-on-cras.patch
Patch10471: 10471-qemu-migration-fix-missing-owner-on-disconnection-c.patch
Patch10472: 10472-qemu-cleanup-tmp-snapshot-PSBM-106875.patch
Patch10473: 10473-logging-allow-max_len-0-to-disable-log-rollover-PSB.patch
Patch10474: 10474-qemu-support-nvram-block-job-on-reconnect.patch
Patch10475: 10475-vstorage-migration-handle-ready-state-on-reconnect-.patch
Patch10476: 10476-qemu-add-filename-to-qemuMonitorGetBlockInfo.patch
Patch10477: 10477-vstorage-migration-handle-completed-tmp-snapshot-co.patch
Patch10478: 10478-example-fix-typo-and-formatting.patch
Patch10479: 10479-example-add-ipv6-filters-examples.patch
Patch10480: 10480-doc-document-new-filters-and-not-documented-ones.patch
Patch10481: 10481-nwfilter-add-vz-specific-filters-PSBM-121477.patch
Patch10482: 10482-docker-add-compatibility-of-validation-with-current.patch
Patch10483: 10483-vstorage-migration-keep-nvram-tmp-snapshot-in-statu.patch
Patch10484: 10484-vstorage-migration-adopt-qemuDomainGetStatsOneBlock.patch
Patch10485: 10485-vstorage-migration-fix-active-block-stats-with-tmp-.patch
Patch10486: 10486-vstorage-migration-fix-inactive-block-stats-with-tm.patch
Patch10487: 10487-docker-fix-condition-for-list-of-storage-pools-PSBM.patch
Patch10488: 10488-vstorage-migration-handle-short-time-EBUSY-on-commi.patch
Patch10489: 10489-qemu-qemuDomainRenameCallback-fix-sending-false-und.patch
Patch10490: 10490-qemu-use-auto-memory-freeing-in-qemuDomainRenameCal.patch
Patch10491: 10491-qemu-rename-send-events-only-on-success.patch
Patch10492: 10492-qemu-rename-return-instead-of-goto-if-no-cleanup-re.patch
Patch10493: 10493-qemu-remove-duplicate-code-for-removing-remnant-fil.patch
Patch10494: 10494-qemu-rename-support-renaming-snapshots-directory-PS.patch
Patch10495: 10495-qemu-rename-support-renaming-checkpoints-directory.patch
Patch10496: 10496-qemu-update-name-on-reverting-from-snapshot.patch
Patch10497: 10497-qemu-rename-remove-snapshot-checkpoint-restriction.patch
Patch10498: 10498-qemu-remove-possible-garbage-left-from-previous-ren.patch
Patch10499: 10499-docker-Add-support-autostart-feature-PSBM-122024.patch
Patch10500: 10500-docker-Refactoring-for-future-changes-PSBM-122024.patch
Patch10501: 10501-docker-Get-list-for-autostart-domains-PSBM-122024.patch
Patch10502: 10502-docker-Set-domain-as-not-autostart-by-default-PSBM-.patch
Patch10503: 10503-docker-Add-virDomainHasManagedSaveImage-method-and-.patch
Patch10504: 10504-api-add-stub-for-virDomainBlockCheckpointXSwitch.patch
Patch10505: 10505-api-add-VIR_DOMAIN_MEMORY_MIN_GUARANTEE_VZ_AUTO.patch
Patch10506: 10506-tools-support-memtune-min-guarantee-auto-vz.patch
Patch10507: 10507-qemu-support-min_gurantee-in-virDomain-Set-Get-Memo.patch
Patch10508: 10508-Fix-for-possibility-to-use-inituser-without-initgro.patch
Patch10509: 10509-docker-Fix-adding-of-restart-policy-PSBM-122225.patch
Patch10510: 10510-docker-Revert-possibility-to-use-cpushares-0-PSBM-1.patch
Patch10511: 10511-docker-Fix-for-correct-work-with-process-id-PSBM-12.patch
Patch10512: 10512-docker-Style-fix-PSBM-122225.patch
Patch10513: 10513-docker-Split-dockerContainerUpdate-to-dockerContain.patch
Patch10514: 10514-docker-Add-compatibility-with-virtsh-edit-command-P.patch
Patch10515: 10515-vzct-2-support-autostarting-domains-PSBM-121587.patch
Patch10516: 10516-docker-Don-t-use-case-sensitive-comparison-PSBM-122.patch
Patch10517: 10517-docker-Optimization-powershell-scripts-PSBM-122944.patch
Patch10518: 10518-docker-Using-sscanf-with-string-memory-allocation-P.patch
Patch10519: 10519-docker-Fix-some-error-msgs-PSBM-122944.patch
Patch10520: 10520-docker-Add-storagePoolLookupByVolume-method-PSBM-12.patch
Patch10521: 10521-docker-Add-real-refresh-metadata-for-storage-pool-P.patch
Patch10522: 10522-qemu-turn-on-postcopy-to-migrate-bitmaps-PSBM-10017.patch
Patch10523: 10523-qemu-fix-guest-visible-disk-id-if-serial-is-long-VS.patch
Patch10524: 10524-docker-Refactoring-code-with-default-cert-path-PSBM.patch
Patch10525: 10525-qemu-fix-managed-pr-helper-tear-down-on-chaning-dev.patch
Patch10526: 10526-docker-Check-existence-of-image-for-domain-definiti.patch
Patch10527: 10527-docker-Support-network-bandwidth-limits-for-contain.patch
Patch10528: 10528-docker-Use-negative-value-for-removing-network-band.patch
Patch10529: 10529-docker-Will-set-negative-value-only-if-it-needs-PSB.patch
Patch10530: 10530-docker-fixup-Set-correct-type-of-memory-var-PSBM-10.patch
Patch10531: 10531-docker-We-cannot-create-second-network-with-driver-.patch
Patch10532: 10532-docker-Connection-docker-network-to-selected-window.patch
Patch10533: 10533-doc-document-virsh-commands-for-block-snaphots-expo.patch
Patch10534: 10534-vz-fix-after-Parallels-to-Virtuozzo-rename-PSBM-124.patch
Patch10535: 10535-vstorage-remove-build-time-checks-for-runtime-binar.patch
Patch10536: 10536-virsh-fix-Vstorage-support-reporting.patch
Patch10537: 10537-exec-don-t-print-errors-to-stderr-PSBM-124629.patch
Patch10538: 10538-vzct-2-implement-exec-API-PSBM-106206.patch
Patch10539: 10539-virsh-don-t-call-virDomainGetGuestInfo-for-vzct-int.patch
Patch10540: 10540-daemon-switch-off-autoshutdown-VSTOR-40335.patch
Patch10541: 10541-util-add-access-check-for-hooks-to-fix-running-as-n.patch
Patch10542: 10542-util-fix-accessibility-check-for-hook-directory.patch
Patch10543: 10543-api-fix-documentation-typo.patch
Patch10544: 10544-misc-add-bypass-cache-flag-for-block-snapshot-creat.patch
Patch10545: 10545-vzct-Support-setting-memory-for-active-CT-PSBM-1224.patch
Patch10546: 10546-vzct-Support-setting-cpu-num-for-active-CT-PSBM-122.patch
Patch10547: 10547-docs-document-backup-API-PSBM-124261.patch
Patch10548: 10548-vzct-Support-setting-memory-guarantee-for-active-CT.patch
Patch10549: 10549-qemu-capabilities-Add-capability-for-the-flat-argum.patch
Patch10550: 10550-qemu-monitor-Refactor-variable-cleanup-in-qemuMonit.patch
Patch10551: 10551-qemu-monitor-Add-flat-parameter-for-qemuMonitorJSON.patch
Patch10552: 10552-qemu-Don-t-request-nested-entries-from-qemuMonitorQ.patch
Patch10553: 10553-vzct-Support-setting-IO-limits-for-active-CT-PSBM-1.patch
Patch10554: 10554-tools-treat-in-shutdown-etc-as-shutdown-finished-VS.patch
Patch10555: 10555-qemu-don-t-error-if-cannot-find-disk-by-alias-PSBM-.patch
Patch10556: 10556-qemu-vcmmd-support-for-setting-balloon-PSBM-123145.patch
Patch10557: 10557-qemu-better-cluster-size-for-tmp-deltas-on-vstorage.patch
Patch10558: 10558-util-add-hanging-process-debugging-PSBM-126062.patch
Patch10559: 10559-vzct-Support-disk-resize-for-active-CT-PSBM-122525.patch
Patch10560: 10560-qemu-detect-block-node-names-after-attaching-a-disk.patch
Patch10561: 10561-qemu-api-support-min_guarantee-as-fraction-of-ballo.patch
Patch10562: 10562-security-take-lock-only-if-attributes-are-to-be-cha.patch
Patch10563: 10563-security-don-t-restore-labels-for-readonly-and-shar.patch
Patch10564: 10564-qemu-fix-noisy-error-for-domain-with-image-on-reado.patch
Patch10565: 10565-misc-add-blockjob-type-for-block-snapshot-job-PSBM-.patch
Patch10566: 10566-qemu-monitor-add-qemuMonitorBlockDirtyBitmapRemoveB.patch
Patch10567: 10567-FIXUP-qemu-virDomainBlockExportName-adapt-to-abort-.patch
Patch10568: 10568-FIXUP-qemuDomainBlockExportCancel-simplify-memory-m.patch
Patch10569: 10569-util-add-virTimeBackOffWaitUnlocked.patch
Patch10570: 10570-backup-qemu-retry-bitmap-deletion-while-it-is-used-.patch
Patch10571: 10571-FIXUP-qemu-modernize-memory-mgmt-in-qemuBlockSnapsh.patch
Patch10572: 10572-qemu-add-qemuMonitorJSONBlockdevDelBusy.patch
Patch10573: 10573-backup-qemu-retry-fleece-node-deletion-while-it-is-.patch
Patch10574: 10574-vstorage-migration-cleanup-precreated-src-tmp-delta.patch
Patch10575: 10575-FIXUP-use-qemuDomainObjEnterMonitorAsync-inside-asy.patch
Patch10576: 10576-FIXUP-reduce-scope-for-logManager-var.patch
Patch10577: 10577-upgrade-drain-chardev-s-pipes-PSBM-108071.patch
Patch10578: 10578-FIXUP-rename-to-VCMMD_MEMGUARANTEE_BYTES-PSBM-12721.patch
Patch10579: 10579-security-handle-chown-EACCES-on-readonly-cifs-mount.patch
Patch10580: 10580-FIXUP-qemu-allow-relative-memory-guarantee-value-0-.patch
Patch10581: 10581-vzct-add-ip-address-to-venet0-schema.patch
Patch10582: 10582-vzct-dump-ip-info-for-interfaces-PSBM-106470.patch
Patch10583: 10583-vzct-support-setting-net-interface-ips-on-define.patch
Patch10584: 10584-upgrade-support-ethernet-net-type-PSBM-127606.patch
Patch10585: 10585-qemu-acquire-job-to-handle-agent-disconnection-PSBM.patch
Patch10586: 10586-FIXUP-add-missing-pieces-for-vz-backup-API-docs-PSB.patch
Patch10587: 10587-nwfilter-don-t-add-symmetric-record-for-policy-rule.patch
Patch10588: 10588-FIXUP-update-inactive-config-on-pull-completion-VST.patch
Patch10589: 10589-FIXUP-fix-vstorage-tmp-link-cleanup-PSBM-127546.patch
Patch10590: 10590-qemu-notify-vcmmd-of-node-vcpu-pinning-PSBM-126679.patch
Patch10591: 10591-FIXUP-qemu-fix-typo-in-virDomainDefMarkExplicitBack.patch
Patch10592: 10592-FIXUP-Fix-for-bug-PSBM-128906.patch
Patch10593: 10593-FIXUP-qemu-don-t-access-vcmmd-in-session-driver-PSB.patch

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-config-nwfilter = %{version}-%{release}
%if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
%endif
%if %{with_qemu}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
%endif
%if %{with_vzct}
Requires: libvirt-daemon-driver-vzct = %{version}-%{release}
%endif
# We had UML driver, but we've removed it.
Obsoletes: libvirt-daemon-driver-uml <= 5.0.0
Obsoletes: libvirt-daemon-uml <= 5.0.0
%if %{with_vbox}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

Requires: libvirt-daemon-driver-interface = %{version}-%{release}
%if %{with_secret}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-client = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

Obsoletes: libvirt-daemon-driver-secret < 3.9.0-14%{?dist}.14
Obsoletes: libvirt-daemon-driver-nodedev < 3.9.0-14%{?dist}.14
Obsoletes: libvirt-daemon-driver-lxc < 3.9.0-14%{?dist}.14
Obsoletes: libvirt-daemon-driver-storage-logical < 3.9.0-14%{?dist}.14
Obsoletes: libvirt-daemon-driver-storage-disk < 3.9.0-14%{?dist}.14
Obsoletes: libvirt-daemon-driver-storage-mpath < 3.9.0-14%{?dist}.14
Obsoletes: libvirt-daemon-driver-storage-iscsi < 3.9.0-14%{?dist}.14
Obsoletes: libvirt-daemon-driver-storage-scsi < 3.9.0-14%{?dist}.14
Obsoletes: libvirt-daemon-driver-storage-gluster < 3.9.0-14%{?dist}.14
Obsoletes: libvirt-daemon-driver-storage-rbd < 3.9.0-14%{?dist}.14

# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
%if 0%{?enable_autotools}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: gettext-devel
BuildRequires: libtool
BuildRequires: /usr/bin/pod2man
%endif
BuildRequires: gcc
BuildRequires: git
%if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: perl-interpreter
%else
BuildRequires: perl
%endif
BuildRequires: %{python}
BuildRequires: systemd-units
%if %{with_libxl}
BuildRequires: xen-devel
%endif
BuildRequires: libxml2-devel
BuildRequires: libxslt
BuildRequires: readline-devel
%if %{with_bash_completion}
BuildRequires: bash-completion >= 2.0
%endif
BuildRequires: ncurses-devel
BuildRequires: gettext
BuildRequires: libtasn1-devel
BuildRequires: gnutls-devel
BuildRequires: libattr-devel
# For pool-build probing for existing pools
BuildRequires: libblkid-devel >= 2.17
# for augparse, optionally used in testing
BuildRequires: augeas
BuildRequires: systemd-devel >= 185
BuildRequires: libpciaccess-devel >= 0.10.9
BuildRequires: yajl-devel
%if %{with_sanlock}
BuildRequires: sanlock-devel >= 2.4
%endif
BuildRequires: libpcap-devel
BuildRequires: libnl3-devel
BuildRequires: libselinux-devel
BuildRequires: dnsmasq >= 2.41
BuildRequires: iptables
BuildRequires: radvd
BuildRequires: ebtables
BuildRequires: module-init-tools
BuildRequires: cyrus-sasl-devel
BuildRequires: polkit >= 0.112
BuildRequires: patch
# For mount/umount in FS driver
BuildRequires: util-linux
%if %{with_qemu}
# For managing ACLs
BuildRequires: libacl-devel
# From QEMU RPMs
BuildRequires: /usr/bin/qemu-img
%endif
# For LVM drivers
BuildRequires: lvm2
# For pool type=iscsi
BuildRequires: iscsi-initiator-utils
%if %{with_storage_iscsi_direct}
# For pool type=iscsi-direct
BuildRequires: libiscsi-devel
%endif
# For disk driver
BuildRequires: parted-devel
# For Multipath support
BuildRequires: device-mapper-devel
# For XFS reflink clone support
BuildRequires: xfsprogs-devel
%if %{with_storage_rbd}
BuildRequires: librados2-devel
BuildRequires: librbd1-devel
%endif
%if %{with_storage_gluster}
BuildRequires: glusterfs-api-devel >= 3.4.1
BuildRequires: glusterfs-devel >= 3.4.1
%endif
%if %{with_storage_sheepdog}
BuildRequires: sheepdog
%endif
%if %{with_storage_zfs}
# Support any conforming implementation of zfs. On stock Fedora
# this is zfs-fuse, but could be zfsonlinux upstream RPMs
BuildRequires: /sbin/zfs
BuildRequires: /sbin/zpool
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-ng-devel >= 0.5.0
%if %{with_fuse}
BuildRequires: fuse-devel >= 2.8.6
%endif
%if %{with_phyp} || %{with_libssh2}
BuildRequires: libssh2-devel >= 1.3.0
%endif

BuildRequires: netcf-devel >= 0.2.2
%if %{with_esx}
BuildRequires: libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires: libwsman-devel >= 2.2.3
%endif
BuildRequires: audit-libs-devel
# we need /usr/sbin/dtrace
BuildRequires: systemtap-sdt-devel

# For mount/umount in FS driver
BuildRequires: util-linux
# For showmount in FS driver (netfs discovery)
BuildRequires: nfs-utils

# Communication with the firewall and polkit daemons use DBus
BuildRequires: dbus-devel

# Fedora build root suckage
BuildRequires: gawk

# For storage wiping with different algorithms
BuildRequires: scrub

%if %{with_numad}
BuildRequires: numad
%endif

%if %{with_wireshark}
BuildRequires: wireshark-devel >= 2.4.0
%endif

%if %{with_libssh}
BuildRequires: libssh-devel >= 0.7.0
%endif

%if %{with_vz}
BuildRequires: libprlsdk-devel
%else
Obsoletes: libvirt-daemon-driver-vz < %{version}-%{release}
Obsoletes: libvirt-daemon-vz < %{version}-%{release}
%endif

%if %{with_vzct}
BuildRequires: libprlsdk-devel
BuildRequires: ploop-devel
BuildRequires: libvzctl-devel >= 7.0.638
BuildRequires: libvcmmd-devel
BuildRequires: libvzevent-devel
%if 0%{?rhel} > 7
BuildRequires: kernel-headers
%else
BuildRequires: vzkernel-headers
%endif
BuildRequires: perl-XML-XPath
%endif

%if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: rpcgen
BuildRequires: libtirpc-devel
%endif

%if %{with_firewalld_zone}
BuildRequires: firewalld-filesystem
%endif

%if %{with_docker}
BuildRequires: libcurl-devel
BuildRequires: libwsman-devel
%endif

%if %{with_vcmmd}
BuildRequires: libvcmmd-devel
%endif

Provides: bundled(gnulib)

%description
Libvirt is a C toolkit to interact with the virtualization capabilities
of recent versions of Linux (and other OSes). The main package includes
the libvirtd server exporting the virtualization support.

%package docs
Summary: API reference and website documentation

%description docs
Includes the API reference for the libvirt C library, and a complete
copy of the libvirt.org website documentation.

%package daemon
Summary: Server side daemon and supporting files for libvirt library

# All runtime requirements for the libvirt package (runtime requrements
# for subpackages are listed later in those subpackages)

# The client side, i.e. shared libs are in a subpackage
Requires: %{name}-libs = %{version}-%{release}

# for modprobe of pci devices
Requires: module-init-tools

# for /sbin/ip & /sbin/tc
Requires: iproute
# tc is provided by iproute-tc since at least Fedora 26
%if 0%{?fedora} || 0%{?rhel} > 7
Requires: iproute-tc
%endif

Requires: polkit >= 0.112
%ifarch %{ix86} x86_64 ia64
# For virConnectGetSysinfo
Requires: dmidecode
%endif
# For service management
Requires(post): systemd-units
Requires(post): systemd-sysv
Requires(preun): systemd-units
Requires(postun): systemd-units
%if %{with_numad}
Requires: numad
%endif
# libvirtd depends on 'messagebus' service
Requires: dbus
# For uid creation during pre
Requires(pre): shadow-utils

%description daemon
Server side daemon required to manage the virtualization capabilities
of recent versions of Linux. Requires a hypervisor specific sub-RPM
for specific drivers.

%package daemon-config-network
Summary: Default configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description daemon-config-network
Default configuration files for setting up NAT based networking

%package daemon-config-nwfilter
Summary: Network filter configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

%description daemon-config-nwfilter
Network filter configuration files for cleaning guest traffic

%package daemon-driver-network
Summary: Network driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: dnsmasq >= 2.41
Requires: radvd
Requires: iptables

%description daemon-driver-network
The network driver plugin for the libvirtd daemon, providing
an implementation of the virtual network APIs using the Linux
bridge capabilities.


%package daemon-driver-nwfilter
Summary: Nwfilter driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iptables
Requires: ebtables

%description daemon-driver-nwfilter
The nwfilter driver plugin for the libvirtd daemon, providing
an implementation of the firewall APIs using the ebtables,
iptables and ip6tables capabilities


%package daemon-driver-nodedev
Summary: Nodedev driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# needed for device enumeration
Requires: systemd >= 185

%description daemon-driver-nodedev
The nodedev driver plugin for the libvirtd daemon, providing
an implementation of the node device APIs using the udev
capabilities.


%package daemon-driver-interface
Summary: Interface driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: netcf-libs >= 0.2.2

%description daemon-driver-interface
The interface driver plugin for the libvirtd daemon, providing
an implementation of the network interface APIs using the
netcf library


%if %{with_secret}
%package daemon-driver-secret
Summary: Secret driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-secret
The secret driver plugin for the libvirtd daemon, providing
an implementation of the secret key APIs.
%endif

%package daemon-driver-storage-core
Summary: Storage driver plugin including base backends for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: nfs-utils
# For mkfs
Requires: util-linux
%if %{with_qemu}
# From QEMU RPMs
Requires: /usr/bin/qemu-img
%endif
%if !%{with_storage_rbd}
Obsoletes: libvirt-daemon-driver-storage-rbd < %{version}-%{release}
%endif

%description daemon-driver-storage-core
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using files, local disks, LVM, SCSI,
iSCSI, and multipath storage.

%if %{with_storage_misc}
%package daemon-driver-storage-logical
Summary: Storage driver plugin for lvm volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: lvm2

%description daemon-driver-storage-logical
The storage driver backend adding implementation of the storage APIs for block
volumes using lvm.


%package daemon-driver-storage-disk
Summary: Storage driver plugin for disk
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: parted
Requires: device-mapper

%description daemon-driver-storage-disk
The storage driver backend adding implementation of the storage APIs for block
volumes using the host disks.


%package daemon-driver-storage-scsi
Summary: Storage driver plugin for local scsi devices
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-scsi
The storage driver backend adding implementation of the storage APIs for scsi
host devices.


%package daemon-driver-storage-iscsi
Summary: Storage driver plugin for iscsi
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iscsi-initiator-utils

%description daemon-driver-storage-iscsi
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using the host iscsi stack.


%if %{with_storage_iscsi_direct}
%package daemon-driver-storage-iscsi-direct
Summary: Storage driver plugin for iscsi-direct
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: libiscsi

%description daemon-driver-storage-iscsi-direct
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using libiscsi direct connection.
%endif


%package daemon-driver-storage-mpath
Summary: Storage driver plugin for multipath volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: device-mapper

%description daemon-driver-storage-mpath
The storage driver backend adding implementation of the storage APIs for
multipath storage using device mapper.
%endif


%if %{with_storage_gluster}
%package daemon-driver-storage-gluster
Summary: Storage driver plugin for gluster
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
    %if 0%{?fedora}
Requires: glusterfs-client >= 2.0.1
    %endif
    %if (0%{?fedora} || 0%{?with_storage_gluster})
Requires: /usr/sbin/gluster
    %endif

%description daemon-driver-storage-gluster
The storage driver backend adding implementation of the storage APIs for gluster
volumes using libgfapi.
%endif


%if %{with_storage_rbd}
%package daemon-driver-storage-rbd
Summary: Storage driver plugin for rbd
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-rbd
The storage driver backend adding implementation of the storage APIs for rbd
volumes using the ceph protocol.
%endif


%if %{with_storage_sheepdog}
%package daemon-driver-storage-sheepdog
Summary: Storage driver plugin for sheepdog
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: sheepdog

%description daemon-driver-storage-sheepdog
The storage driver backend adding implementation of the storage APIs for
sheepdog volumes using.
%endif


%if %{with_storage_zfs}
%package daemon-driver-storage-zfs
Summary: Storage driver plugin for ZFS
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# Support any conforming implementation of zfs
Requires: /sbin/zfs
Requires: /sbin/zpool

%description daemon-driver-storage-zfs
The storage driver backend adding implementation of the storage APIs for
ZFS volumes.
%endif

%if %{with_storage_vstorage}
%package daemon-driver-storage-vstorage
Summary: Storage driver plugin for Vstorage
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: vstorage-client

%description daemon-driver-storage-vstorage
The storage driver backend adding implementation of the storage APIs for
Vstorage volumes.
%endif


%package daemon-driver-storage
Summary: Storage driver plugin including all backends for the libvirtd daemon
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
%if %{with_storage_iscsi_direct}
Requires: libvirt-daemon-driver-storage-iscsi-direct = %{version}-%{release}
%endif
%if %{with_storage_sheepdog}
Requires: libvirt-daemon-driver-storage-sheepdog = %{version}-%{release}
%endif
%if %{with_storage_zfs}
Requires: libvirt-daemon-driver-storage-zfs = %{version}-%{release}
%endif

%description daemon-driver-storage
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using LVM, iSCSI,
parted and more.


%if %{with_qemu}
%package daemon-driver-qemu
Summary: QEMU driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: /usr/bin/qemu-img
# For image compression
Requires: gzip
Requires: bzip2
Requires: lzop
Requires: xz
    %if 0%{?fedora} || 0%{?rhel} > 7
Requires: systemd-container
    %endif
%if %{with_vcmmd}
Requires: libvcmmd
%endif

%description daemon-driver-qemu
The qemu driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
QEMU
%endif


%if %{with_lxc}
%package daemon-driver-lxc
Summary: LXC driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires: libvirt-daemon-driver-network = %{version}-%{release}
    %if 0%{?fedora} || 0%{?rhel} > 7
Requires: systemd-container
    %endif

%description daemon-driver-lxc
The LXC driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
the Linux kernel
%endif


%if %{with_vbox}
%package daemon-driver-vbox
Summary: VirtualBox driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-vbox
The vbox driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
VirtualBox
%endif


%if %{with_libxl}
%package daemon-driver-libxl
Summary: Libxl driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Obsoletes: libvirt-daemon-driver-xen < 4.3.0

%description daemon-driver-libxl
The Libxl driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
Libxl
%endif

%if %{with_vz}
%package daemon-driver-vz
Summary: Virtuozzo driver plugin for the libvirtd daemon
Group: Development/Libraries
Requires: libvirt-daemon = %{version}-%{release}

%description daemon-driver-vz
The vz driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
Virtuozzo
%endif


%if %{with_vzct}
%package daemon-driver-vzct
Summary: Virtuozzo Containers driver plugin for the libvirtd daemon
Group: Development/Libraries
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvzctl >= 7.0.638
Requires: ploop-lib
Requires: ploop
Requires: vzctl

%description daemon-driver-vzct
The libvirt hypervisor driver which provides access to Virtuozzo
containers
%endif


%if %{with_qemu_tcg}
%package daemon-qemu
Summary: Server side daemon & driver required to run QEMU guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
%if %{with_secret}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu

%description daemon-qemu
Server side daemon and driver required to manage the virtualization
capabilities of the QEMU TCG emulators
%endif


%if %{with_qemu_kvm}
%package daemon-kvm
Summary: Server side daemon & driver required to run KVM guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
%if %{with_secret}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu-kvm

%description daemon-kvm
Server side daemon and driver required to manage the virtualization
capabilities of the KVM hypervisor
%endif


%if %{with_lxc}
%package daemon-lxc
Summary: Server side daemon & driver required to run LXC guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-lxc = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-lxc
Server side daemon and driver required to manage the virtualization
capabilities of LXC
%endif


%if %{with_libxl}
%package daemon-xen
Summary: Server side daemon & driver required to run XEN guests

Requires: libvirt-daemon = %{version}-%{release}
    %if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
    %endif
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: xen

%description daemon-xen
Server side daemon and driver required to manage the virtualization
capabilities of XEN
%endif

%if %{with_vbox}
%package daemon-vbox
Summary: Server side daemon & driver required to run VirtualBox guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vbox
Server side daemon and driver required to manage the virtualization
capabilities of VirtualBox
%endif

%if %{with_vz}
%package daemon-vz
Summary: Server side daemon & driver required to run Virtuozzo guests
Group: Development/Libraries

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vz = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vz
Server side daemon and driver required to manage the virtualization
capabilities of Virtuozzo
%endif

%if %{with_vzct}
%package daemon-vzct
Summary: Server side daemon & driver required to run Virtuozzo containers
Group: Development/Libraries

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vzct = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vzct
Server side daemon and driver required to manage the virtualization
capabilities of Virtuozzo containers
%endif

%package client
Summary: Client side utilities of the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: readline
Requires: ncurses
# Needed by /usr/libexec/libvirt-guests.sh script.
Requires: gettext
# Needed by virt-pki-validate script.
Requires: gnutls-utils
%if %{with_bash_completion}
Requires: %{name}-bash-completion = %{version}-%{release}
%endif

%description client
The client binaries needed to access the virtualization
capabilities of recent versions of Linux (and other OSes).

%package libs
Summary: Client side libraries
# So remote clients can access libvirt over SSH tunnel
# (client invokes 'nc' against the UNIX socket on the server)
Requires: nc
Requires: cyrus-sasl
# Needed by default sasl.conf - no onerous extra deps, since
# 100's of other things on a system already pull in krb5-libs
Requires: cyrus-sasl-gssapi
%if %{with_docker}
Requires: libwsman1
%endif

%description libs
Shared libraries for accessing the libvirt daemon.

%package admin
Summary: Set of tools to control libvirt daemon
Requires: %{name}-libs = %{version}-%{release}
Requires: readline
%if %{with_bash_completion}
Requires: %{name}-bash-completion = %{version}-%{release}
%endif

%description admin
The client side utilities to control the libvirt daemon.

%if %{with_bash_completion}
%package bash-completion
Summary: Bash completion script

%description bash-completion
Bash completion script stub.
%endif

%if %{with_wireshark}
%package wireshark
Summary: Wireshark dissector plugin for libvirt RPC transactions
Requires: wireshark >= 2.4.0
Requires: %{name}-libs = %{version}-%{release}

%description wireshark
Wireshark dissector plugin for better analysis of libvirt RPC traffic.
%endif

%if %{with_lxc}
%package login-shell
Summary: Login shell for connecting users to an LXC container
Requires: %{name}-libs = %{version}-%{release}

%description login-shell
Provides the set-uid virt-login-shell binary that is used to
connect a user to an LXC container when they login, by switching
namespaces.
%endif

%package devel
Summary: Libraries, includes, etc. to compile with the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: pkgconfig

%description devel
Include header files & development libraries for the libvirt C library.

%if %{with_sanlock}
%package lock-sanlock
Summary: Sanlock lock manager plugin for QEMU driver
Requires: sanlock >= 2.4
#for virt-sanlock-cleanup require augeas
Requires: augeas
Requires: %{name}-daemon = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description lock-sanlock
Includes the Sanlock lock manager plugin for the QEMU
driver
%endif

%package nss
Summary: Libvirt plugin for Name Service Switch
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description nss
Libvirt plugin for NSS for translating domain names into IP addresses.


%prep

%autosetup -S git_am -N

# "make dist" replaces all symlinks with a copy of the linked files;
# we need to replace all of them with the original symlinks
echo "Restoring symlinks"
while read lnk target; do
    if [ -e $lnk ]; then
        rm -rf $lnk
        ln -s $target $lnk
    fi
done <%{_sourcedir}/symlinks || exit 1
git add .
git commit -q -a --author 'rpm-build <rpm-build>' -m symlinks


git config gc.auto 0

%autopatch

%build
%if ! %{supported_platform}
echo "This RPM requires either Fedora >= %{min_fedora} or RHEL >= %{min_rhel}"
exit 1
%endif

%if %{with_qemu}
    %define arg_qemu --with-qemu
%else
    %define arg_qemu --without-qemu
%endif

%if %{with_openvz}
    %define arg_openvz --with-openvz
%else
    %define arg_openvz --without-openvz
%endif

%if %{with_lxc}
    %define arg_lxc --with-lxc
    %define arg_login_shell --with-login-shell
%else
    %define arg_lxc --without-lxc
    %define arg_login_shell --without-login-shell
%endif

%if %{with_vbox}
    %define arg_vbox --with-vbox
%else
    %define arg_vbox --without-vbox
%endif

%if %{with_libxl}
    %define arg_libxl --with-libxl
%else
    %define arg_libxl --without-libxl
%endif

%if %{with_phyp}
    %define arg_phyp --with-phyp
%else
    %define arg_phyp --without-phyp
%endif

%if %{with_esx}
    %define arg_esx --with-esx
%else
    %define arg_esx --without-esx
%endif

%if %{with_hyperv}
    %define arg_hyperv --with-hyperv
%else
    %define arg_hyperv --without-hyperv
%endif

%if %{with_vmware}
    %define arg_vmware --with-vmware
%else
    %define arg_vmware --without-vmware
%endif

%if %{with_storage_rbd}
    %define arg_storage_rbd --with-storage-rbd
%else
    %define arg_storage_rbd --without-storage-rbd
%endif

%if %{with_storage_sheepdog}
    %define arg_storage_sheepdog --with-storage-sheepdog
%else
    %define arg_storage_sheepdog --without-storage-sheepdog
%endif

%if %{with_storage_gluster}
    %define arg_storage_gluster --with-storage-gluster
%else
    %define arg_storage_gluster --without-storage-gluster
%endif

%if %{with_storage_zfs}
    %define arg_storage_zfs --with-storage-zfs
%else
    %define arg_storage_zfs --without-storage-zfs
%endif

%if %{with_storage_vstorage}
    %define arg_storage_vstorage --with-storage-vstorage
%else
    %define arg_storage_vstorage --without-storage-vstorage
%endif

%if %{with_numactl}
    %define arg_numactl --with-numactl
%else
    %define arg_numactl --without-numactl
%endif

%if %{with_numad}
    %define arg_numad --with-numad
%else
    %define arg_numad --without-numad
%endif

%if %{with_fuse}
    %define arg_fuse --with-fuse
%else
    %define arg_fuse --without-fuse
%endif

%if %{with_sanlock}
    %define arg_sanlock --with-sanlock
%else
    %define arg_sanlock --without-sanlock
%endif

%if %{with_firewalld}
    %define arg_firewalld --with-firewalld
%else
    %define arg_firewalld --without-firewalld
%endif

%if %{with_firewalld_zone}
    %define arg_firewalld_zone --with-firewalld-zone
%else
    %define arg_firewalld_zone --without-firewalld-zone
%endif

%if %{with_wireshark}
    %define arg_wireshark --with-wireshark-dissector
%else
    %define arg_wireshark --without-wireshark-dissector
%endif

%if %{with_storage_iscsi_direct}
    %define arg_storage_iscsi_direct --with-storage-iscsi-direct
%else
    %define arg_storage_iscsi_direct --without-storage-iscsi-direct
%endif

%if %{with_secret}
    %define arg_secret --with-secrets
%else
    %define arg_secret --without-secrets
%endif

%if %{with_storage_misc}
    %define arg_storage_misc --with-storage-lvm --with-storage-iscsi --with-storage-scsi --with-storage-disk --with-storage-mpath
%else
    %define arg_storage_misc --without-storage-lvm --without-storage-iscsi --without-storage-scsi --without-storage-disk --without-storage-mpath
%endif

%if %{with_vz}
    %define arg_vz --with-vz
%else
    %define arg_vz --without-vz
%endif

%if %{with_vzct}
    %define arg_vzct --with-vzct
%else
    %define arg_vzct --without-vzct
%endif

%if %{with_docker}
    %define arg_docker --with-docker
%else
    %define arg_docker --without-docker
%endif

%if %{with_vcmmd}
    %define arg_vcmmd --with-vcmmd
%else
    %define arg_vcmmd --without-vcmmd
%endif

%define when  %(date +"%%F-%%T")
%define where %(hostname)
%define who   %{?packager}%{!?packager:Unknown}
%define arg_packager --with-packager="%{who}, %{when}, %{where}"
%define arg_packager_version --with-packager-version="%{release}"

%define arg_selinux_mount --with-selinux-mount="/sys/fs/selinux"

%if 0%{?fedora}
    # Nightly edk2.git-ovmf-x64
    LOADERS="/usr/share/edk2.git/ovmf-x64/OVMF_CODE-pure-efi.fd:/usr/share/edk2.git/ovmf-x64/OVMF_VARS-pure-efi.fd"
    # Nightly edk2.git-ovmf-ia32
    LOADERS="$LOADERS:/usr/share/edk2.git/ovmf-ia32/OVMF_CODE-pure-efi.fd:/usr/share/edk2.git/ovmf-ia32/OVMF_VARS-pure-efi.fd"
    # Nightly edk2.git-aarch64
    LOADERS="$LOADERS:/usr/share/edk2.git/aarch64/QEMU_EFI-pflash.raw:/usr/share/edk2.git/aarch64/vars-template-pflash.raw"
    # Nightly edk2.git-arm
    LOADERS="$LOADERS:/usr/share/edk2.git/arm/QEMU_EFI-pflash.raw:/usr/share/edk2.git/arm/vars-template-pflash.raw"

    # Fedora edk2-ovmf
    LOADERS="$LOADERS:/usr/share/edk2/ovmf/OVMF_CODE.fd:/usr/share/edk2/ovmf/OVMF_VARS.fd"
    # Fedora edk2-ovmf-ia32
    LOADERS="$LOADERS:/usr/share/edk2/ovmf-ia32/OVMF_CODE.fd:/usr/share/edk2/ovmf-ia32/OVMF_VARS.fd"
    # Fedora edk2-aarch64
    LOADERS="$LOADERS:/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw:/usr/share/edk2/aarch64/vars-template-pflash.raw"
    # Fedora edk2-arm
    LOADERS="$LOADERS:/usr/share/edk2/arm/QEMU_EFI-pflash.raw:/usr/share/edk2/arm/vars-template-pflash.raw"
    %define arg_loader_nvram --with-loader-nvram="$LOADERS"
%endif

# place macros above and build commands below this comment

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

%if 0%{?enable_autotools}
 autoreconf -if
%endif

rm -f po/stamp-po
%configure %{?arg_qemu} \
           %{?arg_openvz} \
           %{?arg_lxc} \
           %{?arg_vbox} \
           %{?arg_libxl} \
           --with-sasl \
           --with-polkit \
           --with-libvirtd \
           %{?arg_phyp} \
           %{?arg_esx} \
           %{?arg_hyperv} \
           %{?arg_vmware} \
           --without-xenapi \
           %{?arg_vz} \
           %{?arg_vzct} \
           %{?arg_docker} \
           --without-bhyve \
           --with-interface \
           --with-network \
           --with-storage-fs \
           %{?arg_storage_misc} \
           %{?arg_storage_iscsi_direct} \
           %{?arg_storage_rbd} \
           %{?arg_storage_sheepdog} \
           %{?arg_storage_gluster} \
           %{?arg_storage_zfs} \
           %{?arg_storage_vstorage} \
           %{?arg_numactl} \
           %{?arg_numad} \
           --with-capng \
           %{?arg_fuse} \
           --with-netcf \
           %{?arg_vcmmd} \
           --with-selinux \
           %{?arg_selinux_mount} \
           --without-apparmor \
           --without-hal \
           --with-udev \
           --with-yajl \
           %{?arg_sanlock} \
           --with-libpcap \
           --with-macvtap \
           --with-audit \
           --with-dtrace \
           --with-driver-modules \
           %{?arg_firewalld} \
           %{?arg_firewalld_zone} \
           %{?arg_wireshark} \
           --without-pm-utils \
           --with-nss-plugin \
           %{arg_packager} \
           %{arg_packager_version} \
           --with-qemu-user=%{qemu_user} \
           --with-qemu-group=%{qemu_group} \
           --with-tls-priority=%{tls_priority} \
           %{?arg_loader_nvram} \
           %{?arg_secret} \
           %{?enable_werror} \
           --enable-expensive-tests \
           --with-init-script=systemd \
           %{?arg_login_shell}
make %{?_smp_mflags} V=1
gzip -9 ChangeLog

%install
rm -fr %{buildroot}

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

%make_install %{?_smp_mflags} SYSTEMD_UNIT_DIR=%{_unitdir} V=1

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.a
%if %{with_wireshark}
rm -f $RPM_BUILD_ROOT%{wireshark_plugindir}/libvirt.la
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/lib/libvirt/dnsmasq/
# We don't want to install /etc/libvirt/qemu/networks in the main %files list
# because if the admin wants to delete the default network completely, we don't
# want to end up re-incarnating it on every RPM upgrade.
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
# libvirt saves this file with mode 0600
chmod 0600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml

# nwfilter files are installed in /usr/share/libvirt and copied to /etc in %post
# to avoid verification errors on changed files in /etc
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
cp -a $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml \
    $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
# libvirt saves these files with mode 600
chmod 600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml

# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
%if ! %{with_qemu}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif
%find_lang %{name}

%if ! %{with_sanlock}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirt_sanlock.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%endif

%if ! %{with_lxc}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%if ! %{with_qemu}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
%endif
%if ! %{with_lxc}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if ! %{with_libxl}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/libxl.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.libxl
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_libxl.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%endif

# Copied into libvirt-docs subpackage eventually
mv $RPM_BUILD_ROOT%{_datadir}/doc/libvirt libvirt-docs

%ifarch %{power64} s390x x86_64 ia64 alpha sparc64
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes-64.stp

    %if %{with_qemu}
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes-64.stp
    %endif
%endif

%check
%if %do_check
cd tests
# These tests don't current work in a mock build root
for i in nodeinfotest seclabeltest
do
  rm -f $i
  printf 'int main(void) { return 0; }' > $i.c
  printf '#!/bin/sh\nexit 0\n' > $i
  chmod +x $i
done
if ! make %{?_smp_mflags} check VIR_TEST_DEBUG=1
then
  cat test-suite.log || true
  exit 1
fi
%endif

%post libs
%if 0%{?rhel} == 7
/sbin/ldconfig
%endif

%postun libs
%if 0%{?rhel} == 7
/sbin/ldconfig
%endif

%pre daemon
# 'libvirt' group is just to allow password-less polkit access to
# libvirtd. The uid number is irrelevant, so we use dynamic allocation
# described at the above link.
getent group libvirt >/dev/null || groupadd -r libvirt

exit 0

%post daemon

%systemd_post virtlockd.socket virtlockd-admin.socket
%systemd_post virtlogd.socket virtlogd-admin.socket
%systemd_post libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_post libvirtd-tcp.socket libvirtd-tls.socket
%systemd_post libvirtd.service

# request daemon restart in posttrans
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%preun daemon
%systemd_preun libvirtd.service
%systemd_preun libvirtd-tcp.socket libvirtd-tls.socket
%systemd_preun libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_preun virtlogd.socket virtlogd-admin.socket virtlogd.service
%systemd_preun virtlockd.socket virtlockd-admin.socket virtlockd.service

%postun daemon
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    /bin/systemctl reload-or-try-restart virtlockd.service >/dev/null 2>&1 || :
    /bin/systemctl reload-or-try-restart virtlogd.service >/dev/null 2>&1 || :
fi

# In upgrade scenario we must explicitly enable virtlockd/virtlogd
# sockets, if libvirtd is already enabled and start them if
# libvirtd is running, otherwise you'll get failures to start
# guests
%triggerpostun daemon -- libvirt-daemon < 1.3.0
if [ $1 -ge 1 ] ; then
    /bin/systemctl is-enabled libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl enable virtlogd.socket virtlogd-admin.socket || :
    /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl start virtlogd.socket virtlogd-admin.socket || :
fi

%posttrans daemon
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    # See if user has previously modified their install to
    # tell libvirtd to use --listen
    grep -E '^LIBVIRTD_ARGS=.*--listen' /etc/sysconfig/libvirtd 1>/dev/null 2>&1
    if test $? = 0
    then
        # Then lets keep honouring --listen and *not* use
        # systemd socket activation, because switching things
        # might confuse mgmt tool like puppet/ansible that
        # expect the old style libvirtd
        /bin/systemctl mask libvirtd.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-ro.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-admin.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-tls.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-tcp.socket >/dev/null 2>&1 || :
    else
        # Old libvirtd owns the sockets and will delete them on
        # shutdown. Can't use a try-restart as libvirtd will simply
        # own the sockets again when it comes back up. Thus we must
        # do this particular ordering, so that we get libvirtd
        # running with socket activation in use
        /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1
        if test $? = 0
        then
            /bin/systemctl stop libvirtd.service >/dev/null 2>&1 || :

            /bin/systemctl try-restart libvirtd.socket >/dev/null 2>&1 || :
            /bin/systemctl try-restart libvirtd-ro.socket >/dev/null 2>&1 || :
            /bin/systemctl try-restart libvirtd-admin.socket >/dev/null 2>&1 || :

            /bin/systemctl start libvirtd.service >/dev/null 2>&1 || :
        fi
    fi
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%post daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%postun daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%post daemon-config-network
if test $1 -eq 1 && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml ; then
    # see if the network used by default network creates a conflict,
    # and try to resolve it
    # NB: 192.168.122.0/24 is used in the default.xml template file;
    # do not modify any of those values here without also modifying
    # them in the template.
    orig_sub=122
    sub=${orig_sub}
    nl='
'
    routes="${nl}$(ip route show | cut -d' ' -f1)${nl}"
    case ${routes} in
      *"${nl}192.168.${orig_sub}.0/24${nl}"*)
        # there was a match, so we need to look for an unused subnet
        for new_sub in $(seq 124 254); do
          case ${routes} in
          *"${nl}192.168.${new_sub}.0/24${nl}"*)
            ;;
          *)
            sub=$new_sub
            break;
            ;;
          esac
        done
        ;;
      *)
        ;;
    esac

    UUID=`/usr/bin/uuidgen`
    sed -e "s/${orig_sub}/${sub}/g" \
        -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
    ln -s ../default.xml %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
    # libvirt saves this file with mode 0600
    chmod 0600 %{_sysconfdir}/libvirt/qemu/networks/default.xml

    # Make sure libvirt picks up the new network defininiton
    mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
    touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :
fi

%posttrans daemon-config-network
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%if %{with_vzct}
%post daemon-vzct
/usr/sbin/modprobe vzevent
/bin/systemctl start vz.service >/dev/null 2>&1 ||:
%endif

%post daemon-config-nwfilter
restart_daemon=0
for dfile in %{_datadir}/libvirt/nwfilter/*.xml; do
  sfile=%{_sysconfdir}/libvirt/nwfilter/`basename $dfile`
  if [ ! -f "$sfile" ]; then
    cp "$dfile" "$sfile"
    # libvirt saves these files with mode 600
    chmod 600 "$sfile"
    restart_daemon=1
  fi
done
# Make sure libvirt picks up the new nwfilter defininitons
if [ $restart_daemon -eq 1 ]; then
  mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
  touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :
fi

%posttrans daemon-config-nwfilter
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :


%if %{with_qemu}
%pre daemon-driver-qemu
# We want soft static allocation of well-known ids, as disk images
# are commonly shared across NFS mounts by id rather than name; see
# https://fedoraproject.org/wiki/Packaging:UsersAndGroups
getent group kvm >/dev/null || groupadd -f -g 36 -r kvm
getent group qemu >/dev/null || groupadd -f -g 107 -r qemu
if ! getent passwd qemu >/dev/null; then
  if ! getent passwd 107 >/dev/null; then
    useradd -r -u 107 -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  else
    useradd -r -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  fi
fi
exit 0
%endif

%preun client

%systemd_preun libvirt-guests.service

%post client
%systemd_post libvirt-guests.service

%postun client
%systemd_postun libvirt-guests.service

%if %{with_lxc}
%pre login-shell
getent group virtlogin >/dev/null || groupadd -r virtlogin
exit 0
%endif

%files

%files docs
%doc AUTHORS ChangeLog.gz NEWS README README.md
%doc libvirt-docs/*

# API docs
%dir %{_datadir}/gtk-doc/html/libvirt/
%doc %{_datadir}/gtk-doc/html/libvirt/*.devhelp
%doc %{_datadir}/gtk-doc/html/libvirt/*.html
%doc %{_datadir}/gtk-doc/html/libvirt/*.png
%doc %{_datadir}/gtk-doc/html/libvirt/*.css


%files daemon

%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/

%{_unitdir}/libvirtd.service
%{_unitdir}/libvirtd.socket
%{_unitdir}/libvirtd-ro.socket
%{_unitdir}/libvirtd-admin.socket
%{_unitdir}/libvirtd-tcp.socket
%{_unitdir}/libvirtd-tls.socket
%{_unitdir}/virt-guest-shutdown.target
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlogd-admin.socket
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_unitdir}/virtlockd-admin.socket
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlogd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlockd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlogd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlockd.conf
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%config(noreplace) %{_prefix}/lib/sysctl.d/60-libvirtd.conf

%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%dir %{_datadir}/libvirt/

%ghost %dir %{_localstatedir}/run/libvirt/

%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/


%dir %attr(0755, root, root) %{_libdir}/libvirt/
%dir %attr(0755, root, root) %{_libdir}/libvirt/connection-driver/
%dir %attr(0755, root, root) %{_libdir}/libvirt/lock-driver
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/lockd.so

%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug
%{_datadir}/augeas/lenses/virtlogd.aug
%{_datadir}/augeas/lenses/tests/test_virtlogd.aug
%{_datadir}/augeas/lenses/virtlockd.aug
%{_datadir}/augeas/lenses/tests/test_virtlockd.aug
%{_datadir}/augeas/lenses/libvirt_lockd.aug
%if %{with_qemu}
%{_datadir}/augeas/lenses/tests/test_libvirt_lockd.aug
%endif

%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%{_datadir}/polkit-1/rules.d/50-libvirt.rules

%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/

%attr(0755, root, root) %{_libexecdir}/libvirt_iohelper

%attr(0755, root, root) %{_sbindir}/libvirtd
%attr(0755, root, root) %{_sbindir}/virtlogd
%attr(0755, root, root) %{_sbindir}/virtlockd

%{_mandir}/man8/libvirtd.8*
%{_mandir}/man8/virtlogd.8*
%{_mandir}/man8/virtlockd.8*
%{_mandir}/man7/virkey*.7*

%files daemon-config-network
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml

%files daemon-config-nwfilter
%dir %{_datadir}/libvirt/nwfilter/
%{_datadir}/libvirt/nwfilter/*.xml
%ghost %{_sysconfdir}/libvirt/nwfilter/*.xml

%files daemon-driver-interface
%{_libdir}/%{name}/connection-driver/libvirt_driver_interface.so

%files daemon-driver-network
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%ghost %dir %{_localstatedir}/run/libvirt/network/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%attr(0755, root, root) %{_libexecdir}/libvirt_leaseshelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_network.so

%if %{with_firewalld_zone}
%{_prefix}/lib/firewalld/zones/libvirt.xml
%endif

%files daemon-driver-nodedev
%{_libdir}/%{name}/connection-driver/libvirt_driver_nodedev.so

%files daemon-driver-nwfilter
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%ghost %dir %{_localstatedir}/run/libvirt/network/
%{_libdir}/%{name}/connection-driver/libvirt_driver_nwfilter.so

%if %{with_secret}
%files daemon-driver-secret
%{_libdir}/%{name}/connection-driver/libvirt_driver_secret.so
%endif

%files daemon-driver-storage

%files daemon-driver-storage-core
%if %{with_storage_misc}
%attr(0755, root, root) %{_libexecdir}/libvirt_parthelper
%endif
%{_libdir}/%{name}/connection-driver/libvirt_driver_storage.so
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_fs.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_fs.so

%if %{with_storage_misc}
%files daemon-driver-storage-disk
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_disk.so

%files daemon-driver-storage-logical
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_logical.so

%files daemon-driver-storage-scsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_scsi.so

%files daemon-driver-storage-iscsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi.so

%files daemon-driver-storage-mpath
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_mpath.so
%endif

%if %{with_storage_iscsi_direct}
%files daemon-driver-storage-iscsi-direct
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi-direct.so
%endif

%if %{with_storage_gluster}
%files daemon-driver-storage-gluster
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_gluster.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_gluster.so
%endif

%if %{with_storage_rbd}
%files daemon-driver-storage-rbd
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_rbd.so
%endif

%if %{with_storage_sheepdog}
%files daemon-driver-storage-sheepdog
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_sheepdog.so
%endif

%if %{with_storage_zfs}
%files daemon-driver-storage-zfs
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_zfs.so
%endif

%if %{with_storage_vstorage}
%files daemon-driver-storage-vstorage
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_vstorage.so
%endif

%if %{with_qemu}
%files daemon-driver-qemu
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu-lockd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%ghost %dir %{_localstatedir}/run/libvirt/qemu/
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%{_libdir}/%{name}/connection-driver/libvirt_driver_qemu.so
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/swtpm/
%dir %attr(0711, root, root) %{_localstatedir}/log/swtpm/libvirt/qemu/
%endif

%if %{with_lxc}
%files daemon-driver-lxc
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%ghost %dir %{_localstatedir}/run/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%attr(0755, root, root) %{_libexecdir}/libvirt_lxc
%{_libdir}/%{name}/connection-driver/libvirt_driver_lxc.so
%endif

%if %{with_libxl}
%files daemon-driver-libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl-lockd.conf
%{_datadir}/augeas/lenses/libvirtd_libxl.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%ghost %dir %{_localstatedir}/run/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%{_libdir}/%{name}/connection-driver/libvirt_driver_libxl.so
%endif

%if %{with_vbox}
%files daemon-driver-vbox
%{_libdir}/%{name}/connection-driver/libvirt_driver_vbox.so
%endif

%if %{with_vz}
%files daemon-driver-vz
%{_libdir}/%{name}/connection-driver/libvirt_driver_vz.so
%endif

%if %{with_vzct}
%files daemon-driver-vzct
%defattr(-, root, root)
%{_libdir}/%{name}/connection-driver/libvirt_driver_vzct.so
%endif

%if %{with_qemu_tcg}
%files daemon-qemu
%endif

%if %{with_qemu_kvm}
%files daemon-kvm
%endif

%if %{with_lxc}
%files daemon-lxc
%endif

%if %{with_libxl}
%files daemon-xen
%endif

%if %{with_vbox}
%files daemon-vbox
%endif

%if %{with_vz}
%files daemon-vz
%endif

%if %{with_vzct}
%files daemon-vzct
%defattr(-, root, root)
%endif

%if %{with_sanlock}
%files lock-sanlock
    %if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu-sanlock.conf
    %endif
    %if %{with_libxl}
%config(noreplace) %{_sysconfdir}/libvirt/libxl-sanlock.conf
    %endif
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/sanlock.so
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0770, root, sanlock) %{_localstatedir}/lib/libvirt/sanlock
%{_sbindir}/virt-sanlock-cleanup
%{_mandir}/man8/virt-sanlock-cleanup.8*
%attr(0755, root, root) %{_libexecdir}/libvirt_sanlock_helper
%endif

%files client
%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1*
%{_mandir}/man1/virt-host-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_bindir}/virt-host-validate

%{_datadir}/systemtap/tapset/libvirt_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%if %{with_qemu}
%{_datadir}/systemtap/tapset/libvirt_qemu_probes*.stp
%endif

%if %{with_bash_completion}
%{_datadir}/bash-completion/completions/virsh
%endif


%{_unitdir}/libvirt-guests.service
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%attr(0755, root, root) %{_libexecdir}/libvirt-guests.sh

%files libs -f %{name}.lang
%license COPYING COPYING.LESSER
%config(noreplace) %{_sysconfdir}/libvirt/libvirt.conf
%config(noreplace) %{_sysconfdir}/libvirt/libvirt-admin.conf
%{_libdir}/libvirt.so.*
%{_libdir}/libvirt-qemu.so.*
%{_libdir}/libvirt-lxc.so.*
%{_libdir}/libvirt-admin.so.*
%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/

%{_datadir}/libvirt/schemas/domainblockexport.rng
%{_datadir}/libvirt/schemas/domainblocksnapshot.rng
%{_datadir}/libvirt/schemas/basictypes.rng
%{_datadir}/libvirt/schemas/capability.rng
%{_datadir}/libvirt/schemas/cputypes.rng
%{_datadir}/libvirt/schemas/domain.rng
%{_datadir}/libvirt/schemas/domaincaps.rng
%{_datadir}/libvirt/schemas/domaincheckpoint.rng
%{_datadir}/libvirt/schemas/domaincommon.rng
%{_datadir}/libvirt/schemas/domainsnapshot.rng
%{_datadir}/libvirt/schemas/interface.rng
%{_datadir}/libvirt/schemas/network.rng
%{_datadir}/libvirt/schemas/networkcommon.rng
%{_datadir}/libvirt/schemas/networkport.rng
%{_datadir}/libvirt/schemas/nodedev.rng
%{_datadir}/libvirt/schemas/nwfilter.rng
%{_datadir}/libvirt/schemas/nwfilter_params.rng
%{_datadir}/libvirt/schemas/nwfilterbinding.rng
%{_datadir}/libvirt/schemas/secret.rng
%{_datadir}/libvirt/schemas/storagecommon.rng
%{_datadir}/libvirt/schemas/storagepool.rng
%{_datadir}/libvirt/schemas/storagepoolcaps.rng
%{_datadir}/libvirt/schemas/storagevol.rng

%{_datadir}/libvirt/cpu_map/*.xml

%{_datadir}/libvirt/test-screenshot.png

%files admin
%{_mandir}/man1/virt-admin.1*
%{_bindir}/virt-admin
%if %{with_bash_completion}
%{_datadir}/bash-completion/completions/virt-admin
%endif

%if %{with_bash_completion}
%files bash-completion
%{_datadir}/bash-completion/completions/vsh
%endif

%if %{with_wireshark}
%files wireshark
%{wireshark_plugindir}/libvirt.so
%endif

%files nss
%{_libdir}/libnss_libvirt.so.2
%{_libdir}/libnss_libvirt_guest.so.2

%if %{with_lxc}
%files login-shell
%attr(4750, root, virtlogin) %{_bindir}/virt-login-shell
%config(noreplace) %{_sysconfdir}/libvirt/virt-login-shell.conf
%{_mandir}/man1/virt-login-shell.1*
%endif

%files devel
%{_libdir}/libvirt.so
%{_libdir}/libvirt-admin.so
%{_libdir}/libvirt-qemu.so
%{_libdir}/libvirt-lxc.so
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/libvirt-domain-backup.h
%{_includedir}/libvirt/virterror.h
%{_includedir}/libvirt/libvirt.h
%{_includedir}/libvirt/libvirt-admin.h
%{_includedir}/libvirt/libvirt-common.h
%{_includedir}/libvirt/libvirt-domain.h
%{_includedir}/libvirt/libvirt-domain-checkpoint.h
%{_includedir}/libvirt/libvirt-domain-snapshot.h
%{_includedir}/libvirt/libvirt-event.h
%{_includedir}/libvirt/libvirt-host.h
%{_includedir}/libvirt/libvirt-interface.h
%{_includedir}/libvirt/libvirt-network.h
%{_includedir}/libvirt/libvirt-nodedev.h
%{_includedir}/libvirt/libvirt-nwfilter.h
%{_includedir}/libvirt/libvirt-secret.h
%{_includedir}/libvirt/libvirt-storage.h
%{_includedir}/libvirt/libvirt-stream.h
%{_includedir}/libvirt/libvirt-qemu.h
%{_includedir}/libvirt/libvirt-lxc.h
%{_libdir}/pkgconfig/libvirt.pc
%{_libdir}/pkgconfig/libvirt-admin.pc
%{_libdir}/pkgconfig/libvirt-qemu.pc
%{_libdir}/pkgconfig/libvirt-lxc.pc

%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-admin-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml


%changelog
* Fri Jun 11 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.119.2
- FIXUP: qemu: don't access vcmmd in session driver #PSBM-130586

* Tue Apr 27 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.119.1
- FIXUP: Fix for bug #PSBM-128906

* Thu Apr 22 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.119
- FIXUP: qemu: fix typo in virDomainDefMarkExplicitBacking #VSTOR-43080

* Fri Apr 16 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.118
- qemu: notify vcmmd of node/vcpu pinning #PSBM-126679

* Thu Apr 15 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.117
- FIXUP: fix vstorage tmp link cleanup #PSBM-127546

* Wed Apr 14 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.116
- nwfilter: don't add symmetric record for policy rule #PSBM-126688
- FIXUP: update inactive config on pull completion #VSTOR-42858

* Thu Apr 08 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.115
- FIXUP: add missing pieces for vz backup API docs #PSBM-128036

* Wed Apr 07 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.114
- qemu: acquire job to handle agent disconnection #PSBM-127753

* Mon Apr 05 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.113
- vzct: add ip address to venet0 schema
- vzct: dump ip info for interfaces #PSBM-106470
- vzct: support setting net interface ips on define
- upgrade: support ethernet net type #PSBM-127606

* Tue Mar 30 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.112
- FIXUP: qemu: allow relative memory guarantee value 0 #PSBM-127633

* Mon Mar 29 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.111
- security: handle chown EACCES on readonly cifs mount #PSBM-127546

* Fri Mar 26 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.110
- FIXUP: rename to VCMMD_MEMGUARANTEE_BYTES #PSBM-127214

* Thu Mar 25 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.109
- qemu: monitor: add qemuMonitorBlockDirtyBitmapRemoveBusy
- FIXUP: qemu: virDomainBlockExportName: adapt to abort on OOM
- FIXUP: qemuDomainBlockExportCancel: simplify memory managment
- util: add virTimeBackOffWaitUnlocked
- backup: qemu: retry bitmap deletion while it is used by nbd #PSBM-126896
- FIXUP: qemu: modernize memory mgmt in qemuBlockSnapshotStop
- qemu: add qemuMonitorJSONBlockdevDelBusy
- backup: qemu: retry fleece node deletion while it is used by nbd
- vstorage migration: cleanup precreated src tmp deltas #PSBM-123432
- FIXUP: use qemuDomainObjEnterMonitorAsync inside async job
- FIXUP: reduce scope for logManager var
- upgrade: drain chardev's pipes #PSBM-108071

* Thu Mar 18 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.108
- misc: add blockjob type for block snapshot job #PSBM-126433

* Tue Mar 16 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.107
- security: take lock only if attributes are to be changed #PSBM-127003
- security: don't restore labels for readonly and shared images on errors
- qemu: fix noisy error for domain with image on readonly FS

* Thu Mar 11 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.106
- qemu/api: support min_guarantee as fraction of balloon #PSBM-126684

* Wed Mar 03 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.105
- vzct: Support disk resize for active CT #PSBM-122525
- qemu: detect block node names after attaching a disk #VSTOR-40911

* Tue Mar 02 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.104
- DROP: upgrade: make correct reconnection of upgrade
- DROP: pull: qemu: block snapshots basic implementation
- DROP: pull: qemu: load bitmaps on domain start
- DROP: pull: qemu: add exportable paused start
- DROP: qemu: add exec with true streams
- DROP: api/qemu: add move nvram API
- DROP: qemu: support interactive exec #PSBM-91739
- DROP: exec: provide tty params on exec when possible
- DROP: exec: handle client window size change when interactive
- DROP: exec: restore std streams' flags on become foreground #PSBM-91602 #PSBM-93755
- DROP: debug: print 'thr a a bt' in log when taking some mutex takes much time
- DROP: qemu: fix race on legacy block completion and quering stats
- DROP: qemu: sync backing chain update and completed blockjob #VSTOR-28575 #VSTOR-34322
- DROP: vzct 2: add basic structure and listing
- DROP: vzct 2: implement define
- DROP: xml: add venet0 network interface type
- DROP: doc: adopt README.md for Virtuozzo
- DROP: vzct 2: intoduce migration
- DROP: vzct 2: support memory guarantees #PSBM-106482
- DROP: qemu: add vcmmd support #PSBM-106483
- DROP: vzct 2: support jobs during migration #PSBM-107444
- DROP: vzct 2: drop job on client disconnection during migration
- DROP: vstorage migration: execute src migration cleanup in cleanup thread
- DROP: qemu: don't leave descriptors in fdsets after process startup #PSBM-108299
- DROP: vstorage migration: disable API that can clash with tmp snapshot
- DROP: qemu: handle ibpb and virt-ssbd on Intel for u15 #PSBM-121810
- DROP: rpc: document deleted EXT_PROC_DOMAIN_BLOCK_CHECKPOINT_X_SWITCH = 10 #PSBM-122230
- DROP: qemu: support min_gurantee in virDomain{Set,Get}MemoryParameters #PSBM-121895
- DROP: qemu: turn on postcopy to migrate bitmaps #PSBM-100171
- DROP: FIXUP: qemu: fix incorrect job cleanup of p2p migration #PSBM-123687
- DROP: FIXUP: don't update sync block jobs from another thread #PSBM-123582
- DROP: FIXUP: vstorage: load bitmaps from base image for tmp snapshot #PSBM-123771
- DROP: REVERT: qemu: handle ibpb and virt-ssbd on Intel for u15 #PSBM-123539
- DROP: FIXUP: fix esx driver build
- DROP: FIXUP: fix refcount in qemu upgrade reconnection #PSBM-123849
- DROP: FIXUP: api: add stub for virDomainBlockCheckpointXSwitch #PSBM-124242
- DROP: FIXUP: add missing option name in  x-move-nvram docs
- DROP: FIXUP: document --reuse-external option of x-move-nvram
- DROP: FIXUP: clarify usage of VIR_DOMAIN_START_X_EXPORTABLE
- DROP: doc: document virsh commands for block snaphots/exports #PSBM-122231
- DROP: FIXUP: add Artem fixes
- DROP: vstorage: remove build time checks for runtime binaries
- DROP: FIXUP: lxc: handle vzct specific venet0 net type
- DROP: FIXUP: update build instructions in README.md
- DROP: FIXUP: exec: add more debug prints to virsh
- DROP: FIXUP: exec: fix error reporting in virsh
- DROP: FIXUP: exec: don't use virExecMonitorTerminate on ^] (escape char)
- DROP: FIXUP: exec: rework handling inner errors and IO errors #PSBM-124313 #PSBM-124629
- DROP: FIXUP: exec: make sure stdin is fully transmitted in virsh
- DROP: exec: don't print errors to stderr #PSBM-124629
- DROP: FIXUP: don't print errors to stderr
- DROP: FIXUP: qemu: check stderr is NULL in terminal mode
- DROP: FIXUP: virsh: simplify terminal check
- DROP: FIXUP: virsh: don't use stderr stream in terminal mode
- DROP: FIXUP: vzct 2: check VIR_MIGRATE_PARAM_DEST_XML in p2p also
- DROP: FIXUP: vzct 2: support disk copy options #PSBM-121242
- DROP: FIXUP: qemu: unlock VM on unregister in vcmmd #PSBM-125105
- upgrade: make correct reconnection of upgrade
- DROP: vzct: Ceiling memory size from Kb to Mb
- DROP: FIXUP: vzct: add missing unlock on error path
- DROP: docs: document backup API #PSBM-124261
- DROP: Edits for backup/restore API texts #PSBM-124261
- DROP: Edits for backup/restore API texts #PSBM-124261
- DROP: Edits based on comments
- DROP: qemu: Don't request nested entries from qemuMonitorQueryNamedBlockNodes
- DROP: FIXUP: remove trailing blanks in formatvzbackups.html.in
- DROP: FIXUP: don't crash in unpriviledged mode on shutdown #PSBM-125607
- DROP: vzct: Support setting IO limits for active CT #PSBM-122519
- DROP: FIXUP: don't fail if we messup with bitmaps #VSTOR-40845
- DROP: FIXUP: remove pinning out of vcmmd scope
- DROP: FIXUP: don't notify vcmmd about hotplug/hotunplug
- DROP: FIXUP: qemuProcessVcmmdUpdate get new values as args
- DROP: qemu: open code qemuProcessVcmmdConfigSet
- DROP: FIXUP: qemu: support min_gurantee in virDomain{Set,Get}MemoryParameters
- DROP: FIXUP: factor out qemuProcessLoadBitmaps
- DROP: FIXUP: rollback migration if bitmaps are not copied
- DROP: FIXUP: load bitmaps after postcopy is finished #PSBM-125776
- DROP: FIXUP: syntax check for vzct iotune patch
- DROP: FIXUP: fix vstorage automake macro
- DROP: FIXUP: use lazy_refcount=on for backup reverse delta #PSBM-123438
- DROP: FIXUP: fix indendation
- DROP: FIXUP: initialize virThreadDebug explicitly
- pull: qemu: block snapshots basic implementation
- pull: qemu: load bitmaps on domain start
- pull: qemu: add exportable paused start
- qemu: add exec with true streams
- api/qemu: add move nvram API
- qemu: support interactive exec #PSBM-91739
- exec: provide tty params on exec when possible
- exec: handle client window size change when interactive
- exec: restore std streams' flags on become foreground #PSBM-91602 #PSBM-93755
- debug: print 'thr a a bt' in log when taking some mutex takes much time
- qemu: fix race on legacy block completion and quering stats
- qemu: sync backing chain update and completed blockjob #VSTOR-28575 #VSTOR-34322
- vzct 2: add basic structure and listing
- vzct 2: implement define
- xml: add venet0 network interface type
- doc: adopt README.md for Virtuozzo
- vzct 2: intoduce migration
- vzct 2: support memory guarantees #PSBM-106482
- qemu: add vcmmd support #PSBM-106483
- vzct 2: support jobs during migration #PSBM-107444
- vzct 2: drop job on client disconnection during migration
- vstorage migration: execute src migration cleanup in cleanup thread
- qemu: don't leave descriptors in fdsets after process startup #PSBM-108299
- vstorage: load bitmaps from base image for tmp snapshot #PSBM-123771
- vstorage migration: disable API that can clash with tmp snapshot
- api: add stub for virDomainBlockCheckpointXSwitch
- qemu: support min_gurantee in virDomain{Set,Get}MemoryParameters #PSBM-121895
- qemu: turn on postcopy to migrate bitmaps #PSBM-100171
- doc: document virsh commands for block snaphots/exports #PSBM-122231
- vstorage: remove build time checks for runtime binaries
- exec: don't print errors to stderr #PSBM-124629
- docs: document backup API #PSBM-124261
- qemu: Don't request nested entries from qemuMonitorQueryNamedBlockNodes
- vzct: Support setting IO limits for active CT #PSBM-122519

* Tue Mar 02 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.103
- FIXUP: initialize virThreadDebug explicitly
- util: add hanging process debugging #PSBM-126062

* Mon Mar 01 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.102
- FIXUP: use lazy_refcount=on for backup reverse delta #PSBM-123438
- qemu: better cluster size for tmp deltas on vstorage migration #PSBM-123434
- FIXUP: fix indendation

* Thu Feb 25 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.101
- FIXUP: factor out qemuProcessLoadBitmaps
- FIXUP: rollback migration if bitmaps are not copied
- FIXUP: load bitmaps after postcopy is finished #PSBM-125776
- FIXUP: syntax check for vzct iotune patch
- FIXUP: fix vstorage automake macro

* Wed Feb 24 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.100
- qemu: don't error if cannot find disk by alias #PSBM-125811
- FIXUP: remove pinning out of vcmmd scope
- FIXUP: don't notify vcmmd about hotplug/hotunplug
- FIXUP: qemuProcessVcmmdUpdate get new values as args
- qemu: open code qemuProcessVcmmdConfigSet
- FIXUP: qemu: support min_gurantee in virDomain{Set,Get}MemoryParameters
- qemu: vcmmd support for setting balloon #PSBM-123145

* Thu Feb 18 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.99
- vzct: Support setting IO limits for active CT #PSBM-122519
- tools: treat 'in shutdown' etc as shutdown finished #VSTOR-37835
- FIXUP: don't fail if we messup with bitmaps #VSTOR-40845

* Thu Feb 11 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.98
- qemu: capabilities: Add capability for the 'flat' argument of 'query-named-block-nodes'
- qemu: monitor: Refactor variable cleanup in qemuMonitorJSONQueryNamedBlockNodes
- qemu: monitor: Add 'flat' parameter for qemuMonitorJSONQueryNamedBlockNodes
- qemu: Don't request nested entries from qemuMonitorQueryNamedBlockNodes #PSBM-125515
- FIXUP: remove trailing blanks in formatvzbackups.html.in
- FIXUP: don't crash in unpriviledged mode on shutdown #PSBM-125607

* Tue Feb 09 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.97
- docs: document backup API #PSBM-124261
- Edits for backup/restore API texts #PSBM-124261
- Edits for backup/restore API texts #PSBM-124261
- Edits based on comments
- vzct: Support setting memory guarantee for active CT #PSBM-122518

* Fri Feb 05 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.96
- vzct: Support setting memory for active CT #PSBM-122489
- vzct: Ceiling memory size from Kb to Mb
- vzct: Support setting cpu num for active CT #PSBM-122517
- FIXUP: vzct: add missing unlock on error path

* Wed Feb 03 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.95
- util: add access check for hooks to fix running as non-root
- util: fix accessibility check for hook directory
- api: fix documentation typo
- misc: add bypass cache flag for block snapshot creation #PSBM-124764

* Mon Feb 01 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.94
- FIXUP: qemu: unlock VM on unregister in vcmmd #PSBM-125105

* Fri Jan 29 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.93
- FIXUP: vzct 2: check VIR_MIGRATE_PARAM_DEST_XML in p2p also
- FIXUP: vzct 2: support disk copy options #PSBM-121242

* Wed Jan 27 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.92
- daemon: switch off autoshutdown #VSTOR-40335

* Wed Jan 27 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.91
- FIXUP: don't print errors to stderr
- FIXUP: qemu: check stderr is NULL in terminal mode
- FIXUP: virsh: simplify terminal check
- FIXUP: virsh: don't use stderr stream in terminal mode
- vzct 2: implement exec API #PSBM-106206
- virsh: don't call virDomainGetGuestInfo for vzct interactive exec

* Wed Jan 20 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.90
- FIXUP: exec: add more debug prints to virsh
- FIXUP: exec: fix error reporting in virsh
- FIXUP: exec: don't use virExecMonitorTerminate on ^] (escape char)
- FIXUP: exec: rework handling inner errors and IO errors #PSBM-124313 #PSBM-124629
- FIXUP: exec: make sure stdin is fully transmitted in virsh
- exec: don't print errors to stderr #PSBM-124629

* Wed Jan 20 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.89
- vstorage: remove build time checks for runtime binaries
- FIXUP: lxc: handle vzct specific venet0 net type
- virsh: fix Vstorage support reporting
- FIXUP: update build instructions in README.md

* Tue Jan 12 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.88
- vz: fix after Parallels to Virtuozzo rename #PSBM-124533

* Mon Jan 11 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.87
- DROP: upgrade: support local p2p migration
- src: adopt to VIR_DRV_SUPPORTS_FEATURE return -1
- libxl: adopt to VIR_DRV_SUPPORTS_FEATURE return -1
- qemu: adopt to VIR_DRV_SUPPORTS_FEATURE return -1
- src: don't hide error in VIR_DRV_SUPPORTS_FEATURE
- qemu: build fix for 910b94df
- src: fix resource leak introduced in d4439a6b8
- upgrade: support local p2p migration
- FIXUP: add missing option name in  x-move-nvram docs
- FIXUP: document --reuse-external option of x-move-nvram
- FIXUP: clarify usage of VIR_DOMAIN_START_X_EXPORTABLE
- doc: document virsh commands for block snaphots/exports #PSBM-122231
- FIXUP: add Artem fixes

* Mon Dec 28 2020 Nick Shyrokovskiy <nshyrokovskiy@gmail.com> - vz-5.6.0-10.vz7.86
- FIXUP: api: add stub for virDomainBlockCheckpointXSwitch #PSBM-124242

* Wed Dec 23 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.85
- FIXUP: fix refcount in qemu upgrade reconnection #PSBM-123849

* Tue Dec 22 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.84
- docker: We cannot create second network with driver 'null' #PSBM-123794
- docker: Connection docker network to selected windows network adapter #PSBM-123794
- FIXUP: fix esx driver build
- REVERT: don't build esx #PSBM-123960

* Fri Dec 18 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.83
- docker: Will set negative value only if it needs #PSBM-108327
- docker: fixup: Set correct type of memory var #PSBM-108327
- FIXUP: don't update sync block jobs from another thread #PSBM-123582
- FIXUP: vstorage: load bitmaps from base image for tmp snapshot #PSBM-123771
- REVERT: qemu: handle ibpb and virt-ssbd on Intel for u15 #PSBM-123539

* Wed Dec 16 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.82
- DROP: pull: export bitmap
- DROP: pull: qemu: add option to export last checkpoint
- DROP: nwfilter: use vfork to fasten spawn of {ip,eb]tables commands
- DROP: qemu: support new qemu without nbd-server-add-bitmap command #VSTOR-27428
- DROP: FIXUP: pull: export bitmap #VSTOR-39135
- DROP: FIXUP: fix reading from pipes in virCommandRunFast #PSBM-123565
- DROP: FIXUP: kill process if reaping failed
- DROP: FIXUP: fix copy offset in previous commit #PSBM-123565
- DROP: FIXUP: null terminate strings in case of error in virCommandRunFastRead
- DROP: FIXUP: use VIR_REALLOC_N instead of VIR_RESIZE_N
- pull: export bitmap
- pull: qemu: add option to export last checkpoint
- nwfilter: use vfork to fasten spawn of {ip,eb]tables commands
- qemu: support new qemu without nbd-server-add-bitmap command #VSTOR-27428
- docker: Support network bandwidth limits for containers #PSBM-108327
- docker: Use negative value for removing network bandwidth limit #PSBM-108327
- FIXUP: qemu: fix incorrect job cleanup of p2p migration #PSBM-123687

* Wed Dec 09 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.81
- FIXUP: fix copy offset in previous commit #PSBM-123565
- FIXUP: null terminate strings in case of error in virCommandRunFastRead
- FIXUP: use VIR_REALLOC_N instead of VIR_RESIZE_N

* Wed Dec 09 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.80
- FIXUP: fix reading from pipes in virCommandRunFast #PSBM-123565
- FIXUP: kill process if reaping failed

* Tue Dec 08 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.79
- FIXUP: pull: export bitmap #VSTOR-39135

* Tue Dec 08 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.78
- DROP: conf: add 'format' attribute to domain/os/nvram element
- DROP: pull: api: add driver based implementation
- DROP: api,qemu: add latency histogram
- DROP: qemu: add exec with true streams
- DROP: Drop x- from x-block-latency-histogram-set monitor command
- DROP: api/qemu: add move nvram API
- DROP: qemu: support interactive exec
- DROP: libvirt: add new virDomainCommandXSetParams API
- DROP: api/qemu: add pause/resume for blockjobs
- DROP: qemu: turn on write-blocking for driver-mirror by default
- DROP: vzct 2: add basic structure and listing
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- DROP: vzct 2: implement start/stop
- DROP: vzct 2: support cloud init cdrom
- DROP: vzct 2: add vzctDomainHasManagedSaveImage stub
- DROP: vzct 2: add misc API
- DROP: vzct 2: support stats API
- DROP: vzct 2: support snapshots
- DROP: vzct 2: intoduce migration
- DROP: vzct 2: mark supported xml parts in domain/snapshot docs
- DROP: qemu: add vcmmd support
- DROP: vzct 2: add jobs support for everything except migration
- DROP: vzct 2: add lifecycle events
- DROP: vzct 2: support getting stats for migration
- DROP: vzct 2: support aborting domain job API
- DROP: qemu: migration: add cookie parts for vstorage chardevs
- DROP: qemu: monitor: add option to override backend in qemuMonitorChangeCharDev
- DROP: qemu: migration: support changing chardev backend with virtlogd
- DROP: qemu: migration: detect shared vstorage chardevs
- DROP: vstorage: support migrating with chardevs on vstorage
- DROP: qemu: add vstorage chardev tmpfile names to status file
- DROP: qemu: cleanup up vstorage chardevs after libvirtd crash
- DROP: qemu: drain file chardevs on domain process stop
- DROP: vstorage migration: add vstorage disks info to cookie
- DROP: qemu: add vstorage snapshot utility functions
- DROP: vstorage migration: add vstorage snapshot commit
- DROP: vstorage migration: main patch
- DROP: vstorage migration: track valid temporary snapshot
- DROP: vstorage migration: resolve valid tmp snapshot on domain start
- DROP: vstorage migration: disable API that can clash with tmp snapshot
- DROP: vstorage migration: keep snapshot info in status
- DROP: qemu: cleanup tmp snapshot
- DROP: vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- DROP: vstorage migration: handle completed tmp snapshot commit on reconnect
- DROP: FIXUP: conf: add 'format' attribute to domain/os/nvram element
- DROP: FIXUP: qemu: add vstorage snapshot utility functions
- DROP: qemu: add nvram block job support
- DROP: FIXUP: vstorage migration: add vstorage snapshot commit
- DROP: FIXUP: vstorage migration: main patch
- DROP: FIXUP: vstorage migration: track valid temporary snapshot
- DROP: FIXUP: vstorage migration: resolve valid tmp snapshot on domain start
- DROP: FIXUP: vstorage migration: disable API that can clash with tmp snapshot
- DROP: FIXUP: qemu: cleanup tmp snapshot
- DROP: FIXUP: api/qemu: add move nvram API
- DROP: FIXUP: vstorage migration: handle completed tmp snapshot commit on reconnect
- DROP: qemu: support nvram block job on reconnect
- DROP: FIXUP: vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- DROP: FIXUP: support non-qcow2 images in vstorage disks migration
- DROP: FIXUP: make qemuDomainTmpSnapshotDecipher non static
- DROP: Edits to our method descriptions; fixes
- DROP: Edits to our method descriptions; fixes
- DROP: Edits to virsh commands related to our methods; A minor edit to nvramx description
- DROP: Edits to our XML descriptions
- DROP: qemu: support min_gurantee in virDomain{Set,Get}MemoryParameters
- DROP: FIXUP: vzct 2: fix API introduced in version
- DROP: REVERT: qemu: turn on write-blocking for driver-mirror by default
- DROP: FIXUP: docker: fix trailing space
- DROP: FIXUP: vzct 2: factor out vzctDomainStartFull
- DROP: FIXUP: add retval to qemuProcessVcmmdUpdate
- DROP: FIXUP: handle qemuProcessVcmmdUpdate error in qemuDomainSetMemoryParameters
- DROP: FIXUP: precreate state dir
- DROP: FIXUP: fix for NULL chardev priv of backcompat console
- DROP: FIXUP: fix non-vcmmd build
- DROP: FIXUP: qemu: migration: add cookie parts for vstorage chardevs
- DROP: FIXUP: qemu: monitor: add option to override backend in qemuMonitorChangeCharDev
- DROP: FIXUP: qemu: migration: detect shared vstorage chardevs
- DROP: FIXUP: qemu: migration: support changing chardev backend with virtlogd
- DROP: FIXUP: vstorage: support migrating with chardevs on vstorage
- DROP: FIXUP: qemu: add vstorage chardev tmpfile names to status file
- DROP: FIXUP: qemu: drain file chardevs on domain process stop
- DROP: FIXUP: use shallow copy for tmp snapshot on vstorage
- DROP: FIXUP: vstorage migration: optimize snapshot image
- DROP: FIXUP: use 1MiB cluster size etc on source for vstorage tmp snapshot
- conf: add 'format' attribute to domain/os/nvram element
- pull: api: add driver based implementation
- api,qemu: add latency histogram
- qemu: add exec with true streams
- api/qemu: add move nvram API
- qemu: support interactive exec
- libvirt: add new virDomainCommandXSetParams API
- api/qemu: add pause/resume for blockjobs
- vzct 2: add basic structure and listing
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: implement start/stop
- vzct 2: support cloud init cdrom
- vzct 2: add vzctDomainHasManagedSaveImage stub
- vzct 2: add misc API
- vzct 2: support stats API
- vzct 2: support snapshots
- vzct 2: intoduce migration
- vzct 2: mark supported xml parts in domain/snapshot docs
- qemu: add vcmmd support
- vzct 2: add jobs support for everything except migration
- vzct 2: add lifecycle events
- vzct 2: support getting stats for migration
- vzct 2: support aborting domain job API
- qemu: migration: add cookie parts for vstorage chardevs
- qemu: monitor: add option to override backend in qemuMonitorChangeCharDev
- qemu: migration: support changing chardev backend with virtlogd
- qemu: migration: detect shared vstorage chardevs
- vstorage: support migrating with chardevs on vstorage
- qemu: add vstorage chardev tmpfile names to status file
- qemu: cleanup up vstorage chardevs after libvirtd crash
- qemu: drain file chardevs on domain process stop
- vstorage migration: add vstorage disks info to cookie
- qemu: add nvram block job support
- qemu: add vstorage snapshot utility functions
- vstorage migration: add vstorage snapshot commit
- vstorage migration: main patch
- vstorage migration: track valid temporary snapshot
- vstorage migration: resolve valid tmp snapshot on domain start
- vstorage migration: disable API that can clash with tmp snapshot
- vstorage migration: keep snapshot info in status
- qemu: cleanup tmp snapshot
- qemu: support nvram block job on reconnect
- vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- vstorage migration: handle completed tmp snapshot commit on reconnect
- qemu: support min_gurantee in virDomain{Set,Get}MemoryParameters
- docker: Check existence of image for domain definition and pulling image #PSBM-123097

* Mon Dec 07 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.77
- don't touch existing nwfilters on update #PSBM-105904
- REVERT: spec: keep existing nwfilters uuid on update

* Mon Dec 07 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.76
- FIXUP: vstorage migration: optimize snapshot image #PSBM-123411
- FIXUP: use 1MiB cluster size etc on source for vstorage tmp snapshot #PSBM-123416

* Fri Dec 04 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.75
- FIXUP: use shallow copy for tmp snapshot on vstorage #PSBM-123396

* Thu Dec 03 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.74
- FIXUP: qemu: migration: add cookie parts for vstorage chardevs
- qemu: support file chardev append option on hotplug/change
- qemu: support logfile option on chardev hotplug/change
- FIXUP: qemu: monitor: add option to override backend in qemuMonitorChangeCharDev
- FIXUP: qemu: migration: detect shared vstorage chardevs
- FIXUP: qemu: migration: support changing chardev backend with virtlogd
- FIXUP: vstorage: support migrating with chardevs on vstorage
- FIXUP: qemu: add vstorage chardev tmpfile names to status file
- FIXUP: qemu: drain file chardevs on domain process stop #PSBM-123148
- docker: Refactoring code with default cert path #PSBM-123097
- qemu: fix managed pr-helper tear down on chaning device media #PSBM-123337

* Mon Nov 30 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.73
- FIXUP: fix non-vcmmd build

* Mon Nov 30 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.72
- FIXUP: fix for NULL chardev priv of backcompat console #VSTOR-38939
- qemu: fix guest visible disk id if serial is long #VSTOR-38958

* Fri Nov 27 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.71
- FIXUP: precreate state dir #PSBM-123047

* Thu Nov 26 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.70
- docker: Don't use case-sensitive comparison #PSBM-122944
- docker: Optimization powershell scripts #PSBM-122944
- docker: Using sscanf with string memory allocation #PSBM-122944
- docker: Fix some error msgs #PSBM-122944
- docker: Add storagePoolLookupByVolume method #PSBM-122944
- docker: Add real refresh metadata for storage pool #PSBM-122944
- qemu: turn on postcopy to migrate bitmaps #PSBM-100171

* Tue Nov 24 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.69
- Fix for possibility to use inituser without initgroup #PSBM-122225
- docker: Fix adding of restart policy #PSBM-122225
- docker: Revert possibility to use cpushares=0 #PSBM-122225
- docker: Fix for correct work with process id #PSBM-122225
- docker: Style fix #PSBM-122225
- FIXUP: vzct 2: fix API introduced in version
- REVERT: qemu: turn on write-blocking for driver-mirror by default #PSBM-122688
- FIXUP: docker: fix trailing space
- docker: Split dockerContainerUpdate to dockerContainerUpdate and dockerContainerUpdateById #PSBM-122225
- docker: Add compatibility with 'virtsh edit' command #PSBM-122225
- FIXUP: vzct 2: factor out vzctDomainStartFull
- vzct 2: support autostarting domains #PSBM-121587
- FIXUP: add retval to qemuProcessVcmmdUpdate
- FIXUP: handle qemuProcessVcmmdUpdate error in qemuDomainSetMemoryParameters #PSBM-122883

* Fri Nov 20 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.68
- api: add VIR_DOMAIN_MEMORY_MIN_GUARANTEE_VZ_AUTO
- tools: support memtune --min-guarantee-auto-vz
- qemu: support min_gurantee in virDomain{Set,Get}MemoryParameters #PSBM-121895

* Thu Nov 19 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.67
- DROP: pull: introduce checkpoint switch API
- DROP: lib: provide error message in new blockjob event
- DROP: qemu: add exec with true streams
- DROP: Edits to our method descriptions; fixes PSBM-102691
- lib: provide error message in new blockjob event
- qemu: add exec with true streams
- Edits to our method descriptions; fixes PSBM-102691
- Edits to virsh commands related to our methods; A minor edit to nvramx description
- Edits to our XML descriptions
- rpc: document deleted EXT_PROC_DOMAIN_BLOCK_CHECKPOINT_X_SWITCH = 10 #PSBM-122230

* Tue Nov 17 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.66
- DROP: qemu: add option to process offloaded blockjob event ealier
- DROP: qemu: update legacy block job sync after offloading changes
- DROP: qemu: make latency work with legacy interface
- DROP: vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- DROP: vstorage migration: handle completed tmp snapshot commit on reconnect
- DROP: qemu: add nvram block job support
- DROP: qemu: support nvram block job on reconnect
- DROP: FIXUP: vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- DROP: vstorage migration: fix active block stats with tmp snapshot
- qemu: add option to process offloaded legacy blockjob event ealier #PSBM-121858
- qemu: reconnect: precreate legacy blockjobs
- qemu: remove extra block job finalize on reconnect
- qemu: remove stale cleanup in qemuProcessRefreshLegacyBlockjob
- qemu: add note for outdated legacy block job events
- qemu: use autoptr in qemuProcessRefreshLegacyBlockjobs
- qemu: refresh backing chain after block job reconnection
- qemu: move code that depends on backing chain appropriately
- qemu: fix race on legacy block completion and quering stats
- qemu: make latency work with legacy interface
- vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- vstorage migration: handle completed tmp snapshot commit on reconnect
- qemu: add nvram block job support
- qemu: support nvram block job on reconnect
- FIXUP: vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- vstorage migration: fix active block stats with tmp snapshot
- Edits to our method descriptions; fixes PSBM-102691
- Edits to our method descriptions; fixes PSBM-102691
- qemu: qemuDomainRenameCallback: fix sending false undefined event
- qemu: use auto memory freeing in qemuDomainRenameCallback
- qemu: rename: send events only on success
- qemu: rename: return instead of goto if no cleanup required
- qemu: remove duplicate code for removing remnant files
- qemu: rename: support renaming snapshots directory #PSBM-100720
- qemu: rename: support renaming checkpoints directory
- qemu: update name on reverting from snapshot
- qemu: rename: remove snapshot/checkpoint restriction
- qemu: remove possible garbage left from previous rename/undefine
- docker: Add support autostart feature #PSBM-122024
- docker: Refactoring for future changes #PSBM-122024
- docker: Get list for autostart domains #PSBM-122024
- docker: Set domain as not autostart by default #PSBM-122024
- docker: Add virDomainHasManagedSaveImage method and reboot default action #PSBM-122024

* Tue Nov 10 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.65
- vstorage migration: handle short time EBUSY on commit #PSBM-122012

* Mon Nov 09 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.64
- DROP: qemu: use job finish instead of discard on migration cleanup
- DROP: qemu: migration: detect shared vstorage chardevs
- DROP: vstorage migration: main patch
- DROP: vstorage migration: determine valid snapshot on crash/disconnections
- DROP: qemu: migration: fix missing owner on disconnection cleanup
- qemu: fix qemuMigrationSrcCleanup to use qemuMigrationJobFinish
- qemu: migration: detect shared vstorage chardevs
- vstorage migration: main patch
- vstorage migration: determine valid snapshot on crash/disconnections
- qemu: migration: fix missing owner on disconnection cleanup
- FIXUP: make qemuDomainTmpSnapshotDecipher non static
- vstorage migration: adopt qemuDomainGetStatsOneBlock to tmp snapshot
- vstorage migration: fix active block stats with tmp snapshot #PSBM-121042
- vstorage migration: fix inactive block stats with tmp snapshot #PSBM-121042
- docker: fix condition for list of storage pools

* Tue Nov 03 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.63
- qemu: handle ibpb and virt-ssbd on Intel for u15 #PSBM-121810
- docker: add compatibility of validation with current xml scheme #PSBM-121897
- FIXUP: conf: add 'format' attribute to domain/os/nvram element
- vstorage migration: add vstorage nvram info to cookie
- FIXUP: qemu: add vstorage snapshot utility functions
- qemu: add nvram block job support
- FIXUP: vstorage migration: add vstorage snapshot commit
- FIXUP: vstorage migration: main patch #PSBM-106202 #PSBM-121052
- FIXUP: vstorage migration: track valid temporary snapshot
- FIXUP: vstorage migration: resolve valid tmp snapshot on domain start
- FIXUP: vstorage migration: disable API that can clash with tmp snapshot
- vstorage migration: keep nvram tmp snapshot in status
- FIXUP: qemu: cleanup tmp snapshot #PSBM-106875
- FIXUP: api/qemu: add move nvram API
- FIXUP: vstorage migration: handle completed tmp snapshot commit on reconnect
- qemu: support nvram block job on reconnect
- FIXUP: vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- FIXUP: support non-qcow2 images in vstorage disks migration

* Tue Oct 27 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.62
- DROP: upgrade: support local p2p migration
- DROP: upgrade: vnc: make vnc upgrade possible
- DROP: upgrade: support for server backends for serial chardevs
- DROP: upgrade: close agent channel befor postcopy with release ram
- DROP: pull: qemu: block snapshots basic implementation
- DROP: pull: add autodelete option for creating block snapshots
- DROP: pull: stop exporting snapshot on snapshot autodelete
- DROP: pull: pull: add dirty bitmap on creating snapshot
- DROP: pull: add command to remove checkpoint
- DROP: api,qemu: add latency histogram
- DROP: pull: clean autodelete snapshots on daemon restart
- DROP: exec: kill orphans on client disconnect
- DROP: exec: kill orphans on migration destination
- DROP: qemu: support explicit disk backing in input
- DROP: conf: remove features unknown to qemu
- DROP: qemu: agent: log total tx/rx for streams
- DROP: debug: print 'thr a a bt' in log when taking some mutex takes much time
- DROP: qemu: migration: implement shared workaround
- DROP: qemu: handle host usb device add/del udev events
- DROP: qemu: wait blockjob finishing if it is absent in qemu
- DROP: FIXUP: pull: qemu: block snapshots basic implementation
- DROP: FIXUP: qemu: agent: log total tx/rx for streams
- DROP: FIXUP: api,qemu: add latency histogram
- DROP: FIXUP: upgrade: support local p2p migration
- DROP: vzct 2: add basic structure and listing
- DROP: FIXUP: qemu: support explicit disk backing in input
- DROP: FIXUP: conf: remove features unknown to qemu
- DROP: FIXUP: debug: print 'thr a a bt' in log when taking some mutex takes much time
- DROP: vzct 2: support stats API
- DROP: FIXUP: upgrade: vnc: make vnc upgrade possible
- DROP: FIXUP: qemu: wait blockjob finishing if it is absent in qemu
- DROP: FIXUP: don't lock VMs in event loop on closing connection
- DROP: vstorage migration: add vstorage disks info to cookie
- DROP: vstorage migration: execute src migration cleanup in cleanup thread
- DROP: qemu: use more precise args in qemuDomainSnapshotCreateInactiveExternal
- DROP: qemu: use more precise args in qemuDomainSnapshotCreateDiskActive
- DROP: vstorage migration: add vstorage snapshot commit
- DROP: vstorage migration: main patch
- DROP: vstorage migration: handle lossing connection to manager
- DROP: vstorage migration: support p2p
- DROP: vstorage migration: handle libvirtd crashes
- DROP: qemu: add vcmmd support
- DROP: vzct 2: add jobs support for everything except migration
- DROP: FIXUP: mark chardevs to be unplugged outside cmdline building
- DROP: FIXUP: prepare chardev plug/unplug functions to reuse
- DROP: qemu: migration: add cookie parts for vstorage chardevs
- DROP: qemu: migration: detect shared vstorage chardevs
- DROP: vstorage: support migrating with chardevs on vstorage
- DROP: qemu: cleanup up vstorage chardevs after libvirtd crash
- DROP: REVERT: d8d14ae vstorage migration: handle libvirtd crashes
- DROP: REVERT: 25cee97 vstorage migration: support p2p
- DROP: REVERT: 0069126 vstorage migration: handle lossing connection to manager
- DROP: REVERT: bdb9763 vstorage migration: main patch
- DROP: REVERT: 66bf3fc vstorage migration: add vstorage snapshot commit phase
- DROP: REVERT: be09fb5 vstorage migration: add vstorage snapshot commit
- DROP: REVERT: e73c697 qemu: use more precise args in qemuDomainSnapshotCreateDiskActive
- DROP: REVERT: a58cd6a qemu: use more precise args in qemuDomainSnapshotCreateInactiveExternal
- DROP: REVERT: 63a5ee1 qemu: use job finish instead of discard on migration cleanup
- DROP: REVERT: 966f7e5 vstorage migration: execute src migration cleanup in cleanup thread
- DROP: REVERT: 6a25c7a vstorage migration: introduce virDomainMigrateVstorageCommit
- DROP: REVERT: ec406d6 vstorage migration: add vstorage disks info to cookie
- DROP: vstorage migration: add vstorage snapshot commit
- DROP: vstorage migration: main patch
- DROP: vstorage migration: execute src migration cleanup in cleanup thread
- DROP: qemu: use job finish instead of discard on migration cleanup
- DROP: vstorage migration: track valid temporary snapshot
- DROP: vstorage migration: resolve valid tmp snapshot on domain start
- DROP: vstorage migration: disable API that can clash with tmp snapshot
- DROP: vstorage migration: keep snapshot info in status
- DROP: FIXUP: cleanup thread: add option to cleanup single VM
- DROP: FIXUP: qemu: enhance domain cleanup
- DROP: qemu: cleanup tmp snapshot
- DROP: FIXUP: qemu: migration: detect shared vstorage chardevs
- DROP: FIXUP: fix recent uninitialized var case
- DROP: FIXUP: take into account tmp snapshot in qemuBlockDiskDetectNodes
- DROP: FIXUP: don't call vzctl2_free_env_ids for NULL
- DROP: FIXUP: drop snapshot on its file unlink failure
- DROP: REVERT: qemu: wait blockjob finishing if it is absent in qemu
- DROP: FIXUP: move tmp snapshot actions to job handler
- DROP: FIXUP: only kickof tmp snapshot commit in cleanup thread
- DROP: FIXUP register vcpu count as UInt
- DROP: Report io requests counters for vzct driver
- DROP: FIXUP: vzct 2: handle per domain failure on getting stats
- DROP: FIXUP: fix build without vcmmd support
- upgrade: support local p2p migration
- DROP: FIXUP: fix domain without disks for qemuDomainTmpSnapshotFindDisks
- upgrade: vnc: make vnc upgrade possible
- upgrade: support for server backends for serial chardevs
- upgrade: close agent channel befor postcopy with release ram
- pull: qemu: block snapshots basic implementation
- pull: add autodelete option for creating block snapshots
- pull: stop exporting snapshot on snapshot autodelete
- pull: pull: add dirty bitmap on creating snapshot
- pull: add command to remove checkpoint
- api,qemu: add latency histogram
- pull: clean autodelete snapshots on daemon restart
- qemu: don't wait job in cleanup thread
- exec: kill orphans on client disconnect
- exec: kill orphans on migration destination
- qemu: support explicit disk backing in input
- conf: remove features unknown to qemu
- qemu: agent: log total tx/rx for streams
- debug: print 'thr a a bt' in log when taking some mutex takes much time
- qemu: migration: implement shared workaround
- qemu: handle host usb device add/del udev events
- vzct 2: add basic structure and listing
- vzct 2: support stats API
- qemu: add vcmmd support
- vzct 2: add jobs support for everything except migration
- vstorage migration: execute src migration cleanup in cleanup thread
- qemu: migration: add cookie parts for vstorage chardevs
- qemu: migration: detect shared vstorage chardevs
- vstorage: support migrating with chardevs on vstorage
- qemu: cleanup up vstorage chardevs after libvirtd crash
- vstorage migration: add vstorage snapshot commit
- vstorage migration: main patch
- vstorage migration: track valid temporary snapshot
- vstorage migration: resolve valid tmp snapshot on domain start
- vstorage migration: disable API that can clash with tmp snapshot
- vstorage migration: keep snapshot info in status
- qemu: cleanup tmp snapshot

* Mon Oct 26 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.61
- FIXUP: fix domain without disks for qemuDomainTmpSnapshotFindDisks #PSBM-121770

* Mon Oct 26 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.60
- FIXUP: fix build without vcmmd support

* Fri Oct 23 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.59
- FIXUP: vzct 2: handle per domain failure on getting stats #PSBM-121482

* Fri Oct 23 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.58
- Report io requests counters for vzct driver #PSBM-121662

* Thu Oct 22 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.57
- example: fix typo and formatting
- example: add ipv6 filters examples
- doc: document new filters and not documented ones
- FIXUP register vcpu count as UInt #PSBM-121594
- nwfilter: add vz specific filters #PSBM-121477

* Wed Oct 21 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.56
- FIXUP: drop snapshot on its file unlink failure
- qemu: add option to process offloaded blockjob event ealier
- REVERT: qemu: wait blockjob finishing if it is absent in qemu
- qemu: sync backing chain update and completed blockjob #VSTOR-28575 #VSTOR-34322
- qemu: update legacy block job sync after offloading changes
- FIXUP: move tmp snapshot actions to job handler
- FIXUP: only kickof tmp snapshot commit in cleanup thread
- vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- qemu: add filename to qemuMonitorGetBlockInfo
- vstorage migration: handle completed tmp snapshot commit on reconnect #PSBM-121261

* Thu Oct 15 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.55
- FIXUP: take into account tmp snapshot in qemuBlockDiskDetectNodes #PSBM-120959
- FIXUP: don't call vzctl2_free_env_ids for NULL #PSBM-121188

* Wed Oct 14 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.54
- Support resources change for libvirt docker driver #PSBM-120736
- REVERT: d8d14ae vstorage migration: handle libvirtd crashes
- REVERT: 25cee97 vstorage migration: support p2p
- REVERT: 0069126 vstorage migration: handle lossing connection to manager
- REVERT: bdb9763 vstorage migration: main patch #PSBM-106202
- REVERT: 66bf3fc vstorage migration: add vstorage snapshot commit phase
- REVERT: be09fb5 vstorage migration: add vstorage snapshot commit
- REVERT: e73c697 qemu: use more precise args in qemuDomainSnapshotCreateDiskActive
- REVERT: a58cd6a qemu: use more precise args in qemuDomainSnapshotCreateInactiveExternal
- REVERT: 63a5ee1 qemu: use job finish instead of discard on migration cleanup
- REVERT: 966f7e5 vstorage migration: execute src migration cleanup in cleanup thread
- REVERT: 6a25c7a vstorage migration: introduce virDomainMigrateVstorageCommit
- REVERT: ec406d6 vstorage migration: add vstorage disks info to cookie
- vstorage migration: introduce virDomainMigrateVstorageCommit
- vstorage migration: add vstorage snapshot commit phase
- vstorage migration: add vstorage disks info to cookie
- qemu: add vstorage snapshot utility functions
- vstorage migration: add vstorage snapshot commit
- vstorage migration: main patch #PSBM-106202
- vstorage migration: support p2p
- vstorage migration: execute src migration cleanup in cleanup thread
- qemu: use job finish instead of discard on migration cleanup
- vstorage migration: track valid temporary snapshot
- vstorage migration: resolve valid tmp snapshot on domain start
- qemu: move restoring after failure to cleanup in qemuDomainDefineXMLFlags
- vstorage migration: disable API that can clash with tmp snapshot
- vstorage migration: keep snapshot info in status
- vstorage migration: add dst cleanup after disconnection
- vstorage migration: determine valid snapshot on crash/disconnections
- qemu: migration: fix missing owner on disconnection cleanup
- FIXUP: cleanup thread: add option to cleanup single VM
- FIXUP: qemu: enhance domain cleanup
- qemu: cleanup tmp snapshot #PSBM-106875
- logging: allow max_len=0 to disable log rollover #PSBM-121257
- FIXUP: qemu: migration: detect shared vstorage chardevs #PSBM-121001
- FIXUP: fix recent uninitialized var case

* Tue Oct 06 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.53
- DROP: vzct 2: support stats API
- DROP: qemu: add vcmmd support
- DROP: FIXUP: qemu: move vcmmd register to later moment
- DROP: FIXUP: vzct 2: fix unlimited vcpu in stats
- DROP: FIXUP: vzct 2: add disk usage to stats
- vzct 2: support stats API
- qemu: add vcmmd support
- docker: support wss volume resizing #PSBM-108203
- qemu: monitor: return error message from qemuMonitorRemoveFd
- qemu: monitor: add qemuMonitorQueryFdsets function
- qemu: don't leave descriptors in fdsets after process startup #PSBM-108299
- FIXUP: mark chardevs to be unplugged outside cmdline building
- FIXUP: prepare chardev plug/unplug functions to reuse
- qemu: migration: add cookie parts for vstorage chardevs
- logging: close backing file on eof on drain
- qemu: monitor: let qemuMonitorAddFd generate fdset
- qemu: monitor: add option to override backend in qemuMonitorChangeCharDev
- qemu: migration: support changing chardev backend with virtlogd
- logging: handle race on drain and closing in event loop
- logging: allow NULL to inode and offset out args on drain
- qemu: migration: detect shared vstorage chardevs
- vstorage: support migrating with chardevs on vstorage #PSBM-106373
- qemu: add vstorage chardev tmpfile names to status file
- qemu: sync chardevs unplugged status on reconnect
- qemu: cleanup up vstorage chardevs after libvirtd crash
- qemu: drain file chardevs on domain process stop

* Fri Oct 02 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.52
- Fixes for support creation of docker container #PSBM-107933
- logging: read all bytes on EOF in event handler
- logging: fix endless loop on EOF
- docker: Support CPU limits #PSBM-107960
- docker: support wss storage pool for connection capabilibies #PSBM-108203
- FIXUP: vzct 2: fix unlimited vcpu in stats #PSBM-108263
- FIXUP: vzct 2: add disk usage to stats #PSBM-106059

* Mon Sep 21 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.51
- FIXUP: qemu: move vcmmd register to later moment #PSBM-108113

* Mon Sep 21 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.50
- vzct 2: support getting stats for migration #PSBM-107763
- vzct 2: support aborting domain job API #PSBM-107446

* Thu Sep 17 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.49
- DROP: vzct 2: add basic structure and listing
- DROP: vzct 2: implement define
- DROP: vzct 2: support stats API
- DROP: vzct 2: support snapshots
- DROP: vzct 2: intoduce migration
- DROP: FIXUP: vzct 2: some logging cleanups
- DROP: FIXUP: vzct 2: fix snapshot loading on daemon start
- DROP: FIXUP: vzct 2: move loading snapshots meta to a better place
- vzct 2: add basic structure and listing
- vzct 2: implement define
- vzct 2: support stats API
- vzct 2: support snapshots
- vzct 2: intoduce migration
- vzct 2: add lifecycle events #PSBM-107730

* Thu Sep 17 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.48
- DROP: qemu: support updating backend of serial device
- DROP: vzct 2: add basic structure and listing
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- DROP: vzct 2: implement start/stop
- DROP: vzct 2: support vnc #PSBM-104068
- DROP: vzct 2: support cloud init cdrom #PSBM-104067
- DROP: vzct 2: support iolimits #PSBM-104069
- DROP: vzct 2: add misc API
- DROP: vzct 2: make disk names stable #PSBM-104105
- DROP: vzct 2: support stats API #PSBM-104070
- DROP: FIXUP: don't lock VMs in event loop on closing connection #VSTOR-34225
- DROP: vzct 2: support snapshots
- DROP: vstorage migration: execute src migration cleanup in cleanup thread
- DROP: vzct 2: intoduce migration
- DROP: FIXUP: vzct2: use auto cleanup
- DROP: vzct 2: support memory guarantees #PSBM-106482
- DROP: FIXUP: vzct 2: use new light vcpu mode and unlimimed support
- DROP: FIXUP: fix NULL pointer error introduced by migration code #PSBM-107672
- DROP: FIXUP: handle cleanup request NOT on disconnection #PSBM-107396
- DROP: FIXUP: qemu: support updating backend of serial device
- DROP: FIXUP: vzct 2: support auto memguarantee #PSBM-107697
- DROP: FIXUP: rename some types
- DROP: FIXUP: vzct 2: move ctid from private to config extraId
- DROP: FIXUP: vzct 2: don't handle add/delete/update in event loop
- DROP: FIXUP: better error reports on libvzctl errors
- DROP: vzct 2: add jobs support for everything except migration
- DROP: FIXUP: vzct 2: don't log debug messages by default
- DROP: FIXUP: fix false positive compiler error
- DROP: docker: support DNS configuration #PSBM-106778
- DROP: FIXUP: vzct 2: provide extraId in defineXML
- DROP: FIXUP: Changes for support DNS configuration
- DROP: FIXUP: Changes for support DNS configuration #PSBM-107940
- qemu: support updating backend of serial device
- vzct 2: add basic structure and listing
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: implement start/stop
- vzct 2: support vnc #PSBM-104068
- vzct 2: support cloud init cdrom #PSBM-104067
- vzct 2: support iolimits #PSBM-104069
- vzct 2: add misc API
- vzct 2: make disk names stable #PSBM-104105
- vzct 2: support stats API #PSBM-104070
- FIXUP: don't lock VMs in event loop on closing connection #VSTOR-34225
- vzct 2: support snapshots
- vstorage migration: execute src migration cleanup in cleanup thread
- vzct 2: intoduce migration
- vzct 2: support memory guarantees #PSBM-106482
- vzct 2: add jobs support for everything except migration
- docker: support DNS configuration #PSBM-106778
- qemu: fix concurrency crash bug in snapshot revert
- qemu: fix concurrency crash bug in force snapshot revert #PSBM-107833
- FIXUP: vzct 2: some logging cleanups
- FIXUP: vzct 2: fix snapshot loading on daemon start
- FIXUP: vzct 2: move loading snapshots meta to a better place

* Tue Sep 15 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.47
- docker: rename CA certificate file to ca.pem
- FIXUP: Changes for support DNS configuration
- FIXUP: Changes for support DNS configuration #PSBM-107940

* Tue Sep 15 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.46
- Changes for support DNS configuration #PSBM-106778
- docker: support DNS configuration #PSBM-106778
- FIXUP: vzct 2: provide extraId in defineXML

* Tue Sep 15 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.45
- FIXUP: docker: use correct timeouts and subnet value #PSBM-106778
- docker: add support for static IP address #PSBM-106778
- conf: add auto mininal memory guarantee mode
- FIXUP: qemu: support updating backend of serial device
- FIXUP: vzct 2: support auto memguarantee #PSBM-107697
- qemu: add vcmmd support #PSBM-106483
- FIXUP: using vars for compacting code #PSBM-106778
- qemu: agent: disable blocking calls to agent #PSBM-107669
- FIXUP: rename some types
- conf: support extra id in domain list
- FIXUP: vzct 2: move ctid from private to config extraId
- FIXUP: vzct 2: don't handle add/delete/update in event loop
- FIXUP: better error reports on libvzctl errors
- vzct 2: add jobs support for everything except migration
- vzct 2: support jobs during migration #PSBM-107444
- vzct 2: drop job on client disconnection during migration
- FIXUP: vzct 2: don't log debug messages by default
- FIXUP: fix false positive compiler error

* Thu Sep 10 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.44
- FIXUP: handle cleanup request NOT on disconnection #PSBM-107396

* Wed Sep 09 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.43
- add build after adding secret driver AGAIN

* Wed Sep 09 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.42
- add build after adding secret driver

* Sun Sep 06 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.41
- DROP: upgrade: store generation in status file
- DROP: hubapi: remote: support domain- API calls
- DROP: conf: add more options to save config filename
- DROP: vzct 2: add basic structure and listing
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- DROP: vzct 2: support vnc #PSBM-104068
- DROP: vzct 2: support snapshots
- DROP: vzct 2: support venet0 network interface #PSBM-105548
- DROP: vstorage migration: add vstorage disks info to cookie
- DROP: FIXUP: vstorage migration: add vstorage disks info to cookie #PSBM-107012
- DROP: FIXUP: hubapi: remote: support domain- API calls
- DROP: FIXUP: use virFileRead function
- DROP: FIXUP: vzct: improve vz event logging
- DROP: FIXUP: return domain from vzctAddDomain
- DROP: FIXUP: better config/status files handling
- DROP: vzct 2: save disks uuid in config/status files
- DROP: FIXUP: vzct2: don't store private data for cdroms
- DROP: FIXUP: vzct 2: fix typo #PSBM-107583
- conf: accept path in virDomainSaveXML
- upgrade: store generation in status file
- hubapi: remote: support domain- API calls
- conf: add more options to save config filename
- vzct 2: add basic structure and listing
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: support vnc #PSBM-104068
- vzct 2: support snapshots
- vzct 2: support venet0 network interface #PSBM-105548
- vstorage migration: add vstorage disks info to cookie
- vzct 2: save disks uuid in config/status files
- docker: unification of source code #PSBM-106989
- docker: common auth certificate for docker and winrm #PSBM-106989
- FIXUP: docker: use more correct powershell expressions
- conf: support light vcpus and unlimitied number
- FIXUP: vzct 2: use new light vcpu mode and unlimimed support
- vzct 2: mark supported xml parts in domain/snapshot docs #PSBM-106576
- FIXUP: fix NULL pointer error introduced by migration code #PSBM-107672

* Thu Sep 03 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.40
- vzct 2: support memory guarantees #PSBM-106482
- FIXUP: vzct 2: fix typo #PSBM-107583

* Thu Sep 03 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.39
- FIXUP: vzct2: don't store private data for cdroms

* Thu Sep 03 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.38
- DROP: exec: kill orphans on client disconnect #PSBM-91329 #VSTOR-17959
- DROP: exec: kill orphans on migration destination #PSBM-91329 #VSTOR-17959
- DROP: Add new type of storage pool for Windows Storage Spaces (WSS) #PSBM-106275
- DROP: FIXUP: exec: kill orphans on migration destination
- DROP: FIXUP: exec: kill orphans on client disconnect
- exec: kill orphans on client disconnect #PSBM-91329 #VSTOR-17959
- exec: kill orphans on migration destination #PSBM-91329 #VSTOR-17959
- Add new type of storage pool for Windows Storage Spaces (WSS) #PSBM-106275
- docker: reuse winrm coonnection #PSBM-106278
- docker: forbid access to primordial storage pools #PSBM-106278
- FIXUP: vstorage migration: add vstorage disks info to cookie #PSBM-107012
- virsh: don't shout if virDomainGetJobInfo is not supported
- FIXUP: hubapi: remote: support domain- API calls
- util: add virFileRead function
- FIXUP: use virFileRead function
- FIXUP: vzct: improve vz event logging
- FIXUP: return domain from vzctAddDomain
- FIXUP: better config/status files handling
- vzct 2: save disks uuid in config/status files
- vzct 2: intoduce migration
- FIXUP: vzct2: use auto cleanup

* Wed Aug 19 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.37
- DROP: dac: don't fail on attempt to change uid/gid of the image
- DROP: vzct 2: add basic structure and listing
- DROP: vzct 2: support snapshots
- DROP: FIXUP: vzct 2: make snapshot lists stable #PSBM-106114
- DROP: FIXUP: vzct 2: fix memory/name issues #PSBM-106138
- DROP: REVERT: dac: don't fail on attempt to change uid/gid of the image
- DROP: FIXUP: vzct 2: configure libvzctl logs #PSBM-106284
- DROP: vzct 2: don't try virDomainLookupByID
- DROP: FIXUP: vzct 2: don't try virDomainLookupByID
- vzct 2: add basic structure and listing
- vzct 2: support snapshots
- vzct 2: don't try virDomainLookupByID
- doc: adopt README.md for Virtuozzo
- docker: first implementation of winrs transport to windows host #PSBM-106275
- docker: basic implementation of storage driver for Windows host #PSBM-106275
- Add new type of storage pool for Windows Storage Spaces (WSS) #PSBM-106275
- docker: full implementation of storage driver for Windows #PSBM-106275
- docker: add method for cloning volume #PSBM-106275
- docker: using common CA certificate for docker and winrm connection #PSBM-106275
- FIXUP: exec: kill orphans on migration destination
- vstorage migration: add vstorage disks info to cookie
- vstorage migration: introduce virDomainMigrateVstorageCommit
- FIXUP: exec: kill orphans on client disconnect
- vstorage migration: execute src migration cleanup in cleanup thread
- qemu: use job finish instead of discard on migration cleanup
- qemu: use more precise args in qemuDomainSnapshotCreateInactiveExternal
- qemu: use more precise args in qemuDomainSnapshotCreateDiskActive
- vstorage migration: add vstorage snapshot commit
- vstorage migration: add vstorage snapshot commit phase
- vstorage migration: main patch #PSBM-106202
- vstorage migration: handle lossing connection to manager
- vstorage migration: support p2p
- vstorage migration: handle libvirtd crashes

* Fri Jul 31 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.36
- FIXUP: vzct 2: don't try virDomainLookupByID

* Fri Jul 31 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.35
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- DROP: vzct 2: support stats API #PSBM-104070
- DROP: vzct 2: support snapshots
- DROP: FIXUP: vzct 2: handle VZCTL_E_NOTSUPP for disk stats #PSBM-106108
- DROP: FIXUP: vzct 2: use new VZCTL_NETTYPE_VNET #PSBM-106230
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: support stats API #PSBM-104070
- vzct 2: support snapshots
- FIXUP: vzct 2: make snapshot lists stable #PSBM-106114
- virsh: handle snapshots with domain state unknown
- conf: moment: remember if name is autogenerated
- FIXUP: vzct 2: fix memory/name issues #PSBM-106138
- util: add means to detect vstorage filesystem
- REVERT: dac: don't fail on attempt to change uid/gid of the image
- security: exclude vstorage from labelling #PSBM-105985
- FIXUP: vzct 2: configure libvzctl logs #PSBM-106284
- vzct 2: don't try virDomainLookupByID
- qemu: caps: use more precise condition when to use CAP_DAC_OVERRIDE #PSBM-106271

* Mon Jul 27 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.34
- FIXUP: vzct 2: handle VZCTL_E_NOTSUPP for disk stats #PSBM-106108
- FIXUP: vzct 2: use new VZCTL_NETTYPE_VNET #PSBM-106230
- qemu: auto load vhost-vsock module #PSBM-106171
- qemu: make latency work with legacy interface #PSBM-106129

* Fri Jul 24 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.33
- DROP: vzct 2: add basic structure and listing
- DROP: vzct 2: implement define
- DROP: vzct 2: support stats API #PSBM-104070
- DROP: FIXUP: vzct 2: add missing balloon stats #PSBM-105516
- DROP: FIXUP: vzct 2: fix crash on updating deleted out of sync domain #PSBM-106054
- DROP: FIXUP: vzct 2: fix net interface update on define
- DROP: FIXUP: vzct 2: error out on undefining running domain
- vzct 2: add basic structure and listing
- vzct 2: implement define
- vzct 2: support stats API #PSBM-104070
- docker: Add some configuration features for driver #PSBM-106011
- network: make it safe to call networkSetupPrivateChains() multiple times
- network: force re-creation of iptables private chains on firewalld restart #PSBM-105958

* Wed Jul 22 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.32
- upgrade: don't mess with security labels #PSBM-105674
- qemu: pass rememberOwner during update #PSBM-105674
- docs: fix typo in virsh.rst for balloon.major_fault
- include: clarify docs for hugetlb in virDomainMemoryStatTags
- docs: add missing balloon stats docs in domstats
- docs: add missing iothread stats docs in domstats
- src: add missing balloon stats docs
- FIXUP: vzct 2: add missing balloon stats #PSBM-105516
- FIXUP: vzct 2: fix crash on updating deleted out of sync domain #PSBM-106054
- FIXUP: vzct 2: fix net interface update on define
- FIXUP: vzct 2: error out on undefining running domain

* Mon Jul 20 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.31
- qemu: ignore allow_disk_format_probing #PSBM-105558

* Thu Jul 16 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.30
- DROP: vzct 2: support stats API #PSBM-104070
- vzct 2: support stats API #PSBM-104070
- xml: add venet0 network interface type
- vzct 2: support venet0 network interface #PSBM-105548

* Wed Jul 15 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.29
- DROP: vzct 2: support stats API #PSBM-104070
- vzct 2: support stats API #PSBM-104070

* Fri Jul 10 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.28
- DROP: vzct 2: add basic structure and listing
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- DROP: vzct 2: implement start/stop
- DROP: vzct 2: support vnc #PSBM-104068
- DROP: vzct 2: support cloud init cdrom #PSBM-104067
- DROP: vzct 2: add stubs for couple of functions
- DROP: vzct 2: add misc API
- vzct 2: add basic structure and listing
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: implement start/stop
- vzct 2: support vnc #PSBM-104068
- vzct 2: support cloud init cdrom #PSBM-104067
- vzct 2: add vzctDomainHasManagedSaveImage stub
- vzct 2: add misc API
- vzct 2: support snapshots
- docker: Offline migration of windows container #PSBM-104866
- FIXUP: Changes for using define instead of several identical string #PSBM-104866
- docker: Added rename method for driver

* Mon Jun 29 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.27
- DROP: vzct 2: add domains listing
- DROP: docker: First implementation of libvirt Docker driver #PSBM-102978
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- DROP: vzct 2: implement start/stop
- DROP: vzct 2: store libvirt config for domain
- DROP: vzct 2: add state file and transient config
- DROP: vzct 2: support vnc #PSBM-104068
- DROP: vzct 2: support cloud init cdrom #PSBM-104067
- DROP: vzct 2: support iolimits #PSBM-104069
- DROP: vzct 2: add misc API
- DROP: vzct 2: make disk names stable #PSBM-104105
- DROP: vzct 2: support stats API #PSBM-104070
- DROP: vzct 2: handle update for a running domain #PSBM-104643
- DROP: Support hooks placed in several files in libvirt #PSBM-104792
- docker: First implementation of libvirt Docker driver #PSBM-102978
- vzct 2: add basic structure and listing
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: implement start/stop
- vzct 2: support vnc #PSBM-104068
- vzct 2: support cloud init cdrom #PSBM-104067
- vzct 2: support iolimits #PSBM-104069
- vzct 2: add misc API
- vzct 2: make disk names stable #PSBM-104105
- vzct 2: support stats API #PSBM-104070
- Support hooks placed in several files in libvirt #PSBM-104792
- qemu: optimize qemuOpenFileAs for reads #VSTOR-34701
- Add qemu hook suitable to handle device hotplug/hotunplug #PSBM-104793

* Fri Jun 19 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.26
- qemu: use explicit backing mode only if there is nbd in backing #PSBM-104929
- Support hooks placed in several files in libvirt #PSBM-104792

* Wed Jun 17 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.25
- FIXUP: don't lock VMs in event loop on closing connection #VSTOR-34225

* Tue Jun 16 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.24
- DROP: UPSTREAM: remove return checks because of OOM
- OOM: add abort to functions we don't check return value #PSBM-104580
- qemu: bring back capabilities from update 14 #PSBM-104797
- docker: Added support for mounting volumes or FSs #PSBM-104538

* Mon Jun 15 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.23
- FIXUP: upgrade: vnc: make vnc upgrade possible #PSBM-104751
- FIXUP: qemu: wait blockjob finishing if it is absent in qemu #VSTOR-34322

* Tue Jun 09 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.22
- DROP: UPSTREAM: remove return checks because of OOM
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- DROP: vzct 2: implement start/stop
- DROP: UPSTREAM: remove return checks because of OOM
- DROP: vzct 2: store libvirt config for domain
- DROP: vzct 2: add state file and transient config
- DROP: vzct 2: support vnc #PSBM-104068
- DROP: vzct 2: support cloud init cdrom #PSBM-104067
- DROP: vzct 2: make disk names stable #PSBM-104105
- UPSTREAM: remove return checks because of OOM
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: implement start/stop
- vzct 2: store libvirt config for domain
- vzct 2: add state file and transient config
- vzct 2: support vnc #PSBM-104068
- vzct 2: support cloud init cdrom #PSBM-104067
- vzct 2: make disk names stable #PSBM-104105
- vzct 2: support stats API #PSBM-104070
- vzct 2: handle update for a running domain #PSBM-104643
- docker: implementation of network driver #PSBM-104537

* Fri Jun 05 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.21
- DROP: vzct 2: add domains listing
- DROP: docker: First implementation of libvirt Docker driver #PSBM-102978
- DROP: vzct 2: store libvirt config for domain
- DROP: vzct 2: support cloud init cdrom #PSBM-104067
- vzct 2: add domains listing
- docker: First implementation of libvirt Docker driver #PSBM-102978
- vzct 2: store libvirt config for domain
- vzct 2: support cloud init cdrom #PSBM-104067
- docker: cleanup code #PSBM-104537
- docker: changing of type of some objects in XML model #PSBM-104537
- vzct 2: make disk names stable #PSBM-104105
- FIXUP: docker: simplification of existing code #PSBM-104537

* Mon Jun 01 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.20
- vzct 2: support iolimits #PSBM-104069
- vzct 2: add misc API
- docker: implementation of connectGetAllDomainStats method #PSBM-104003

* Fri May 29 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.19
- DROP: virdomainobjlist: handle deleting on list iteration
- DROP: UPSTREAM: remove return checks because of OOM
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- DROP: UPSTREAM: remove return checks because of OOM
- DROP: vzct 2: store libvirt config for domain
- DROP: vzct 2: support vnc #PSBM-104068
- UPSTREAM: remove return checks because of OOM
- vzct 2: support dumpxml
- vzct 2: implement define
- UPSTREAM: remove return checks because of OOM
- vzct 2: store libvirt config for domain
- vzct 2: support vnc #PSBM-104068
- vzct 2: support cloud init cdrom #PSBM-104067
- vzct 2: add stubs for couple of functions

* Wed May 27 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.18
- DROP: vzct 2: add domains listing
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- DROP: vzct 2: implement start/stop
- vzct 2: add domains listing
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: implement start/stop
- FIXUP: docker: look up by name #PSBM-104003
- docker: cleanup code #PSBM-104003
- conf: add more options to save config filename
- vzct 2: store libvirt config for domain
- vzct 2: add state file and transient config
- vzct 2: support vnc #PSBM-104068

* Thu May 21 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.17
- DROP: rpc: kill prl_disp_service on dead connection #PSBM-102477
- DROP: vzct 2: support dumpxml
- DROP: vzct 2: implement define
- vzct 2: support dumpxml
- vzct 2: implement define
- UPSTREAM: remove return checks because of OOM
- docker: cleanup code for hypervisor driver #PSBM-104003
- FIXUP: debug: print 'thr a a bt' in log when taking some mutex takes much time
- FIXUP: docker: look up by hash-id with leading zero #PSBM-104003
- docker: implementation of stats methods #PSBM-104003

* Tue May 19 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.16
- DROP: vzct 2: add domains listing
- DROP: vzct 2: support dumpxml
- vzct 2: add domains listing
- vzct 2: support dumpxml
- vzct 2: implement define
- vzct 2: implement start/stop
- docker: implementation of XML methods for libvirt driver #PSBM-103381

* Thu May 14 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.15
- DROP: vzct 2: add domains listing
- vzct 2: add domains listing
- docker: add 'template' source type #PSBM-103381

* Tue May 12 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.14
- DROP: vzct 2: add domains listing
- UPSTREAM: remove return checks because of OOM
- vzct 2: add domains listing
- conf: allow NULL callback in virDomainObjListRename
- vzct 2: support dumpxml

* Fri May 08 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.13
- DROP: vzct 2: add domains listing
- vzct 2: add domains listing

* Thu May 07 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.12
- DROP: vzct 2: add domains listing
- vzct 2: add domains listing

* Thu May 07 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.11
- qemu: Check for job being set when getting iothread stats #PSBM-103817

* Fri May 01 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.10
- DROP: vzct: initial patch
- DROP: vzct: add boot order support
- DROP: vircommand: fix checking mixing daemon and string output
- DROP: vzct: initial vnc support
- DROP: vzct: implement blockstats API
- DROP: vzct: add memory stats
- DROP: conf: borrow some network code from lxc
- DROP: vzct: add networking support
- DROP: vzct: implement suspend/resume API
- DROP: vzct: implement device attach/device for fs and net
- DROP: vzct: implement domain shutdown API
- DROP: vzct: add reset and reboot
- DROP: vzct: support autostart
- DROP: vzct: implement virDomainSetVcpus
- DROP: vzct: add .domainSetMemory
- DROP: vzct: support managed save
- DROP: vzct: add snapshot support
- DROP: vzct: support basic migration
- DROP: vzct: support p2p migration
- DROP: vzct: support disk attach/detach
- DROP: vzct: add interface stats API
- DROP: vzct: support migration abort
- DROP: vzct: migration: add job handling in non p2p mode
- DROP: vzct: support non shared disk migration
- DROP: vzct: support detach/attach vnc graphics
- DROP: vzct: support updating vnc graphics
- DROP: vzct: support changing user password
- DROP: vzct: destroy domain on netlink CT stopped event
- DROP: vzct: support block resize
- DROP: vzct: migration: support src/dst persistent config flags
- DROP: vzct: migration: support vzctDomainGetJobInfo(Stats)
- DROP: vzct: implement virDomainGetVcpus
- DROP: vzct: support io limits in xml
- vzct 2: add domains listing
- docker: correct POST HTTP request #PSBM-103381
- docker: add special label with libvirt uuid in container config #PSBM-103381

* Mon Apr 27 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.9
- DROP: vzct: initial patch
- DROP: vzct: add boot order support
- DROP: vzct: support basic migration
- DROP: vzct: support disk attach/detach
- DROP: vzct: support non shared disk migration
- DROP: vzct: support io limits in xml
- DROP: build: add targets list
- vzct: initial patch
- vzct: add boot order support
- vzct: support basic migration
- vzct: support disk attach/detach
- vzct: support non shared disk migration
- vzct: support io limits in xml
- docker: implementation control methods for domain #PSBM-103311
- docker: extend types of HTTP request #PSBM-103311

* Thu Apr 23 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.8
- vzct: support io limits in xml
- Implementation some methods for libvirt Docker driver #PSBM-102978

* Wed Apr 22 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.7
- docker: First implementation of libvirt Docker driver #PSBM-102978
- build: add targets list

* Tue Apr 21 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.6
- DROP: vzct: initial patch
- DROP: vzct: add boot order support
- DROP: vzct: initial vnc support
- DROP: vzct: implement domain register/unregister API
- DROP: vzct: implement blockstats API
- DROP: vzct: add memory stats
- DROP: vzct: add networking support
- DROP: vzct: implement suspend/resume API
- DROP: vzct: implement device attach/device for fs and net
- DROP: vzct: implement domain shutdown API
- DROP: vzct: add reset and reboot
- DROP: vzct: support autostart
- DROP: vzct: implement virDomainSetVcpus
- DROP: vzct: add .domainSetMemory
- DROP: vzct: support managed save
- DROP: vzct: add snapshot support
- DROP: vzct: support basic migration
- DROP: vzct: support disk/fs block devs
- DROP: vzct: support disk attach/detach
- DROP: vzct: add interface stats API
- DROP: vzct: support migration abort
- DROP: vzct: migration: add job handling in non p2p mode
- DROP: vzct: support non shared disk migration
- DROP: vzct: support updating vnc graphics
- DROP: vzct: support changing user password
- DROP: vzct: destroy domain on netlink CT stopped event
- DROP: conf: borrow some network code from lxc
- DROP: vzct: configure tap in driver
- DROP: vzct: support block resize
- DROP: vzct: implement virDomainGetVcpus
- vzct: initial patch
- vzct: add boot order support
- vzct: initial vnc support
- vzct: implement blockstats API
- vzct: add memory stats
- conf: borrow some network code from lxc
- vzct: add networking support
- vzct: implement suspend/resume API
- vzct: implement device attach/device for fs and net
- vzct: implement domain shutdown API
- vzct: add reset and reboot
- vzct: support autostart
- vzct: implement virDomainSetVcpus
- vzct: add .domainSetMemory
- vzct: support managed save
- vzct: add snapshot support
- vzct: support basic migration
- vzct: support disk attach/detach
- vzct: add interface stats API
- vzct: support migration abort
- vzct: migration: add job handling in non p2p mode
- vzct: support non shared disk migration
- vzct: support updating vnc graphics
- vzct: support changing user password
- vzct: destroy domain on netlink CT stopped event
- vzct: support block resize
- vzct: implement virDomainGetVcpus

* Mon Apr 13 2020 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-5.6.0-10.vz7.5
- lib: add virDomainGetGuestInfo()
- remote: implement virDomainGetGuestInfo
- qemu: add helper for getting guest users
- qemu: add helper function for querying OS info
- qemu: add helper for querying timezone info
- qemu: add support for new fields in FSInfo
- qemu: add helper for getting full FSInfo
- qemu: Implement virDomainGetGuestInfo()
- backport fixup: remote: implement virDomainGetGuestInfo
- qemu: guestinfo: handle unsupported agent commands
- virsh: add 'guestinfo' command
- RHEL: screenshot: Implement multiple screen support
- make check: fix when lxc is turned off
- cfg.mk: disable sc_copyright_check
- RHEL: qemu: support relative backing for RHEL 7.0.z qemu
- RHEL: qemu: Support vhost-user-multiqueue with QEMU 2.3
- RHEL: Define ETHTOOL_[GS]COALESCE when building on older kernels
- qemuhotplugtest: Test guestfwd attach and detach
- iohelper: truncate large chunks on write #PSBM-70840
- Added new flag VIR_DOMAIN_CREATE_USER
- conf: tune connection parameters for Virtuozzo #PSBM-92128
- Set LimitCORE=infinity in libvirtd.service
- conf: add 'format' attribute to domain/os/nvram element
- qemu: don't pause vm when creating internal snapshot
- vz: use /etc/machine-id as host uuid
- qemu: log: log monitor events by default
- relax network adapter config checking (bug #PSBM-54596 fix)
- qemu: v2 fix reboot scenario (bugs #PSBM-41956 #PSBM-54756 fix)
- vz: set virtio as default network model
- qemu: fix crash on getting block stats for empty cdrom
- vz: rework the way we get perfomance counters
- vz: use cached statistics for a predefined period
- vz: don't subscribe to perfomance counters
- vz: cleanup: delete unused constant definition
- vz: don't create driver object during daemon initialization
- vireventpoll: isolate common code
- vireventpoll implimentation using epoll
- conf/qemu: add hv-scsi model to scsi controllers
- vz: add domain name info in error message
- qemu: simplify graphics port releasing
- upgrade: support local p2p migration
- object: add shared lock option to lockable
- upgrade: initial implementation
- upgrade: don't show events from not face process
- upgrade: start target domain with source id
- cgroup: use id+generation for machine cgroup name if last is not 0
- upgrade: fix id clashes for domain private paths etc
- upgrade: store generation in status file
- dom list: refactor: reuse code in find functions
- upgrade: return face domain from domlist
- migration: support --release-ram
- migration: add --postcopy-start to start postcopy immediately
- upgrade: virtlogd: handle output for one path from 2 qemu
- upgrade: pass live config to target
- upgrade: don't generate seclabel again on upgrade
- upgrade: handle auto generated char dev unix paths
- upgrade: vnc: do not regenerate graphics for target process
- upgrade: vnc: factor out building vnc opts
- upgrade: vnc: make vnc upgrade possible
- upgrade: vnc: keep vnc state across upgrade
- upgrade: tap: use multiqueue to make upgrade possible
- upgrade: tap: don't regenerate name on upgrade
- upgrade: network iface: keep actual net
- upgrade: snapshots: support snapshots
- upgrade: don't assign dev aliases on upgrade
- qemu: drop acquiring job condition on removing vm from list
- qemu: fix one more race on undefining and create
- upgrade: restart pending jobs after upgrade
- upgrade: fix domain lookup in old face removing phase
- upgrade: make correct reconnection of upgrade
- upgrade: set used ports only for face
- upgrade: support for server backends for serial chardevs
- qemu.conf: set upper limit for vnc/spice ports to 6900
- upgrade: don't reject upgrade if hostname is localhost
- qemu: wait indefinetly when acquiring job condition in event handlers
- upgrade: close agent channel befor postcopy with release ram
- upgrade: use unique name for pidfiles across upgrades
- qemu: remove time limit on waiting qemu disappearence on EOF
- qemu: add vmbus-bridge device if hv-scsi present
- qemu: agent: stop io loop effectively on eof or error
- upgrade: fix crash if vm newdef is empty
- libvirtd: tune OOMScoreAdjust
- keycodes: fix for 'make dist'
- qemu: revert fb2cd32c
- daemon: finish threads on close
- qemu: monitor: check monitor not closed on send
- qemu: implement state driver shutdown function
- vz: remove domain uuid check on migration #PSBM-43767
- qemu: support hv-net interface models
- nwfilter: fix deadlock on firewalld restart/reload
- vz: allow to start vz driver without host cache info
- qemu: snapshot: revert upstream 9e2465834 #PSBM-76749
- api qemu: add block pull compress option #PSBM-73618
- qemu: reduce nesting in qemuDomainSnapshotForEachQcow2Raw
- qemu: include nvram into offline snapshots
- qemu: fail making internal snapshots with non qcow2 nvram
- util: virFDStreamConnectUNIX: add missing error report
- util: add 30s connection timeout to virFDStreamConnectUNIX
- qemu: use job to make domain responsive on qemuDomainOpenChannel
- qemu: wait qemu death indefinetely on domain stop #PSBM-70541
- pull: api: add API for pull (external) backups
- pull: api: add driver based implementation
- pull: remote: add pull backup API implementation
- pull: qemu: monitor: add commands for backup
- pull: conf: add block snapshot format/parse
- pull: virsh: add block snapshot create/delete
- qemu: store guest visible disk size from qemu monitor block info
- qemu: add option to handle inactive blockjobs to cancel op
- util: hash: add misc functions
- pull: conf: add block snaphots to status file
- pull: qemu: block snapshots basic implementation
- pull: qemu: support disks quiesce
- pull: qemu: add block snapshots listing
- pull: qemu: support block snapshot dumpxml
- pull: qemu: monitor: add cmd to delete nbd export
- pull: conf: add export conf def/parsing
- pull: qemu: implement export start/stop
- pull: qemu: don't delete snapshot while disks are exported
- util: hash: remove const from value in kv pair type
- pull: add autodelete option for creating block snapshots #VSTOR-22687
- pull: stop exporting snapshot on snapshot autodelete
- pull: add backcompat capabilities
- pull: qemu: monitor: add bitmap commands
- pull: pull: add dirty bitmap on creating snapshot
- pull: add command to remove checkpoint
- pull: qemu: remove checkpoint on autodelete
- pull: qemu: load bitmaps on domain start
- pull: qemu: monitor: add command to export bitmap
- pull: export bitmap
- pull: migrate checkpoints
- pull: qemu: validate snapshot name
- pull: qemu: add exportable paused start
- pull: add TLS to block export
- pull: add relaxng
- pull: add autoport on export
- qemu: add unmap stats to all domain stats
- api,qemu: add latency histogram
- hubapi: remote: implement listing domains
- hubapi: remote: support domain- API calls
- hubapi: remote: support domain lookup functions
- hubapi: remote: support {create,define}xml API
- hubapi: remote: support domain events
- hubapi: remote: support virConnectGetCapabilities
- hubapi: remote: return vz connection type if vz is in hub
- hubapi: remote: return vz connection type if vzct is in hub
- hubapi: find appropriate connection for domain xml #VZOS-1704
- vz: add option to resize filesystems thur virDomainBlockResize
- vz: support virDomainGetBlockInfo in driver
- dac: don't fail on attempt to change uid/gid of the image
- api/qemu: introduce hv-vss freeze/thaw
- pull: disable risky cases with RW NBD exports
- pull: introduce checkpoint switch API
- qemu: fix attach/detach char devices to use guest device id
- conf: remove none console target type check from  virDomainDefAddConsoleCompat
- conf: remove none console target type check from virDomainDefFormatInternal
- conf: remove none console target type check from virDomainSkipBackcompatConsole
- qemu: update compat console on attach first serial device
- qemu: support updating backend of serial device
- pull: qemu: add option to export last checkpoint
- portallocator: print warn on releasing not used port
- rpc: netdaemon: remove watch before closing fd
- netlink: remove watch before closing fd
- qemu: monitor: set error flag even in OOM conditions
- utils: export virCopyError
- qemu: fix domain object wait to handle monitor errors
- qemu: fix races in beingDestroyed usage
- lib: provide error message in new blockjob event
- qemu: agent: incapsulate vm reference management
- qemu: agent: remove unconvinient destroy callback
- qemu: agent: factor out code to open channel
- qemu: agent: remove useless signalling
- qemu: agent: do not take moninor ref in IO callback
- qemu: agent: remove qemuAgentNotifyCloseLocked
- qemu: agent: don't retry first sync message if monitor closed
- qemu: agent: better error message for disconnected agent
- qemu: agent: give same message on monitor errors
- qemu: agent: move monitor error check to better place
- qemu: agent: reduce nesting in qemuAgentCommand
- qemu: domain: add name arg to qemuFindAgentConfig
- qemu: agent: prepare serial event handler for aux channel
- rpc: support multiple streams on client side
- rpc: fix to support multiple streams
- rpc: close stream on receive errors
- rpc: pass original stream recv/send error
- qemu: add exec with true streams
- tools: stop event loop before closing connection
- virsh: don't print \n footer for x-exec
- pull: fix visible NULL entries in block snapshot hash
- nwfilter: use vfork to fasten spawn of {ip,eb]tables commands
- pci: more verbose error in virPCIGetDeviceAddressFromSysfsLink
- Drop x- from x-block-latency-histogram-set monitor command
- daemon: purge logs for domains removed more than month ago
- remote: fix SIGSEGV on closing client connection
- pull: don't destroy vm if it has block snapshots or exports
- tools: make building virt-login-shell truly conditional
- qemu: destroy domain on monitor EOF anyway
- pull: log merge/rename bitmap operations
- api/qemu: add move nvram API
- qemu: add option to update disk copy_on_read live #VSTOR-10895
- qemu: add qcow2 cache size policy
- tools: move virshGetEscapeChar to utils
- syms: add virStringListCopy to private syms
- virsh: support in, err, out as regular files
- qemu: support interactive exec #PSBM-91739
- qemu: remove sanity check in qemuMonitorJSONDiskNameLookupOne
- exec: provide tty params on exec when possible
- rpc: allow comments in prototol description
- remote: leave stub comment for 16/virDomainGetOSInfoX
- libvirt: add new virDomainCommandXSetParams API
- exec: handle client window size change when interactive
- qemu: add hci value (128MiB) to qcow2 disk cache policy
- upgrade: handle firewall rules #PSBM-90137
- qemu: caps: invalidate kvm capable qemu binaries on every restart #PSBM-88418
- cgroup: blacklist criu temporary mounts #PSBM-90471
- qemu: imply qcow2 format for backing store if not set
- rpc: client: fix race on stream error and stream creation
- exec: virsh: support redirection to special chardevs #PSBM-91601
- exec: restore std streams' flags on become foreground #PSBM-91602 #PSBM-93755
- rpc: client: stream: notify streams of closing connection
- Revert: log: actually do substring matches with fnmatch #PSBM-92872
- pull: clean autodelete snapshots on daemon restart
- qemu: agent: add code -2 when guest exec pid  not found
- exec: kill orphans on client disconnect #PSBM-91329 #VSTOR-17959
- exec: kill orphans on migration destination #PSBM-91329 #VSTOR-17959
- qemu: seccomp: don't turn it on by default #PSBM-93004
- qemu: ignore disabled arch-facilities in configs #PSBM-92991
- qemu: support explicit disk backing in input #VSTOR-21806 #VSTOR-21934
- logging: remove watch before closing fd in virLogHandlerLogFileFree #PSBM-93003
- qemu: don't log error for disk sources not supporting getting offline stats (nbd)
- qemu: don't log error when monitor EOF is expected #PSBM-93003
- qemu: agent: don't log error when monitor EOF is expected
- qemu: agent aux: don't log error when monitor EOF is expected
- qemu: qemuBlockDiskDetectNodes: get name if one is known
- backup: copy bitmaps to top image on snapshot
- virDomainObjListAddObjLocked: Don't expect vm->def to be set
- virDomainObjListAddLocked: Set vm->def only in success path
- virDomainObjListAdd: Leave def assigning as an exercise for caller
- virDomainObjListAdd: Remove unused flag
- qemu: Grab modify job for changing domain XML
- qemu_domain: Allow qemuDomainObjListAdd to keep job upon return
- qemu: release job on cleanup path
- qemu: snapshot revert: reuse common cleanup code
- qemu: snapshot: save/restore inactive persistent config
- schema: snapshot: add persistent domain config
- conf: snapshot: dump/parse persistent domain config
- docs: add persistent config to snapshot xml description
- conf: snapshot: check domain name on redefine
- conf: snapshot: support persistent config on redefine
- qemu: add option to close cdrom tray #PSBM-95870
- conf: remove features unknown to qemu (related to #PSBM-96228)
- agent: increase default timeout from 5s to 30s #PSBM-97240
- qemu: introduce qemuDomainChrSerialTargetModel
- conf: add debugcon chardev guest interface
- qemu: make irq optional when formatting the ISA address
- qemu: implement debugcon chardev
- qemu: autoadd iobase to debugcon chardev
- api/qemu: add pause/resume for blockjobs
- qemu: agent: log total tx/rx for streams
- debug: print 'thr a a bt' in log when taking some mutex takes much time
- qemu: monitor: throttle logging BLOCK_IO_ERROR events #VSTOR-26657
- qemu: ignore delayed EOF events from previous VM incarnations #ABR-243123
- qemu: don't fail pausing block job if it is missing #VSTOR-21176
- qemu: migration: implement shared workaround #VSTOR-11398
- conf: handle empty string in interface target name #PSBM-97765
- conf: add replug option for usb hostdev
- qemu: track hostdev delete intention
- qemu: support host usb device unplug
- qemu: support usb hostdev plugging back
- qemu: handle host usb device add/del udev events
- qemu: handle libvirtd restart after host usb device unplug
- qemu: handle race on device deletion and usb host device plugging
- qemu: hotplug: update device list on device deleted event
- qemu: handle host usb device plug/unplug when libvirtd is down
- qemu: don't mess with non mandatory hostdevs on reattaching
- qemu: handle detaching of unplugged hostdev
- conf: parse hostdev missing flag
- backup: don't keep bitmaps in base image on snapshots #VSTOR-23605
- backup: copy bitmaps down on active block commit #VSTOR-23605
- qemu: support new qemu without nbd-server-add-bitmap command #VSTOR-27428
- fix for "virDomainObjListAdd: Leave def assigning as an exercise for caller" #PSBM-98834
- qemu: handle storage/virtlogd hanging #VSTOR-27947
- log: in case of OOM at least try to log something on error
- qemu: wait blockjob finishing if it is absent in qemu #VSTOR-28575
- qemu: support 'preserve' option for 'on_poweroff'
- qemu: add reconnect params for nbd network disks #VSTOR-28845
- netdaemon: fix deadlock on stopping libvirtd when VM is starting #VSTOR-29392
- qemu: kill partially started domain immediately on reconnect #VSTOR-29393
- qemu: migration: log keep alive message during migration #PSBM-99571
- conf: refactor virDomainBlockIoTuneInfoHas*
- conf: expand iotune params if only group name is given
- qemu: check iotune params same for all disk in group
- qemu: fix using defaults when setting persistent iotune params
- qemu: propagate iotune settings to all disks in the group
- qemu: get defaults from iotune group we move disk into
- qemu: when leaving iotune group update xml properly #PSBM-99202
- qemu: disable snapshot explicitly when block snapshot is in progress #VSTOR-29840
- make: add flags to configure sanitizer
- asan: workaround sanitizer issues with clone(2)
- asan: configure to coredump on signals
- hubapi: workaround virURIFormat degradation in vz8
- qemu: hide details of fake reboot
- qemu: adopt nodename detection to backup filter node
- FIXUP: pull: qemu: block snapshots basic implementation #VSTOR-30694
- FIXUP: qemu: agent: log total tx/rx for streams #VSTOR-31096
- qemu: turn on write-blocking for driver-mirror by default #PSBM-97507
- FIXUP: api,qemu: add latency histogram
- qemu: adopt latency impl to new qemu #PSBM-97535
- qemu: turn on keep alive for nbd disk migration #PSBM-97768
- FIXUP: upgrade: support local p2p migration #PSBM-100796
- virdomainobjlist: handle deleting on list iteration
- vzct: initial patch
- vzct: add boot order support
- vircommand: fix checking mixing daemon and string output
- vzct: initial vnc support
- vzct: implement domain register/unregister API
- vzct: implement blockstats API
- vzct: add memory stats
- vzct: add networking support
- vzct: implement suspend/resume API
- vzct: implement device attach/device for fs and net
- vzct: implement domain shutdown API
- vzct: add reset and reboot
- vzct: support autostart
- vzct: implement virDomainSetVcpus
- vzct: add .domainSetMemory
- vzct: support managed save
- vzct: add snapshot support
- vzct: support basic migration
- vzct: support p2p migration
- vzct: support disk/fs block devs
- vzct: support disk attach/detach
- vzct: add interface stats API
- vzct: support migration abort
- vzct: migration: add job handling in non p2p mode
- vzct: support non shared disk migration
- vzct: support detach/attach vnc graphics
- vzct: support updating vnc graphics
- vzct: support changing user password
- vzct: destroy domain on netlink CT stopped event
- conf: borrow some network code from lxc
- vzct: configure tap in driver
- vzct: support block resize
- vzct: migration: support src/dst persistent config flags
- vzct: migration: support vzctDomainGetJobInfo(Stats)
- vzct: implement virDomainGetVcpus
- vz: fixes after renaming Parallels to Virtuozzo in sdk
- vz: build fix for passing qemuCaps to virDomainDeviceDefPostParse
- vz: build fix for passing qemuCaps to virDomainDefParseNode
- FIXUP: qemu: support explicit disk backing in input #VSTOR-31504
- virsystemd: workaround race on systemd-machined idle shutdown #PSBM-102137
- qemu: agent: sync once if qemu has serial port event #PSBM-101972
- qemu: remove redundant needReply argument of qemuAgentCommand
- rpc: kill prl_disp_service on dead connection #PSBM-102477
- FIXUP: conf: remove features unknown to qemu (related to #PSBM-96228)
- rpc: add timeout on connection #VSTOR-32643
- util: fix byte order of port in virSocketAddrResolveService

* Mon Dec  9 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-10
- util: introduce virPCIDeviceConfigOpenInternal (rhbz#1758330)
- util: Introduce virPCIDeviceConfigOpenWrite (rhbz#1758330)
- util: introduce readonly attribute to virPCIDeviceConfigOpenInternal (rhbz#1758330)
- util: introduce virPCIDeviceConfigOpenTry (rhbz#1758330)
- util: default to read-only in virPCIDeviceConfigOpen (rhbz#1758330)
- virpcimock: Mock __open_2() (rhbz#1758330)
- tests: virpcimock: Always declare __open_2 (rhbz#1758330)
- qemu: Add support for setting string migration params (rhbz#1754533)
- Introduce VIR_MIGRATE_PARAM_TLS_DESTINATION migration param (rhbz#1754533)
- qemu: Implement VIR_MIGRATE_PARAM_TLS_DESTINATION (rhbz#1754533)
- virsh: Add --tls-destination option for migrate command (rhbz#1754533)

* Thu Nov 28 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-9
- qemu: Separate image metadata removal into a function (rhbz#1741456)
- qemuProcessStop: Remove image metadata for running mirror jobs (rhbz#1741456)
- qemu: fix EFI nvram removal on domain undefine (rhbz#1751596)

* Thu Nov 21 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-8
- qemu: avoid double reservation of PCI address for interface type='hostdev' (rhbz#1744523)
- domain_conf: Make virDomainDeviceFindSCSIController accept virDomainDeviceDriveAddress struct (rhbz#1744079)
- domain_conf: Relax SCSI addr used check (rhbz#1744079)
- cpu_conf: Pass policy to CPU feature filtering callbacks (rhbz#1756157)
- qemuxml2*test: Add tests for Icelake-Server, -pconfig (rhbz#1756157)
- qemu: Drop disabled CPU features unknown to QEMU (rhbz#1756157)
- cputest: Add data for Ice Lake Server CPU (rhbz#1756157)
- cpu_map: Drop pconfig from Icelake-Server CPU model (rhbz#1756157)
- qemu: Fix NULL ptr dereference caused by qemuDomainDefFormatBufInternal (rhbz#1756157)

* Mon Oct 21 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-7
- qemu_blockjob: Remove secdriver metadata for whole backing chain on job completion (rhbz#1741456)
- qemu_driver: Fix comment of qemuStateCleanup() (rhbz#1755303)
- driver: Introduce virDriverShouldAutostart() (rhbz#1755303)
- lib: autostart objects exactly once (rhbz#1755303)
- Revert "src: Document autostart for session demon" (rhbz#1755303)
- security: Pass @migrated to virSecurityManagerSetAllLabel (rhbz#1740024)
- security: Rename virSecurityManagerGetDriver() to virSecurityManagerGetVirtDriver() (rhbz#1740024)
- security: Introduce virSecurityManagerGetDriver() (rhbz#1740024)
- security_stack: Turn list of nested drivers into a doubly linked list (rhbz#1740024)
- security_stack: Perform rollback if one of stacked drivers fails (rhbz#1740024)
- util: new function virNetDevMacVLanIsMacvtap() (rhbz#1723367)
- util: make a couple virNetDevMacVlan*() functions public (rhbz#1723367)
- qemu: reorganize qemuInterfaceEthernetConnect() (rhbz#1723367)
- conf: use virXMLFormatElement for interface <target> (rhbz#1723367)
- conf: new "managed" attribute for target dev of <interface type='ethernet'> (rhbz#1723367)
- qemu: support unmanaged target tap dev for <interface type='ethernet'> (rhbz#1723367)
- qemu: support unmanaged macvtap devices with <interface type='ethernet'> (rhbz#1723367)

* Thu Sep 19 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-6
- remote: fix registration of TLS socket (rhbz#1752837)

* Mon Sep 16 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-5
- vircgroupv2: fix setting cpu.max period (rhbz#1749247)

* Wed Sep  4 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-4
- src: security: Replace bitwise OR with logical OR (rhbz#1740024)
- security_util: Use more VIR_AUTOFREE() (rhbz#1740024)
- security_util: Document virSecurityMoveRememberedLabel (rhbz#1740024)
- security: Don't increase XATTRs refcounter on failure (rhbz#1740024)
- util: Introduce virhostuptime (rhbz#1741140)
- security_util: Remove stale XATTRs (rhbz#1741140)
- security_util: verify xattrs only if ref is present (rhbz#1741140)
- virSecuritySELinuxSetFileconImpl: Drop @optional argument (rhbz#1740506)
- security_selinux: Drop virSecuritySELinuxSetFileconOptional() (rhbz#1740506)
- security_selinux: Drop @optional from _virSecuritySELinuxContextItem (rhbz#1740506)
- security_selinux: Drop virSecuritySELinuxSetFileconHelper (rhbz#1740506)
- security_selinux: Play nicely with network FS that only emulates SELinux (rhbz#1740506)
- qemu_blockjob: Print image path on failed security metadata move too (rhbz#1741456)
- qemu_blockjob: Remove secdriver metadata more frequently (rhbz#1741456)
- vircgroupv2: fix abort in VIR_AUTOFREE (rhbz#1747482)

* Fri Aug 30 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-3
- vircgroupv2: fix parsing multiple values in single file (rhbz#1734353)
- vircgroupv2: fix virCgroupV2GetCpuCfsQuota for "max" value (rhbz#1735740)
- network: fix ability to use openvswitch with vlans (rhbz#1739554)
- remote: use Wants instead of Requires for libvirtd sockets (rhbz#1741403)
- remote: move timeout arg into sysconf file (rhbz#1741403)
- remote: forbid the --listen arg when systemd socket activation (rhbz#1741403)
- rpm: don't enable socket activation in upgrade if --listen present (rhbz#1741403)
- qemuBuildHotpluggableCPUProps: use VIR_RETURN_PTR (rhbz#1741658)
- qemu: Extract and store vCPU properties as qemu returned them (rhbz#1741658)
- qemu: command: Use all vCPU properties when creating args for vCPU hotplug (rhbz#1741658)
- qemu: alias: Generate 'qomName' of disk with useraliases (rhbz#1741838)

* Mon Aug 19 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-2
- Revert "tpm: Check TPM XML device configuration changes after edit" (rhbz#1739338)
- qemu: Clarify error message in qemuMigrationSrcIsSafe (rhbz#1660575)
- qemu: Check for drop-cache capability (rhbz#1660575)
- qemu: Allow migration with disk cache on (rhbz#1660575)
- qemu: Pass qemuCaps to qemuDomainDefCopy (rhbz#1741796)
- qemu: Pass qemuCaps to qemuDomainDefFormatBufInternal (rhbz#1741796)
- qemu: Pass qemuCaps to qemuDomainSaveImageOpen (rhbz#1741796)
- qemu: Pass qemuCaps to qemuMigrationAnyPrepareDef (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefParseString (rhbz#1741796)
- qemu: Pass qemuCaps to qemuMigrationCookieXMLParse (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefCopy (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefPostParse (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefParseNode (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDeviceDefPostParse (rhbz#1741796)
- qemu: Fix crash on incoming migration (rhbz#1741796)
- network: fix crash during cleanup from failure to allocate port (rhbz#1741390)
- network: replace virSaveLastError() with virErrorPreserveLast() (rhbz#1741390)
- access: fix incorrect addition to virAccessPermNetwork (rhbz#1741428)
- util: allow tap-based guest interfaces to have MAC address prefix 0xFE (rhbz#1743349)

* Tue Aug  6 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-1
- Rebased to libvirt-5.6.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1643404, rhbz#1721375, rhbz#1724065, rhbz#1726609, rhbz#1726643
    rhbz#1727013, rhbz#1727866, rhbz#1729022, rhbz#1731332

* Fri Jul 26 2019 Jiri Denemark <jdenemar@redhat.com> - 5.5.0-2
- vircgroup: fix cgroups v2 controllers detection (rhbz#1513930)
- vircgroupv2: store enabled controllers (rhbz#1513930)

* Wed Jul  3 2019 Jiri Denemark <jdenemar@redhat.com> - 5.5.0-1
- Rebased to libvirt-5.5.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1426162, rhbz#1513930, rhbz#1598657, rhbz#1717768, rhbz#1720517
    rhbz#1720519, rhbz#1720522, rhbz#1720524, rhbz#1722360, rhbz#1723633

* Thu Jun 27 2019 Pavel Hrdina <phrdina@redhat.com> - 5.4.0-2
- RHEL: spec: Disable gluster on i686 (rhbz#1724445)
- rpc: virnetlibsshsession: update deprecated functions (rhbz#1724678)

* Tue Jun  4 2019 Jiri Denemark <jdenemar@redhat.com> - 5.4.0-1
- Rebased to libvirt-5.4.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1580229, rhbz#1628475, rhbz#1702758, rhbz#1707708, rhbz#1716260
    rhbz#1716261, rhbz#1716262, rhbz#1716263

* Tue May  7 2019 Jiri Denemark <jdenemar@redhat.com> - 5.3.0-1
- Rebased to libvirt-5.3.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1578741, rhbz#1602418, rhbz#1680304, rhbz#1690240, rhbz#1292102
    rhbz#1623389, rhbz#1658504, rhbz#1689165, rhbz#1689815, rhbz#1692926
    rhbz#1217444, rhbz#1564270, rhbz#1580229, rhbz#1697676

* Fri Mar 15 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-7
- qemu: Set job statsType for external memory snapshot (rhbz#1688774)

* Wed Mar  6 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-6
- qemu: Don't set migration caps when changing postcopy bandwidth (rhbz#1336709)

* Fri Mar  1 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-5
- qemu: fix i6300esb watchdog hotplug on Q35 (rhbz#1666559)

* Tue Feb 26 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-4
- RHEL: util: fix typo in iptables --delete command (rhbz#1679119)

* Mon Feb 18 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-3
- vshtabletest: indent strings with expected output (rhbz#1676354)
- vsh-table: allow empty columns (rhbz#1676354)
- virsh: introduce ninfos variable in cmdDomFSInfo (rhbz#1676354)
- virsh: rename ret to rc in cmdDomFSInfo (rhbz#1676354)
- virsh: do not access uninitialized memory in cmdDomFSInfo (rhbz#1676354)
- virsh: introduce 'ret' in cmdDomFSInfo (rhbz#1676354)
- virsh: do not report error on zero filesystems in cmdDomFSInfo (rhbz#1676354)
- virsh: use virBufferTrim in cmdDomFSInfo (rhbz#1676354)
- virsh: allow empty targets in cmdDomFSInfo (rhbz#1676354)
- util: fix memory leak in virFirewallDInterfaceSetZone() (rhbz#1672340)
- internal: introduce a family of NULLSTR macros (rhbz#1662849)
- virsh: fix snapshot list --parent (rhbz#1662849)
- network: explicitly allow icmp/icmpv6 in libvirt zonefile (rhbz#1672340)

* Fri Feb  8 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-2
- RHEL: qemu: Fix crash trying to use iSCSI hostdev (rhbz#1669966)
- docs: Drop /dev/net/tun from the list of shared devices (rhbz#1671791)
- qemu: conf: Remove /dev/sev from the default cgroup device acl list (rhbz#1671791)
- qemu: cgroup: Expose /dev/sev/ only to domains that require SEV (rhbz#1671791)
- qemu: domain: Add /dev/sev into the domain mount namespace selectively (rhbz#1671791)
- security: dac: Relabel /dev/sev in the namespace (rhbz#1671791)
- qemu: caps: Use CAP_DAC_OVERRIDE for probing to avoid permission issues (rhbz#1671791)
- qemu: caps: Don't try to ask for CAP_DAC_OVERRIDE if non-root (rhbz#1671791)
- qemu: command: Don't skip 'readonly' and throttling info for empty drive (rhbz#1672259)
- Revert "RHEL: network: regain guest network connectivity after firewalld switch to nftables" (rhbz#1672340)
- configure: change HAVE_FIREWALLD to WITH_FIREWALLD (rhbz#1672340)
- util: move all firewalld-specific stuff into its own files (rhbz#1672340)
- util: new virFirewallD APIs + docs (rhbz#1672340)
- configure: selectively install a firewalld 'libvirt' zone (rhbz#1672340)
- network: set firewalld zone of bridges to "libvirt" zone when appropriate (rhbz#1672340)
- network: allow configuring firewalld zone for virtual network bridge device (rhbz#1672340)
- util: remove test code accidentally committed to virFirewallDZoneExists (rhbz#1672340)
- qemu: Use C99 initializers for qemuMigrationParamsTPMap (rhbz#1336709)
- qemu: Add optional unit to qemuMigrationParamsTPMapItem (rhbz#1336709)
- qemu: Rework qemuDomainMigrateSetMaxSpeed (rhbz#1336709)
- qemu: Make migration params usable outside migration (rhbz#1336709)
- Public API for post-copy migration bandwidth (rhbz#1336709)
- qemu: Implement VIR_MIGRATE_PARAM_BANDWIDTH_POSTCOPY (rhbz#1336709)
- qemu: Implement VIR_DOMAIN_MIGRATE_MAX_SPEED_POSTCOPY flag (rhbz#1336709)
- virsh: Add support for setting post-copy migration bandwidth (rhbz#1336709)

* Fri Jan 25 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-1
- Rebased to libvirt-5.0.0 (rhbz#1666130)
- The rebase also fixes the following bugs:
    rhbz#1597869, rhbz#1644567
- tests: qemuxml2argv: Add test case for empty CDROM with cache mode (rhbz#1668027)
- qemu: command: Don't format image properties for empty -drive (rhbz#1668027)

* Thu Dec  6 2018 Jiri Denemark <jdenemar@redhat.com> - 4.10.0-1
- Rebased to libvirt-4.10.0

* Tue Nov 20 2018 Jiri Denemark <jdenemar@redhat.com> - 4.9.0-1
- Rebased to libvirt-4.9.0
- RHEL: Fix virConnectGetMaxVcpus output (rhbz#1582222)
- RHEL: spec: Require python3-devel on RHEL-8 (rhbz#1518446)
- RHEL: network: regain guest network connectivity after firewalld switch to nftables (rhbz#1638864)

* Fri Nov  9 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-14
- storage: Remove secretPath from _virStorageBackendQemuImgInfo (rhbz#1645459)
- storage: Allow for inputvol to have any format for encryption (rhbz#1645459)
- storage: Allow inputvol to be encrypted (rhbz#1645459)
- access: Modify the VIR_ERR_ACCESS_DENIED to include driverName (rhbz#1631608)
- docs: Enhance polkit documentation to describe secondary connection (rhbz#1631608)
- qemu: Don't ignore resume events (rhbz#1634758, rhbz#1643338)

* Thu Nov  1 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-13
- Revert "spec: Temporarily drop gluster support" (rhbz#1599339)

* Wed Oct 17 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-12
- RHEL: Require firewalld-filesystem for firewalld rpm macros (rhbz#1639932)

* Tue Oct 16 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-11
- virfile: fix cast-align error (rhbz#1634782)
- virfiletest: Fix test name prefix for virFileInData test (rhbz#1634782)
- virfiletst: Test virFileIsSharedFS (rhbz#1634782)
- virFileIsSharedFSType: Detect direct mount points (rhbz#1634782)
- virfile: Rework virFileIsSharedFixFUSE (rhbz#1634782)
- RHEL: network: regain guest network connectivity after firewalld switch to nftables (rhbz#1638864)

* Mon Oct  8 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-10
- conf: Fix check for chardev source path (rhbz#1609723)
- tests: Reuse qemucapabilities data for qemucaps2xml (rhbz#1629862)
- tests: Add more tests to qemucaps2xml (rhbz#1629862)
- qemu: Drop QEMU_CAPS_ENABLE_KVM (rhbz#1629862)
- qemu: Avoid probing non-native binaries all the time (rhbz#1629862)
- qemu: Clarify QEMU_CAPS_KVM (rhbz#1629862)
- qemu: Don't check for /dev/kvm presence (rhbz#1629862)
- tests: Follow up on qemucaps2xmldata rename (rhbz#1629862)
- security: dac: also label listen UNIX sockets (rhbz#1634775)
- spec: Set correct TLS priority (rhbz#1632269)
- spec: Build ceph and gluster support everywhere (rhbz#1599546)
- virsh: Require explicit --domain for domxml-to-native (rhbz#1634769)
- virFileIsSharedFSType: Check for fuse.glusterfs too (rhbz#1634782)
- qemu: fix up permissions for pre-created UNIX sockets (rhbz#1634775)
- cpu_map: Add features for Icelake CPUs (rhbz#1527657, rhbz#1526625)
- cpu_map: Add Icelake CPU models (rhbz#1526625)
- qemu: Properly report VIR_DOMAIN_EVENT_RESUMED_FROM_SNAPSHOT (rhbz#1634758)
- qemu: Report more appropriate running reasons (rhbz#1634758)
- qemu: Pass running reason to RESUME event handler (rhbz#1634758)
- qemu: Map running reason to resume event detail (rhbz#1634758)
- qemu: Avoid duplicate resume events and state changes (rhbz#1634758)
- conf: qemu: add support for Hyper-V frequency MSRs (rhbz#1589702)
- conf: qemu: add support for Hyper-V reenlightenment notifications (rhbz#1589702)
- conf: qemu: add support for Hyper-V PV TLB flush (rhbz#1589702)

* Wed Sep  5 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-9
- RHEL: Fix virConnectGetMaxVcpus output (rhbz#1582222)
- storage: Add --shrink to qemu-img command when shrinking vol (rhbz#1622534)
- access: Fix nwfilter-binding ACL access API name generation (rhbz#1622540)
- conf: Add validation of input devices (rhbz#1591240)
- tests: qemu: Remove disk from graphics-vnc-tls (rhbz#1598167)
- tests: qemu: test more versions for graphics-vnc-tls (rhbz#1598167)
- qemu: vnc: switch to tls-creds-x509 (rhbz#1598167)
- qemu: mdev: Use vfio-pci 'display' property only with vfio-pci mdevs (rhbz#1624740)
- virDomainDefCompatibleDevice: Relax alias change check (rhbz#1603133)
- virDomainDetachDeviceFlags: Clarify update semantics (rhbz#1603133)
- virDomainNetDefCheckABIStability: Check for MTU change too (rhbz#1623158)
- RHEL: spec: Require python3-devel on RHEL-8 (rhbz#1518446)
- qemu: monitor: Remove qemuMonitorJSONExtractCPUArchInfo wrapper (rhbz#1598829)
- qemu: monitor: Use 'target' instead of 'arch' in reply of 'query-cpus-fast' (rhbz#1598829)

* Tue Aug 21 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-8
- tests: Add missing thread_siblings_list files (rhbz#1608479)
- util: Rewrite virHostCPUCountThreadSiblings() (rhbz#1608479)
- utils: Remove arbitrary limit on socket_id/core_id (rhbz#1608479)
- tests: Add linux-high-ids test (rhbz#1608479)
- qemu: hotplug: Fix asynchronous unplug of 'shmem' (rhbz#1618680)
- tests: rename hugepages to hugepages-default (rhbz#1615461)
- tests: extract hugepages-numa-default-dimm out of hugepages-numa (rhbz#1615461)
- tests: rename hugepages-numa into hugepages-numa-default (rhbz#1615461)
- tests: remove unnecessary XML elements from hugepages-numa-default (rhbz#1615461)
- tests: extract pages-discard out of hugepages-pages (rhbz#1615461)
- tests: rename hugepages-pages into hugepages-numa-nodeset (rhbz#1615461)
- tests: rename hugepages-pages2 into hugepages-numa-default-2M (rhbz#1615461)
- tests: extract pages-discard-hugepages out of hugepages-pages3 (rhbz#1615461)
- tests: rename hugepages-pages3 into hugepages-numa-nodeset-part (rhbz#1615461)
- tests: rename hugepages-pages4 into hugepages-numa-nodeset-nonexist (rhbz#1615461)
- tests: rename hugepages-pages5 into hugepages-default-2M (rhbz#1615461)
- tests: rename hugepages-pages6 into hugepages-default-system-size (rhbz#1615461)
- tests: rename hugepages-pages7 into pages-dimm-discard (rhbz#1615461)
- tests: rename hugepages-pages8 into hugepages-nodeset-nonexist (rhbz#1615461)
- tests: introduce hugepages-default-1G-nodeset-2M (rhbz#1615461)
- tests: introduce hugepages-nodeset (rhbz#1615461)
- conf: Move hugepage XML validation check out of qemu_command (rhbz#1615461)
- conf: Move hugepages validation out of XML parser (rhbz#1615461)
- conf: Introduce virDomainDefPostParseMemtune (rhbz#1615461)
- tests: sev: Test launch-security with specific QEMU version (rhbz#1619150)
- qemu: Fix probing of AMD SEV support (rhbz#1619150)
- qemu: caps: Format SEV platform data into qemuCaps cache (rhbz#1619150)
- conf: Parse guestfwd channel device info again (rhbz#1610072)

* Thu Aug 16 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-7
- qemu_migration: Avoid writing to freed memory (rhbz#1615854)

* Thu Aug  2 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-6
- qemu: Exempt video model 'none' from getting a PCI address on Q35
- conf: Fix a error msg typo in virDomainVideoDefValidate

* Tue Jul 31 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-5
- esx storage: Fix typo lsilogic -> lsiLogic
- networkGetDHCPLeases: Don't always report error if unable to read leases file
- nwfilter: Resolve SEGV for NWFilter Snoop processing
- qemu: Remove unused bypassSecurityDriver from qemuOpenFileAs
- qemuDomainSaveMemory: Don't enforce dynamicOwnership
- domain_nwfilter: Return early if net has no name in virDomainConfNWFilterTeardownImpl
- examples: Add clean-traffic-gateway into nwfilters

* Mon Jul 23 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-4
- qemu: hotplug: don't overwrite error message in qemuDomainAttachNetDevice
- qemu: hotplug: report error when changing rom enabled attr for net iface
- qemu: Fix setting global_period cputune element
- tests: qemucaps: Add test data for upcoming qemu 3.0.0
- qemu: capabilities: Add capability for werror/rerror for 'usb-device' frontend
- qemu: command: Move graphics iteration to its own function
- qemu: address: Handle all the video devices within a single loop
- conf: Introduce virDomainVideoDefClear helper
- conf: Introduce virDomainDefPostParseVideo helper
- qemu: validate: Enforce compile time switch type checking for videos
- tests: Add capabilities data for QEMU 2.11 x86_64
- tests: Update capabilities data for QEMU 3.0.0 x86_64
- qemu: qemuBuildHostdevCommandLine: Use a helper variable mdevsrc
- qemu: caps: Introduce a capability for egl-headless
- qemu: Introduce a new graphics display type 'headless'
- qemu: caps: Add vfio-pci.display capability
- conf: Introduce virDomainGraphicsDefHasOpenGL helper
- conf: Replace 'error' with 'cleanup' in virDomainHostdevDefParseXMLSubsys
- conf: Introduce new <hostdev> attribute 'display'
- qemu: command: Enable formatting vfio-pci.display option onto cmdline
- docs: Rephrase the mediated devices hostdev section a bit
- conf: Introduce new video type 'none'
- virt-xml-validate: Add schema for nwfilterbinding
- tools: Fix typo generating adapter_wwpn field
- src: Fix memory leak in virNWFilterBindingDispose

* Mon Jul 23 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-3
- qemu: hotplug: Do not try to add secret object for TLS if it does not exist
- qemu: monitor: Make qemuMonitorAddObject more robust against programming errors
- spec: Explicitly require matching libvirt-libs
- virDomainConfNWFilterInstantiate: initialize @xml to avoid random crash
- qemuProcessStartPRDaemonHook: Try to set NS iff domain was started with one
- qemuDomainValidateStorageSource: Relax PR validation
- virStoragePRDefFormat: Suppress path formatting for migratable XML
- qemu: Wire up PR_MANAGER_STATUS_CHANGED event
- qemu_monitor: Introduce qemuMonitorJSONGetPRManagerInfo
- qemu: Fetch pr-helper process info on reconnect
- qemu: Fix ATTRIBUTE_NONNULL for qemuMonitorAddObject
- virsh.pod: Fix a command name typo in nwfilter-binding-undefine
- docs: schema: Add missing <alias> to vsock device
- virnetdevtap: Don't crash on !ifname in virNetDevTapInterfaceStats
- tests: fix TLS handshake failure with TLS 1.3

* Mon Jul  9 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-2
- qemu: Add capability for the HTM pSeries feature
- conf: Parse and format the HTM pSeries feature
- qemu: Format the HTM pSeries feature
- qemu: hotplug: Don't access srcPriv when it's not allocated
- qemuDomainNestedJobAllowed: Allow QEMU_JOB_NONE
- src: Mention DEVICE_REMOVAL_FAILED event in virDomainDetachDeviceAlias docs
- virsh.pod: Drop --persistent for detach-device-alias
- qemu: don't use chardev FD passing with standalone args
- qemu: remove chardevStdioLogd param from vhostuser code path
- qemu: consolidate parameters of qemuBuildChrChardevStr into flags
- qemu: don't use chardev FD passing for vhostuser backend
- qemu: fix UNIX socket chardevs operating in client mode
- qemuDomainDeviceDefValidateNetwork: Check for range only if IP prefix set
- spec: Temporarily drop gluster support

* Tue Jul  3 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-1
- Rebased to libvirt-4.5.0

* Fri May 25 2018 Jiri Denemark <jdenemar@redhat.com> - 4.3.0-1
- Rebased to libvirt-4.3.0

* Wed Mar 21 2018 Daniel P. Berrangé <berrange@redhat.com> - 4.1.0-2
- Fix systemd macro argument with line continuations (rhbz#1558648)

* Mon Mar  5 2018 Daniel Berrange <berrange@redhat.com> - 4.1.0-1
- Rebase to version 4.1.0

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 19 2018 Daniel P. Berrange <berrange@redhat.com> - 4.0.0-1
- Rebase to version 4.0.0

* Wed Dec 20 2017 Cole Robinson <crobinso@redhat.com> - 3.10.0-2
- Rebuild for xen 4.10

* Tue Dec  5 2017 Daniel P. Berrange <berrange@redhat.com> - 3.10.0-1
- Rebase to version 3.10.0

* Fri Nov  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.9.0-1
- Rebase to version 3.9.0

* Wed Oct  4 2017 Daniel P. Berrange <berrange@redhat.com> - 3.8.0-1
- Rebase to version 3.8.0

* Mon Sep  4 2017 Daniel P. Berrange <berrange@redhat.com> - 3.7.0-1
- Rebase to version 3.7.0

* Wed Aug  2 2017 Daniel P. Berrange <berrange@redhat.com> - 3.6.0-1
- Rebase to version 3.6.0

* Sun Jul 30 2017 Florian Weimer <fweimer@redhat.com> - 3.5.0-4
- Rebuild with binutils fix for ppc64le (#1475636)

* Tue Jul 25 2017 Daniel P. Berrange <berrange@redhat.com> - 3.5.0-3
- Disabled RBD on i386, arm, ppc64 (rhbz #1474743)

* Mon Jul 17 2017 Cole Robinson <crobinso@redhat.com> - 3.5.0-2
- Rebuild for xen 4.9

* Thu Jul  6 2017 Daniel P. Berrange <berrange@redhat.com> - 3.5.0-1
- Rebase to version 3.5.0

* Fri Jun  2 2017 Daniel P. Berrange <berrange@redhat.com> - 3.4.0-1
- Rebase to version 3.4.0

* Mon May  8 2017 Daniel P. Berrange <berrange@redhat.com> - 3.3.0-1
- Rebase to version 3.3.0

* Mon Apr  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.2.0-1
- Rebase to version 3.2.0

* Fri Mar  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.1.0-1
- Rebase to version 3.1.0

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jan 19 2017 Daniel P. Berrange <berrange@redhat.com> - 3.0.0-1
- Rebase to version 3.0.0
